***************************************************************************************
** This code generates the Appendix Figure 16, which reports the share of 			 **
** respondents indicating a specific policy as the best one to fight inflation.	     **
***************************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

****************************************************************************


*** set general style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"


****************************************************************
** Compute conditional shares and create the figure by income **
****************************************************************

{
preserve

*Note: keep only respondents who do not see the treatment video on the trade-offs between inflation and unemployment.

keep if treatment==0

*Note: these variables are indicators taking value 1 when the respondent reports in the open-ended question that the policy of interest is the best one to fight inflation.

global redib oeqcl_biden oeqcl_fis_pol_cont oeqcl_fis_pol_exp oeqcl_greedflation oeqcl_help_lowinc oeqcl_immigration oeqcl_mon_pol_cont oeqcl_mon_pol_exp oeqcl_price_cap oeqcl_protect_pol

global j=1

foreach var_selec of varlist $redib{
		sum `var_selec' if incomegroup_agg==1
	scalar    redib_low_${j}=r(mean)*100 
	scalar se_redib_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    redib_${j}=r(mean)*100 
	scalar se_redib_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if incomegroup_agg==3
	scalar    redib_high_${j}=r(mean)*100 
	scalar se_redib_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

clear
set obs 39
egen n = seq()

foreach var in redib redib_low redib_high {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}

foreach x in 1 5 9 13 17 21 25 29 33 37  {
replace redib_low = redib_low_`x' if n == `x'
replace min_redib_low = redib_low_`x'  - 1.965 * se_redib_low_`x'  if n == `x'
replace max_redib_low = redib_low_`x'  + 1.965 * se_redib_low_`x'  if n == `x'
scalar up_`x'=redib_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 10 14 18 22 26 30 34 38  {
replace redib = redib_`x' if n == `x'
replace min_redib = redib_`x'  - 1.965 * se_redib_`x'  if n == `x'
replace max_redib = redib_`x'  + 1.965 * se_redib_`x'  if n == `x'
scalar up_`x'=redib_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 11 15 19 23 27 31 35 39 {
replace redib_high = redib_high_`x' if n == `x'
replace min_redib_high = redib_high_`x'  - 1.965 * se_redib_high_`x'  if n == `x'
replace max_redib_high = redib_high_`x'  + 1.965 * se_redib_high_`x'  if n == `x'
scalar up_`x'=redib_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}



* Set figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter n redib_low ,  color(orange) msymbol(O)) (rcap min_redib_low max_redib_low n, horizontal color(orange))  (scatter n redib_high ,  color("17 119 51") msymbol(V) ) (rcap min_redib_high max_redib_high n, horizontal color("17 119 51"))  , ///
			 legend(order(1 3) lab(1 "{bf:Income <$40k}") lab(3 "{bf:Income >$125k}")  size(vlarge) position(6) cols(1)   symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center))  xlabel(0(10)40, labsize(vlarge) ) ylabel(2 "Change President" 6 "Contractionary fiscal policy" 10 "Stimulate the economy" 14 "Fighting greedflation" 18 "Help low income" 22 "Reduce immigration"  26 "Contractionary monetary policy" 30 "Expansionary monetary policy" 34 "Price caps" 38 "Protectionist policies"  , labsize(vlarge) noticks nogrid)  xtitle(" " , size(huge)) ytitle("")   yline(4 8 12 16 20 24 28 32 36 , lwidth(vvthin))
		
resize, xsize(20cm) ysize(25cm)
graph export "$appendix_figures/figa16_1.png", as(png) width(2666) height(3333)  replace

restore

}


*******************************************************************************
** Compute conditional shares and create the figure by age 					 **
*******************************************************************************

{
preserve

*Note: keep only respondents who do not see the treatment video on the trade-offs between inflation and unemployment.

keep if treatment==0

*Note: these variables are indicators taking value 1 when the respondent reports in the open-ended question that the policy of interest is the best one to fight inflation.

global redib oeqcl_biden oeqcl_fis_pol_cont oeqcl_fis_pol_exp oeqcl_greedflation oeqcl_help_lowinc oeqcl_immigration  oeqcl_mon_pol_cont oeqcl_mon_pol_exp oeqcl_price_cap oeqcl_protect_pol

global j=1

foreach var_selec of varlist $redib{
		sum `var_selec' if agegroup_agg==1
	scalar    redib_low_${j}=r(mean)*100 
	scalar se_redib_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    redib_${j}=r(mean)*100 
	scalar se_redib_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==3
	scalar    redib_high_${j}=r(mean)*100 
	scalar se_redib_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

clear
set obs 39
egen n = seq()

foreach var in redib redib_low redib_high {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}

foreach x in 1 5 9 13 17 21 25 29 33 37 {
replace redib_low = redib_low_`x' if n == `x'
replace min_redib_low = redib_low_`x'  - 1.965 * se_redib_low_`x'  if n == `x'
replace max_redib_low = redib_low_`x'  + 1.965 * se_redib_low_`x'  if n == `x'
scalar up_`x'=redib_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 10 14 18 22 26 30 34 38  {
replace redib = redib_`x' if n == `x'
replace min_redib = redib_`x'  - 1.965 * se_redib_`x'  if n == `x'
replace max_redib = redib_`x'  + 1.965 * se_redib_`x'  if n == `x'
scalar up_`x'=redib_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 11 15 19 23 27 31 35 39 {
replace redib_high = redib_high_`x' if n == `x'
replace min_redib_high = redib_high_`x'  - 1.965 * se_redib_high_`x'  if n == `x'
replace max_redib_high = redib_high_`x'  + 1.965 * se_redib_high_`x'  if n == `x'
scalar up_`x'=redib_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}



* Set figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter n redib_low ,  color(black) msymbol(T)) (rcap min_redib_low max_redib_low n, horizontal color(black)) (scatter n redib ,  color(pink) msymbol(S)) (rcap min_redib max_redib n, horizontal color(pink) )   (scatter n redib_high ,  color(purple) msymbol(a) ) (rcap min_redib_high max_redib_high n, horizontal color(purple))  , ///
			 legend(order(1 3 5) lab(1 "{bf:18-29 years}") lab(3 "{bf:30-49 years}") lab(5 "{bf:50-69 years}")  size(vlarge) position(6) cols(2)   symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center))  xlabel(0(10)40, labsize(vlarge) ) ylabel(2 "Change President" 6 "Contractionary fiscal policy" 10 "Stimulate the economy" 14 "Fighting greedflation" 18 "Help low income" 22 "Reduce immigration" 26 "Contractionary monetary policy" 30 "Expansionary monetary policy" 34 "Price caps" 38 "Protectionist policies"  , labsize(vlarge) noticks nogrid)  xtitle(" " , size(huge)) ytitle("")   yline(4 8 12 16 20 24 28 32 36 , lwidth(vvthin))
			 resize, xsize(20cm) ysize(25cm)
		

graph export "$appendix_figures/figa16_2.png", as(png) width(2666) height(3333)  replace

restore

}

