******************************************************************************
** This code generates Appendix Figure 17, which reports the share of 		** 
** respondents who support or strongly support the policy to combat 		**
** inflation listed in the corresponding row, 								**
** dividing the sample income and age. 										**
******************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

****************************************************************************


*** set general style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"


****************************************************************
** Compute conditional shares and create the figure by income **
****************************************************************

{
preserve

*Note: sample includes only respondents who were not shown the video on the trade-offs between inflation and unemployment
keep if treatment==0


global fed dummy_policy_announcement dummy_policy_decreasemsupply  dummy_policy_decreaserate dummy_policy_increaserate
   
global gvt_debt dummy_policy_debtreduce_lowinc dummy_policy_debtreduce_midinc dummy_policy_debtreduce_highinc   

global misc dummy_policy_imports dummy_policy_wagecaps dummy_policy_pricecaps dummy_policy_corporatetaxes dummy_policy_transfer_highinc dummy_policy_antitrust     



* Compute and store conditional means and standard errors for each policy for Republican, Democrats and full sample

global j=1

foreach var_selec of varlist $misc{
	sum `var_selec' if incomegroup_agg==1
	scalar    misc_low_${j}=r(mean)*100 
	scalar se_misc_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    misc_${j}=r(mean)*100 
	scalar se_misc_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if incomegroup_agg==3
	scalar    misc_high_${j}=r(mean)*100 
	scalar se_misc_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $gvt_debt {
	sum `var_selec' if incomegroup_agg==1
	scalar    gvt_debt_low_${j}=r(mean)*100 
	scalar se_gvt_debt_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    gvt_debt_${j}=r(mean)*100 
	scalar se_gvt_debt_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if incomegroup_agg==3
	scalar    gvt_debt_high_${j}=r(mean)*100 
	scalar se_gvt_debt_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $fed{
		sum `var_selec' if incomegroup_agg==1
	scalar    fed_low_${j}=r(mean)*100 
	scalar se_fed_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    fed_${j}=r(mean)*100 
	scalar se_fed_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if incomegroup_agg==3
	scalar    fed_high_${j}=r(mean)*100 
	scalar se_fed_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

clear
set obs 61
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in misc misc_low misc_high gvt_debt gvt_debt_low gvt_debt_high fed_low fed_high fed {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 9 13 17 21{
replace misc_low = misc_low_`x' if n == `x'
replace min_misc_low = misc_low_`x'  - 1.965 * se_misc_low_`x'  if n == `x'
replace max_misc_low = misc_low_`x'  + 1.965 * se_misc_low_`x'  if n == `x'
scalar up_`x'=misc_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 10 14 18 22{
replace misc = misc_`x' if n == `x'
replace min_misc = misc_`x'  - 1.965 * se_misc_`x'  if n == `x'
replace max_misc = misc_`x'  + 1.965 * se_misc_`x'  if n == `x'
scalar up_`x'=misc_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 11 15 19 23{
replace misc_high = misc_high_`x' if n == `x'
replace min_misc_high = misc_high_`x'  - 1.965 * se_misc_high_`x'  if n == `x'
replace max_misc_high = misc_high_`x'  + 1.965 * se_misc_high_`x'  if n == `x'
scalar up_`x'=misc_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}



foreach x in 30 34 38 {
replace gvt_debt_low = gvt_debt_low_`x' if n == `x'
replace min_gvt_debt_low = gvt_debt_low_`x'  - 1.965 * se_gvt_debt_low_`x'  if n == `x'
replace max_gvt_debt_low = gvt_debt_low_`x'  + 1.965 * se_gvt_debt_low_`x'  if n == `x'
scalar up_`x'=gvt_debt_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 31 35 39 {
replace gvt_debt = gvt_debt_`x' if n == `x'
replace min_gvt_debt = gvt_debt_`x'  - 1.965 * se_gvt_debt_`x'  if n == `x'
replace max_gvt_debt = gvt_debt_`x'  + 1.965 * se_gvt_debt_`x'  if n == `x'
scalar up_`x'=gvt_debt_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 32 36 40 {
replace gvt_debt_high = gvt_debt_high_`x' if n == `x'
replace min_gvt_debt_high = gvt_debt_high_`x'  - 1.965 * se_gvt_debt_high_`x'  if n == `x'
replace max_gvt_debt_high = gvt_debt_high_`x'  + 1.965 * se_gvt_debt_high_`x'  if n == `x'
scalar up_`x'=gvt_debt_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 47 51 55 59 {
replace fed_low = fed_low_`x' if n == `x'
replace min_fed_low = fed_low_`x'  - 1.965 * se_fed_low_`x'  if n == `x'
replace max_fed_low = fed_low_`x'  + 1.965 * se_fed_low_`x'  if n == `x'
scalar up_`x'=fed_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 48 52 56 60 {
replace fed = fed_`x' if n == `x'
replace min_fed = fed_`x'  - 1.965 * se_fed_`x'  if n == `x'
replace max_fed = fed_`x'  + 1.965 * se_fed_`x'  if n == `x'
scalar up_`x'=fed_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 49 53 57 61 {
replace fed_high = fed_high_`x' if n == `x'
replace min_fed_high = fed_high_`x'  - 1.965 * se_fed_high_`x'  if n == `x'
replace max_fed_high = fed_high_`x'  + 1.965 * se_fed_high_`x'  if n == `x'
scalar up_`x'=fed_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


* Create yvar for command scatter (to control vertical positioning)

gen temp=0.5+n*0.25 if n<24
replace temp=1.25+0.25*n if n<41 & temp==.
replace temp=2 + 0.25*n if temp==.


* Set the figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter temp misc_low , color(orange) msymbol(O)) (rcap min_misc_low max_misc_low temp, horizontal color(orange) )   (scatter temp misc_high ,  color("17 119 51") msymbol(V) ) (rcap min_misc_high max_misc_high temp,  horizontal color("17 119 51"))   ///
   (scatter temp gvt_debt_low ,   color(orange) msymbol(O) ) (rcap min_gvt_debt_low max_gvt_debt_low temp, horizontal color(orange) )    (scatter temp gvt_debt_high ,  color("17 119 51") msymbol(V)) (rcap min_gvt_debt_high max_gvt_debt_high temp,  horizontal color("17 119 51"))   ///
   (scatter temp fed_low ,  color(orange) msymbol(O) ) (rcap min_fed_low max_fed_low temp, horizontal color(orange) )  (scatter temp fed_high ,  color("17 119 51") msymbol(V) ) (rcap min_fed_high max_fed_high temp,  horizontal color("17 119 51")), ///
			 legend(order(1 3) lab(1 "{bf:Income <$40k}") lab(3 "{bf:Income >$125k}")   position(6) cols(1) size(medlarge)  symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center))  xlabel(0(20)80, labsize(medlarge) ) ylabel(1 `" "Restrict imports" "' 2 `" "Regulate wage growth" "' 3 `" "Freeze prices of essentials" "' 4 `" "Increase corporate taxes" "' 5 `" "Increase taxes on high" "income to fund transfers" "' 6 `" "Tighten antitrust regulation" "'  7.5  `" "{bf:Other policies}" "' 9 `" "Reducing spending on social programs" "' 10 `" "Increasing taxes on" "high and middle income" "' 11 `" "Increasing taxes on high income" "' 12.5  `" "{bf:Reductions in government}" "{bf:debt financed by}" "' 14 `" "Announce future plans" "for interest rate" "' 15 `" "Decrease money supply" "' 16 `" "Decrease interest rate" "' 17 `" "Increase interest rate" "' 18.5 `" "{bf:Monetary policy}" "' , labsize(vlarge) noticks nogrid)   xtitle(" ", size(large)) ytitle("")   yline(7.5 12.5) yline(1.5 2.5 3.5 4.5 5.5 9.5 10.5 14.5 15.5 16.5, lwidth(vthin) lcolor(gray%50))
			resize, xsize(20cm) ysize(25cm)

graph export "$appendix_figures/figa17_1.png", as(png) width(2000) height(2600) replace

restore

}




*************************************************************
** Compute conditional shares and create the figure by age **
*************************************************************


{
preserve

*Note: sample includes only respondents who were not shown the video on the trade-offs between inflation and unemployment

keep if treatment==0


global fed dummy_policy_announcement dummy_policy_decreasemsupply  dummy_policy_decreaserate dummy_policy_increaserate   
global gvt_debt dummy_policy_debtreduce_lowinc dummy_policy_debtreduce_midinc dummy_policy_debtreduce_highinc   

global misc dummy_policy_imports dummy_policy_wagecaps dummy_policy_pricecaps dummy_policy_corporatetaxes dummy_policy_transfer_highinc dummy_policy_antitrust     


* Compute and store conditional means and standard errors for each cause for respondents with age 18-29, 30-49, and 50-69.

global j=1

foreach var_selec of varlist $misc{
	sum `var_selec' if agegroup_agg==1
	scalar    misc_low_${j}=r(mean)*100 
	scalar se_misc_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    misc_${j}=r(mean)*100 
	scalar se_misc_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if agegroup_agg==3
	scalar    misc_high_${j}=r(mean)*100 
	scalar se_misc_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $gvt_debt {
	sum `var_selec' if agegroup_agg==1
	scalar    gvt_debt_low_${j}=r(mean)*100 
	scalar se_gvt_debt_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    gvt_debt_${j}=r(mean)*100 
	scalar se_gvt_debt_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if agegroup_agg==3
	scalar    gvt_debt_high_${j}=r(mean)*100 
	scalar se_gvt_debt_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $fed{
		sum `var_selec' if agegroup_agg==1
	scalar    fed_low_${j}=r(mean)*100 
	scalar se_fed_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    fed_${j}=r(mean)*100 
	scalar se_fed_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==3
	scalar    fed_high_${j}=r(mean)*100 
	scalar se_fed_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

clear
set obs 61
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in misc misc_low misc_high gvt_debt gvt_debt_low gvt_debt_high fed_low fed_high fed {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 9 13 17 21{
replace misc_low = misc_low_`x' if n == `x'
replace min_misc_low = misc_low_`x'  - 1.965 * se_misc_low_`x'  if n == `x'
replace max_misc_low = misc_low_`x'  + 1.965 * se_misc_low_`x'  if n == `x'
scalar up_`x'=misc_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 10 14 18 22{
replace misc = misc_`x' if n == `x'
replace min_misc = misc_`x'  - 1.965 * se_misc_`x'  if n == `x'
replace max_misc = misc_`x'  + 1.965 * se_misc_`x'  if n == `x'
scalar up_`x'=misc_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 11 15 19 23{
replace misc_high = misc_high_`x' if n == `x'
replace min_misc_high = misc_high_`x'  - 1.965 * se_misc_high_`x'  if n == `x'
replace max_misc_high = misc_high_`x'  + 1.965 * se_misc_high_`x'  if n == `x'
scalar up_`x'=misc_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}



foreach x in 30 34 38 {
replace gvt_debt_low = gvt_debt_low_`x' if n == `x'
replace min_gvt_debt_low = gvt_debt_low_`x'  - 1.965 * se_gvt_debt_low_`x'  if n == `x'
replace max_gvt_debt_low = gvt_debt_low_`x'  + 1.965 * se_gvt_debt_low_`x'  if n == `x'
scalar up_`x'=gvt_debt_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 31 35 39 {
replace gvt_debt = gvt_debt_`x' if n == `x'
replace min_gvt_debt = gvt_debt_`x'  - 1.965 * se_gvt_debt_`x'  if n == `x'
replace max_gvt_debt = gvt_debt_`x'  + 1.965 * se_gvt_debt_`x'  if n == `x'
scalar up_`x'=gvt_debt_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 32 36 40 {
replace gvt_debt_high = gvt_debt_high_`x' if n == `x'
replace min_gvt_debt_high = gvt_debt_high_`x'  - 1.965 * se_gvt_debt_high_`x'  if n == `x'
replace max_gvt_debt_high = gvt_debt_high_`x'  + 1.965 * se_gvt_debt_high_`x'  if n == `x'
scalar up_`x'=gvt_debt_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 47 51 55 59 {
replace fed_low = fed_low_`x' if n == `x'
replace min_fed_low = fed_low_`x'  - 1.965 * se_fed_low_`x'  if n == `x'
replace max_fed_low = fed_low_`x'  + 1.965 * se_fed_low_`x'  if n == `x'
scalar up_`x'=fed_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 48 52 56 60 {
replace fed = fed_`x' if n == `x'
replace min_fed = fed_`x'  - 1.965 * se_fed_`x'  if n == `x'
replace max_fed = fed_`x'  + 1.965 * se_fed_`x'  if n == `x'
scalar up_`x'=fed_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 49 53 57 61 {
replace fed_high = fed_high_`x' if n == `x'
replace min_fed_high = fed_high_`x'  - 1.965 * se_fed_high_`x'  if n == `x'
replace max_fed_high = fed_high_`x'  + 1.965 * se_fed_high_`x'  if n == `x'
scalar up_`x'=fed_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


* Create yvar for command scatter (to control vertical positioning)

gen temp=0.5+n*0.25 if n<24
replace temp=1.25+0.25*n if n<41 & temp==.
replace temp=2 + 0.25*n if temp==.


* Set the figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter  temp misc_low ,  color(black) msymbol(T)) (rcap min_misc_low max_misc_low  temp, horizontal color(black)  ) (scatter  temp misc ,  color(pink) msymbol(S)) (rcap min_misc max_misc  temp, horizontal color(pink)  )    (scatter  temp misc_high ,  color(purple) msymbol(a) ) (rcap min_misc_high max_misc_high  temp, horizontal color(purple)  )   ///
   (scatter  temp gvt_debt_low ,  color(black) msymbol(T) ) (rcap min_gvt_debt_low max_gvt_debt_low  temp, horizontal   color(black)) (scatter  temp gvt_debt ,  color(pink) msymbol(S) ) (rcap min_gvt_debt max_gvt_debt  temp, horizontal color(pink)  )    (scatter  temp gvt_debt_high ,  color(purple) msymbol(a)) (rcap min_gvt_debt_high max_gvt_debt_high  temp, horizontal   color(purple))   ///
   (scatter  temp fed_low ,  color(black) msymbol(T) ) (rcap min_fed_low max_fed_low  temp, horizontal color(black)  )  (scatter  temp fed ,  color(pink) msymbol(S) ) (rcap min_fed max_fed  temp, horizontal color(pink)  )  (scatter  temp fed_high ,  color(purple) msymbol(a) ) (rcap min_fed_high max_fed_high  temp, horizontal color(purple)  ), ///
			 legend(order(1 3 5) lab(1 "{bf:18-29 years}") lab(3 "{bf:30-49 years}") lab(5 "{bf:50-69 years}")   position(6) cols(2) size(medlarge)symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center))  xlabel(0(20)80, labsize(medlarge)) ylabel(1 `" "Restrict imports" "' 2 `" "Regulate wage growth" "' 3 `" "Freeze prices of essentials" "' 4 `" "Increase corporate taxes" "' 5 `" "Increase taxes on high" "income to fund transfers" "' 6 `" "Tighten antitrust regulation" "'  7.5  `" "{bf:Other policies}" "' 9 `" "Reducing spending on social programs" "' 10 `" "Increasing taxes on" "high and middle income" "' 11 `" "Increasing taxes on high income" "' 12.5  `" "{bf:Reductions in government}" "{bf:debt financed by}" "' 14 `" "Announce future plans" "for interest rate" "' 15 `" "Decrease money supply" "' 16 `" "Decrease interest rate" "' 17 `" "Increase interest rate" "' 18.5 `" "{bf:Monetary policy}" "'  , labsize(vlarge) noticks nogrid)   xtitle(" ", size(large)) ytitle("")   yline(7.5 12.5) yline(1.5 2.5 3.5 4.5 5.5 9.5 10.5 14.5 15.5 16.5, lwidth(vthin) lcolor(gray%50))
			resize, xsize(20cm) ysize(25cm)
graph export "$appendix_figures/figa17_2.png", as(png) width(2000) height(2600) replace

restore

}

