*****************************************************************************************
** This code generates Appendix Figure 18, which reports the share of respondents who  ** 
** support or strongly support the policy to combar the redistributive impact 		   **
** of inflation listed in the corresponding row, dividing the sample by income and age.** 
*****************************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

********************************************************************************


*** set general style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"

******************************************************
** Compute conditional shares and create the figure **
******************************************************

{
preserve

*Note: sample includes only respondents who were not shown the video on the trade-offs between inflation and unemployment
keep if treatment==0


global redib dummy_policy_redib_lowinctransf dummy_policy_redib_stamps dummy_policy_redib_vouch_lowinc dummy_policy_redib_vouch_midinc dummy_policy_redib_minwage


* Compute and store conditional means and standard errors for each policy by income

global j=1

foreach var_selec of varlist $redib{
		sum `var_selec' if incomegroup_agg==1
	scalar    redib_low_${j}=r(mean)*100 
	scalar se_redib_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    redib_${j}=r(mean)*100 
	scalar se_redib_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if incomegroup_agg==3
	scalar    redib_high_${j}=r(mean)*100 
	scalar se_redib_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

clear
set obs 19
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in redib redib_low redib_high {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 9 13 17  {
replace redib_low = redib_low_`x' if n == `x'
replace min_redib_low = redib_low_`x'  - 1.965 * se_redib_low_`x'  if n == `x'
replace max_redib_low = redib_low_`x'  + 1.965 * se_redib_low_`x'  if n == `x'
scalar up_`x'=redib_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 10 14 18  {
replace redib = redib_`x' if n == `x'
replace min_redib = redib_`x'  - 1.965 * se_redib_`x'  if n == `x'
replace max_redib = redib_`x'  + 1.965 * se_redib_`x'  if n == `x'
scalar up_`x'=redib_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 11 15 19 {
replace redib_high = redib_high_`x' if n == `x'
replace min_redib_high = redib_high_`x'  - 1.965 * se_redib_high_`x'  if n == `x'
replace max_redib_high = redib_high_`x'  + 1.965 * se_redib_high_`x'  if n == `x'
scalar up_`x'=redib_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


* Set the figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter n redib_low ,  color(orange) msymbol(O)) (rcap min_redib_low max_redib_low n, horizontal color(orange))  (scatter n redib_high ,  color("17 119 51") msymbol(V) ) (rcap min_redib_high max_redib_high n, horizontal color("17 119 51"))  , ///
			 legend(order(1 3) lab(1 "{bf:Income <$40k}") lab(3 "{bf:Income >$125k}")  size(medium) position(6) cols(2)   symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center))  xlabel(0(20)100, labsize(medium) ) ylabel(2 "Increase low income transfers" 6 "Increase food stamps" 10 "Increase vouchers for low income" 14 "Increase vouchers for mid income" 18 "Increase minimum wage"  , labsize(medium) noticks nogrid)  xtitle(" " , size(huge)) ytitle("")   yline(4 8 12 16 , lwidth(vvthin))
		

graph export "$appendix_figures/figa18_1.png", as(png)  replace

restore

}




*************************************************************
** Compute conditional shares and create the figure by age **
*************************************************************


{
preserve

*Note: sample includes only respondents who were not shown the video on the trade-offs between inflation and unemployment

keep if treatment==0


global redib dummy_policy_redib_lowinctransf dummy_policy_redib_stamps dummy_policy_redib_vouch_lowinc dummy_policy_redib_vouch_midinc dummy_policy_redib_minwage


* Compute and store conditional means and standard errors for each policy by age

global j=1

foreach var_selec of varlist $redib{
		sum `var_selec' if agegroup_agg==1
	scalar    redib_low_${j}=r(mean)*100 
	scalar se_redib_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    redib_${j}=r(mean)*100 
	scalar se_redib_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==3
	scalar    redib_high_${j}=r(mean)*100 
	scalar se_redib_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

clear
set obs 19
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in redib redib_low redib_high {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 9 13 17  {
replace redib_low = redib_low_`x' if n == `x'
replace min_redib_low = redib_low_`x'  - 1.965 * se_redib_low_`x'  if n == `x'
replace max_redib_low = redib_low_`x'  + 1.965 * se_redib_low_`x'  if n == `x'
scalar up_`x'=redib_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 10 14 18  {
replace redib = redib_`x' if n == `x'
replace min_redib = redib_`x'  - 1.965 * se_redib_`x'  if n == `x'
replace max_redib = redib_`x'  + 1.965 * se_redib_`x'  if n == `x'
scalar up_`x'=redib_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 11 15 19 {
replace redib_high = redib_high_`x' if n == `x'
replace min_redib_high = redib_high_`x'  - 1.965 * se_redib_high_`x'  if n == `x'
replace max_redib_high = redib_high_`x'  + 1.965 * se_redib_high_`x'  if n == `x'
scalar up_`x'=redib_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

* Set the figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter n redib_low ,  color(black) msymbol(T)) (rcap min_redib_low max_redib_low n, horizontal color(black)) (scatter n redib ,  color(pink) msymbol(S)) (rcap min_redib max_redib n, horizontal color(pink))  (scatter n redib_high ,  color(purple) msymbol(a)) (rcap min_redib_high max_redib_high n, horizontal color(purple))  , ///
			  legend(order(1 3 5) lab(1 "{bf:18-29 years}") lab(3 "{bf:30-49 years}") lab(5 "{bf:50-69 years}")    size(medium) position(6) cols(2) symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center))  xlabel(0(20)100, labsize(medium) ) ylabel(2 "Increase low income transfers" 6 "Increase food stamps" 10 "Increase vouchers for low income" 14 "Increase vouchers for mid income" 18 "Increase minimum wage" , labsize(medium) noticks nogrid)  xtitle(" " , size(huge)) ytitle("")   yline(4 8 12 16 , lwidth(vvthin))
		

graph export "$appendix_figures/figa18_2.png", as(png)  replace

restore

}
