********************************************************************************
** This code generates Figure 19, which reports the ratio of the coefficient  **
** of the difference of inflation between two economies and 				  **
** the difference in unemployment between two economies                       **
********************************************************************************


clear all

use "$data/inflation_understanding_conjoint.dta", clear

********************************************************************************

replace unemployment_first=0 if inflation_first==1
label var diff_u "\$\Delta\$ u"
label var diff_pi "\$\Delta\$ \$\pi\$"

drop diff_u_* diff_pi_*

preserve
matrix define R=J(14,5,.)
***Full sample
reghdfe chosen diff_u diff_pi, absorb(*Id) cluster(*Id)
nlcom ratio: (_b[diff_pi] / _b[diff_u] ), post
matrix R[1,1]=e(b)[1,1]
matrix R[1,2]=sqrt(e(V)[1,1])
matrix R[1,3]=R[1,1]- invnormal(0.975)*R[1,2]
matrix R[1,4]=R[1,1]+ invnormal(0.975)*R[1,2]
matrix R[1,5]=19

***Only republicans
reghdfe chosen diff_u diff_pi if republican==1, absorb(*Id) cluster(*Id)
nlcom ratio: (_b[diff_pi] / _b[diff_u] ), post
matrix R[2,1]=e(b)[1,1]
matrix R[2,2]=sqrt(e(V)[1,1])
matrix R[2,3]=R[2,1]- invnormal(0.975)*R[2,2]
matrix R[2,4]=R[2,1]+ invnormal(0.975)*R[2,2]
matrix R[2,5]=16

***Only democrats
reghdfe chosen diff_u diff_pi if democrat==1, absorb(*Id) cluster(*Id)
nlcom ratio: (_b[diff_pi] / _b[diff_u] ), post
matrix R[3,1]=e(b)[1,1]
matrix R[3,2]=sqrt(e(V)[1,1])
matrix R[3,3]=R[3,1]- invnormal(0.975)*R[3,2]
matrix R[3,4]=R[3,1]+ invnormal(0.975)*R[3,2]
matrix R[3,5]=15

***Only rich
reghdfe chosen diff_u diff_pi if incomegroup_agg_3==1, absorb(*Id) cluster(*Id)
nlcom ratio: (_b[diff_pi] / _b[diff_u] ), post
matrix R[4,1]=e(b)[1,1]
matrix R[4,2]=sqrt(e(V)[1,1])
matrix R[4,3]=R[4,1]- invnormal(0.975)*R[4,2]
matrix R[4,4]=R[4,1]+ invnormal(0.975)*R[4,2]
matrix R[4,5]=12

***Only poor
reghdfe chosen diff_u diff_pi if incomegroup_agg_1==1, absorb(*Id) cluster(*Id)
nlcom ratio: (_b[diff_pi] / _b[diff_u] ), post
matrix R[5,1]=e(b)[1,1]
matrix R[5,2]=sqrt(e(V)[1,1])
matrix R[5,3]=R[5,1]- invnormal(0.975)*R[5,2]
matrix R[5,4]=R[5,1]+ invnormal(0.975)*R[5,2]
matrix R[5,5]=11

***Only old
reghdfe chosen diff_u diff_pi if agegroup_agg_3==1, absorb(*Id) cluster(*Id)
nlcom ratio: (_b[diff_pi] / _b[diff_u] ), post
matrix R[6,1]=e(b)[1,1]
matrix R[6,2]=sqrt(e(V)[1,1])
matrix R[6,3]=R[6,1]- invnormal(0.975)*R[6,2]
matrix R[6,4]=R[6,1]+ invnormal(0.975)*R[6,2]
matrix R[6,5]=8

***Only mid
reghdfe chosen diff_u diff_pi if agegroup_agg_2==1, absorb(*Id) cluster(*Id)
nlcom ratio: (_b[diff_pi] / _b[diff_u] ), post
matrix R[7,1]=e(b)[1,1]
matrix R[7,2]=sqrt(e(V)[1,1])
matrix R[7,3]=R[7,1]- invnormal(0.975)*R[7,2]
matrix R[7,4]=R[7,1]+ invnormal(0.975)*R[7,2]
matrix R[7,5]=7

***Only young
reghdfe chosen diff_u diff_pi if agegroup_agg_1==1, absorb(*Id) cluster(*Id)
nlcom ratio: (_b[diff_pi] / _b[diff_u] ), post
matrix R[8,1]=e(b)[1,1]
matrix R[8,2]=sqrt(e(V)[1,1])
matrix R[8,3]=R[8,1]- invnormal(0.975)*R[8,2]
matrix R[8,4]=R[8,1]+ invnormal(0.975)*R[8,2]
matrix R[8,5]=6

***Only control
reghdfe chosen diff_u diff_pi if conjoint_info==0, absorb(*Id) cluster(*Id)
nlcom ratio: (_b[diff_pi] / _b[diff_u] ), post
matrix R[9,1]=e(b)[1,1]
matrix R[9,2]=sqrt(e(V)[1,1])
matrix R[9,3]=R[9,1]- invnormal(0.975)*R[9,2]
matrix R[9,4]=R[9,1]+ invnormal(0.975)*R[9,2]
matrix R[9,5]=3

***Only treatment
reghdfe chosen diff_u diff_pi if conjoint_info==1, absorb(*Id) cluster(*Id)
nlcom ratio: (_b[diff_pi] / _b[diff_u] ), post
matrix R[10,1]=e(b)[1,1]
matrix R[10,2]=sqrt(e(V)[1,1])
matrix R[10,3]=R[10,1]- invnormal(0.975)*R[10,2]
matrix R[10,4]=R[10,1]+ invnormal(0.975)*R[10,2]
matrix R[10,5]=2



clear
svmat R
rename R1 coef
rename R2 std_se
rename R3 lb
rename R4 ub
rename R5 spec

gen spec_long=""
replace spec_long="High unemployment exposure" if spec==-1
replace spec_long="Low unemployment exposure" if spec==-2
replace spec_long="Full sample" if spec==19
replace spec_long="Republican" if spec==16
replace spec_long = "Democrat" if spec==13
replace spec_long="Rich" if spec==12
replace spec_long="Poor" if spec==11
replace spec_long="Old" if spec==8
replace spec_long="Mid" if spec==7
replace spec_long="Young" if spec==6
replace spec_long="Control" if spec==3
replace spec_long="Treatment" if spec==2



graph twoway (scatter spec coef  if spec==19, color(gray) msymbol(sh) ) (rcap lb ub spec if spec==19,  color(gray) horizontal) ///
			(scatter spec coef  if spec==16, color(cranberry) msymbol(X) ) (rcap lb ub spec if spec==16,  color(cranberry) horizontal) ///
			(scatter spec coef  if spec==15, color(ebblue) msymbol(D) ) (rcap lb ub spec if spec==15,  color(ebblue) horizontal) ///
			(scatter spec coef  if spec==12, color("17 119 51") msymbol(V) ) (rcap lb ub spec if spec==12,  color("17 119 51") horizontal) ///
			(scatter spec coef  if spec==11, color(orange) msymbol(O) ) (rcap lb ub spec if spec==11,  color(orange) horizontal) ///
			(scatter spec coef  if spec==8, color(purple) msymbol(a) ) (rcap lb ub spec if spec==8,  color(purple) horizontal) ///
			(scatter spec coef  if spec==7, color(pink) msymbol(S) ) (rcap lb ub spec if spec==7,  color(pink) horizontal) ///
			(scatter spec coef  if spec==6, color(black) msymbol(T) ) (rcap lb ub spec if spec==6,  color(black) horizontal) ///
			(scatter spec coef  if spec==3, color(brown) msymbol(th) ) (rcap lb ub spec if spec==3,  color(brown) horizontal) ///
			(scatter spec coef  if spec==2, color(mint) msymbol(oh) ) (rcap lb ub spec if spec==2,  color(mint) horizontal) , ///
			legend(off) ylabel(2 `" "Providing info on current" "inflation and unemployment" "' 3 `" "No info on current" "inflation and unemployment" "' 6 "18-29 years" 7 "30-49 years" 8 "50-69 years" 11 "Income < $40k" 12 "Income > $125k" 15 "Democrat" 16 "Republican" 19 "Full sample" 20 " ", noticks nogrid) yline(4 9 13 17) ytitle(" ") xlab(0(0.5)3) xline(1, lpattern(straight)) xsize(5) ysize(7)
	
	graph export $appendix_figures/figa19.png,  as(png) height(3500) width(2500) replace
