********************************************************************************
** This code generates Appendix Figure 21, which reports the coefficient of   **
** the treatment in a regression where the outcome is described in each row.  **
********************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

********************************************************************************

**************************************************************
** Run the regressions of treatment on the outcomes in rows **
**************************************************************

{
global demo_controls " women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies incomegroup_agg_2 incomegroup_agg_3 race_black race_asian race_hisp race_mixed policy_first marital_status_2 marital_status_3 marital_status_4 employment_group_2 employment_group_3 v"
matrix define R=J(20,5,.)
***first stage
reg dummy_first_stage treatment $demo_controls, r
matrix R[1,1]=e(b)[1,1]
matrix R[1,2]=r(table)[2,1]
matrix R[1,3]=R[1,1]- invnormal(0.975)*R[1,2]
matrix R[1,4]=R[1,1]+ invnormal(0.975)*R[1,2]
matrix R[1,5]=9

***tradeoff unemp
reg dummy_policy_tradeoff_unemp treatment $demo_controls, r
matrix R[2,1]=e(b)[1,1]
matrix R[2,2]=r(table)[2,1]
matrix R[2,3]=R[2,1]- invnormal(0.975)*R[2,2]
matrix R[2,4]=R[2,1]+ invnormal(0.975)*R[2,2]
matrix R[2,5]=4

***tradeoff debt
reg dummy_policy_tradeoff_debt treatment $demo_controls, r
matrix R[3,1]=e(b)[1,1]
matrix R[3,2]=r(table)[2,1]
matrix R[3,3]=R[3,1]- invnormal(0.975)*R[3,2]
matrix R[3,4]=R[3,1]+ invnormal(0.975)*R[3,2]
matrix R[3,5]=3

***tradeoff growth
reg dummy_policy_tradeoff_growth treatment $demo_controls, r
matrix R[4,1]=e(b)[1,1]
matrix R[4,2]=r(table)[2,1]
matrix R[4,3]=R[4,1]- invnormal(0.975)*R[4,2]
matrix R[4,4]=R[4,1]+ invnormal(0.975)*R[4,2]
matrix R[4,5]=2

***tradeoff spending
reg dummy_policy_tradeoff_spend treatment $demo_controls, r
matrix R[5,1]=e(b)[1,1]
matrix R[5,2]=r(table)[2,1]
matrix R[5,3]=R[5,1]- invnormal(0.975)*R[5,2]
matrix R[5,4]=R[5,1]+ invnormal(0.975)*R[5,2]
matrix R[5,5]=1

*** booms
reg dummy_policy_booms treatment $demo_controls, r
matrix R[6,1]=e(b)[1,1]
matrix R[6,2]=r(table)[2,1]
matrix R[6,3]=R[6,1]- invnormal(0.975)*R[6,2]
matrix R[6,4]=R[6,1]+ invnormal(0.975)*R[6,2]
matrix R[6,5]=11

***signal
reg dummy_policy_signal treatment $demo_controls, r
matrix R[7,1]=e(b)[1,1]
matrix R[7,2]=r(table)[2,1]
matrix R[7,3]=R[7,1]- invnormal(0.975)*R[7,2]
matrix R[7,4]=R[7,1]+ invnormal(0.975)*R[7,2]
matrix R[7,5]=10

***sideffect
reg dummy_policy_sideffects treatment $demo_controls, r
matrix R[8,1]=e(b)[1,1]
matrix R[8,2]=r(table)[2,1]
matrix R[8,3]=R[8,1]- invnormal(0.975)*R[8,2]
matrix R[8,4]=R[8,1]+ invnormal(0.975)*R[8,2]
matrix R[8,5]=8

preserve
clear
svmat R
rename R1 coef
rename R2 std_se
rename R3 lb
rename R4 ub
rename R5 spec

graph twoway (scatter spec coef  , color(gray) ) (rcap lb ub spec,  color(gray) horizontal) , ///
			legend(order(1) lab(1 "Full sample") pos(6) ) ylabel(0.75 " " 1 `" "Reduce spending" "'  2 `" "Reduce growth" "' 3 `" "Reduce debt" "' 4 `" "Reduce unemployment" "'  6  `" "{bf:To reduce inflation,}" "{bf:it is necessary to}" "' 8 `" "Policies to reduce unemployment" "may increase inflation" "' 9 `" "Inflation is a side effect" "of positive economic developments" "' 10 `" "Inflation is often a sign" "of a good economy" "' 11 `" "Inflation happens more" "often in booms" "' 11.25 " " , labsize(medsmall) noticks nogrid) yline(1.5 2.5 3.5 8.5 9.5 10.5, lcolor(gray%50) lwidth(vthin)) yline(6) ytitle(" ") xline(0, lpattern(straight)) xsize(7) ysize(5)
			
			graph export $appendix_figures/figa21_1.png,  as(png) height(2500) width(3500) replace

restore
}


****************************************************************************************
** Run the regressions of treatment on the outcomes in rows (political affiliation)   **
****************************************************************************************

{
global demo_controls " women agegroup_agg_2 agegroup_agg_3  college econ_studies incomegroup_agg_2 incomegroup_agg_3 race_black race_asian race_hisp race_mixed policy_first marital_status_2 marital_status_3 marital_status_4 employment_group_2 employment_group_3 v"
matrix define R=J(20,5,.)

***REPUBLICAN
***first stage
reg dummy_first_stage treatment $demo_controls if republican==1, r
matrix R[1,1]=e(b)[1,1]
matrix R[1,2]=r(table)[2,1]
matrix R[1,3]=R[1,1]- invnormal(0.975)*R[1,2]
matrix R[1,4]=R[1,1]+ invnormal(0.975)*R[1,2]
matrix R[1,5]=9.25

***tradeoff unemp
reg dummy_policy_tradeoff_unemp treatment $demo_controls if republican==1, r
matrix R[2,1]=e(b)[1,1]
matrix R[2,2]=r(table)[2,1]
matrix R[2,3]=R[2,1]- invnormal(0.975)*R[2,2]
matrix R[2,4]=R[2,1]+ invnormal(0.975)*R[2,2]
matrix R[2,5]=4.25

***tradeoff debt
reg dummy_policy_tradeoff_debt treatment $demo_controls if republican==1, r
matrix R[3,1]=e(b)[1,1]
matrix R[3,2]=r(table)[2,1]
matrix R[3,3]=R[3,1]- invnormal(0.975)*R[3,2]
matrix R[3,4]=R[3,1]+ invnormal(0.975)*R[3,2]
matrix R[3,5]=3.25

***tradeoff growth
reg dummy_policy_tradeoff_growth treatment $demo_controls if republican==1, r
matrix R[4,1]=e(b)[1,1]
matrix R[4,2]=r(table)[2,1]
matrix R[4,3]=R[4,1]- invnormal(0.975)*R[4,2]
matrix R[4,4]=R[4,1]+ invnormal(0.975)*R[4,2]
matrix R[4,5]=2.25

***tradeoff spending
reg dummy_policy_tradeoff_spend treatment $demo_controls if republican==1, r
matrix R[5,1]=e(b)[1,1]
matrix R[5,2]=r(table)[2,1]
matrix R[5,3]=R[5,1]- invnormal(0.975)*R[5,2]
matrix R[5,4]=R[5,1]+ invnormal(0.975)*R[5,2]
matrix R[5,5]=1.25

***booms
reg dummy_policy_booms treatment $demo_controls if republican==1, r
matrix R[6,1]=e(b)[1,1]
matrix R[6,2]=r(table)[2,1]
matrix R[6,3]=R[6,1]- invnormal(0.975)*R[6,2]
matrix R[6,4]=R[6,1]+ invnormal(0.975)*R[6,2]
matrix R[6,5]=11.25

***signal
reg dummy_policy_signal treatment $demo_controls if republican==1, r
matrix R[7,1]=e(b)[1,1]
matrix R[7,2]=r(table)[2,1]
matrix R[7,3]=R[7,1]- invnormal(0.975)*R[7,2]
matrix R[7,4]=R[7,1]+ invnormal(0.975)*R[7,2]
matrix R[7,5]=10.25

***sideffect
reg dummy_policy_sideffects treatment $demo_controls if republican==1, r
matrix R[8,1]=e(b)[1,1]
matrix R[8,2]=r(table)[2,1]
matrix R[8,3]=R[8,1]- invnormal(0.975)*R[8,2]
matrix R[8,4]=R[8,1]+ invnormal(0.975)*R[8,2]
matrix R[8,5]=8.25



***DEMOCRAT
***first stage
reg dummy_first_stage treatment $demo_controls if democrat==1, r
matrix R[11,1]=e(b)[1,1]
matrix R[11,2]=r(table)[2,1]
matrix R[11,3]=R[11,1]- invnormal(0.975)*R[11,2]
matrix R[11,4]=R[11,1]+ invnormal(0.975)*R[11,2]
matrix R[11,5]=8.75

***tradeoff unemp
reg dummy_policy_tradeoff_unemp treatment $demo_controls if democrat==1, r
matrix R[12,1]=e(b)[1,1]
matrix R[12,2]=r(table)[2,1]
matrix R[12,3]=R[12,1]- invnormal(0.975)*R[12,2]
matrix R[12,4]=R[12,1]+ invnormal(0.975)*R[12,2]
matrix R[12,5]=3.75

***tradeoff debt
reg dummy_policy_tradeoff_debt treatment $demo_controls if democrat==1, r
matrix R[13,1]=e(b)[1,1]
matrix R[13,2]=r(table)[2,1]
matrix R[13,3]=R[13,1]- invnormal(0.975)*R[13,2]
matrix R[13,4]=R[13,1]+ invnormal(0.975)*R[13,2]
matrix R[13,5]=2.75

***tradeoff growth
reg dummy_policy_tradeoff_growth treatment $demo_controls if democrat==1, r
matrix R[14,1]=e(b)[1,1]
matrix R[14,2]=r(table)[2,1]
matrix R[14,3]=R[14,1]- invnormal(0.975)*R[14,2]
matrix R[14,4]=R[14,1]+ invnormal(0.975)*R[14,2]
matrix R[14,5]=1.75

***tradeoff spending
reg dummy_policy_tradeoff_spend treatment $demo_controls if democrat==1, r
matrix R[15,1]=e(b)[1,1]
matrix R[15,2]=r(table)[2,1]
matrix R[15,3]=R[15,1]- invnormal(0.975)*R[15,2]
matrix R[15,4]=R[15,1]+ invnormal(0.975)*R[15,2]
matrix R[15,5]=0.75

***booms
reg dummy_policy_booms treatment $demo_controls if democrat==1, r
matrix R[16,1]=e(b)[1,1]
matrix R[16,2]=r(table)[2,1]
matrix R[16,3]=R[16,1]- invnormal(0.975)*R[16,2]
matrix R[16,4]=R[16,1]+ invnormal(0.975)*R[16,2]
matrix R[16,5]=10.75

***signal
reg dummy_policy_signal treatment $demo_controls if democrat==1, r
matrix R[17,1]=e(b)[1,1]
matrix R[17,2]=r(table)[2,1]
matrix R[17,3]=R[17,1]- invnormal(0.975)*R[17,2]
matrix R[17,4]=R[17,1]+ invnormal(0.975)*R[17,2]
matrix R[17,5]=9.75

***sideffect
reg dummy_policy_sideffects treatment $demo_controls if democrat==1, r
matrix R[18,1]=e(b)[1,1]
matrix R[18,2]=r(table)[2,1]
matrix R[18,3]=R[18,1]- invnormal(0.975)*R[18,2]
matrix R[18,4]=R[18,1]+ invnormal(0.975)*R[18,2]
matrix R[18,5]=7.75

preserve
clear
svmat R
rename R1 coef
rename R2 std_se
rename R3 lb
rename R4 ub
rename R5 spec
gen spec_long="rep" if spec == 11.25 | spec==10.25 | spec==9.25 | spec==8.25 | spec==4.25 | spec==3.25 | spec==2.25 | spec==1.25
replace spec_long="dem" if spec==10.75 | spec==9.75 | spec==8.75 | spec==7.75 | spec==3.75 | spec==2.75 | spec==1.75 | spec==0.75

graph twoway (scatter spec coef if spec_long=="rep" , color(cranberry) msymbol(X) ) (rcap lb ub spec if spec_long=="rep",  color(cranberry) horizontal) (scatter spec coef if spec_long=="dem" , color(ebblue) msymbol(D)) (rcap lb ub spec if spec_long=="dem",  color(ebblue) horizontal) , ///
			legend(order(1 3) lab(1 "Republican") lab(3 "Democrat") pos(6) col(2)) ylabel(1 `" "Reduce spending" "'  2 `" "Reduce growth" "' 3 `" "Reduce debt" "' 4 `" "Reduce unemployment" "'  6  `" "{bf:To reduce inflation,}" "{bf:it is necessary to}" "' 8 `" "Policies to reduce unemployment" "may increase inflation" "' 9 `" "Inflation is a side effect" "of positive economic developments" "'  10 `" "Inflation is often a sign" "of a good economy" "' 11 `" "Inflation happens more" "often in booms" "' , noticks nogrid labsize(medsmall)) yline(1.5 2.5 3.5 8.5 9.5 10.5, lcolor(gray%50) lwidth(vthin)) yline(6) ytitle(" ") xline(0, lpattern(straight)) xsize(7) ysize(5)
			
			graph export $appendix_figures/figa21_2.png,  as(png) height(2500) width(3500) replace

restore
}
