********************************************************************************
** This code generates Appendix Figure 22, which reports the coefficient of   **
** the treatment in a regression where the outcome is described in each row.  **
********************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

********************************************************************************

*********************************************************************************************
** Run the regressions of treatment on the outcomes in rows (policies to combat inflation) **
*********************************************************************************************
{
matrix define R=J(18,5,.)
	global demo_controls " women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies incomegroup_agg_2 incomegroup_agg_3 race_black race_asian race_hisp race_mixed policy_first marital_status_2 marital_status_3 marital_status_4 employment_group_2 employment_group_3 v"
***increase rate
reg dummy_policy_increaserate treatment $demo_controls, r
matrix R[1,1]=e(b)[1,1]
matrix R[1,2]=r(table)[2,1]
matrix R[1,3]=R[1,1]- invnormal(0.975)*R[1,2]
matrix R[1,4]=R[1,1]+ invnormal(0.975)*R[1,2]
matrix R[1,5]=17

***decrease rate
reg dummy_policy_decreaserate treatment $demo_controls, r
matrix R[2,1]=e(b)[1,1]
matrix R[2,2]=r(table)[2,1]
matrix R[2,3]=R[2,1]- invnormal(0.975)*R[2,2]
matrix R[2,4]=R[2,1]+ invnormal(0.975)*R[2,2]
matrix R[2,5]=16

***decrease money supply
reg dummy_policy_decreasemsupply treatment $demo_controls, r
matrix R[3,1]=e(b)[1,1]
matrix R[3,2]=r(table)[2,1]
matrix R[3,3]=R[3,1]- invnormal(0.975)*R[3,2]
matrix R[3,4]=R[3,1]+ invnormal(0.975)*R[3,2]
matrix R[3,5]=15

***announce rate increase
reg dummy_policy_announcement treatment $demo_controls, r
matrix R[4,1]=e(b)[1,1]
matrix R[4,2]=r(table)[2,1]
matrix R[4,3]=R[4,1]- invnormal(0.975)*R[4,2]
matrix R[4,4]=R[4,1]+ invnormal(0.975)*R[4,2]
matrix R[4,5]=14

***tax high income to reduce debt
reg dummy_policy_debtreduce_highinc treatment $demo_controls, r
matrix R[5,1]=e(b)[1,1]
matrix R[5,2]=r(table)[2,1]
matrix R[5,3]=R[5,1]- invnormal(0.975)*R[5,2]
matrix R[5,4]=R[5,1]+ invnormal(0.975)*R[5,2]
matrix R[5,5]=11

*** tax mid income to reduce debt
reg dummy_policy_debtreduce_midinc treatment $demo_controls, r
matrix R[6,1]=e(b)[1,1]
matrix R[6,2]=r(table)[2,1]
matrix R[6,3]=R[6,1]- invnormal(0.975)*R[6,2]
matrix R[6,4]=R[6,1]+ invnormal(0.975)*R[6,2]
matrix R[6,5]=10

*** decrease low income transfers to reduce debt
reg dummy_policy_debtreduce_lowinc treatment $demo_controls, r
matrix R[7,1]=e(b)[1,1]
matrix R[7,2]=r(table)[2,1]
matrix R[7,3]=R[7,1]- invnormal(0.975)*R[7,2]
matrix R[7,4]=R[7,1]+ invnormal(0.975)*R[7,2]
matrix R[7,5]=9

*** increase antitrust
reg dummy_policy_antitrust treatment $demo_controls, r
matrix R[8,1]=e(b)[1,1]
matrix R[8,2]=r(table)[2,1]
matrix R[8,3]=R[8,1]- invnormal(0.975)*R[8,2]
matrix R[8,4]=R[8,1]+ invnormal(0.975)*R[8,2]
matrix R[8,5]=6

***tax high income to fund low income transfers
reg dummy_policy_transfer_highinc treatment $demo_controls, r
matrix R[9,1]=e(b)[1,1]
matrix R[9,2]=r(table)[2,1]
matrix R[9,3]=R[9,1]- invnormal(0.975)*R[9,2]
matrix R[9,4]=R[9,1]+ invnormal(0.975)*R[9,2]
matrix R[9,5]=5

***increase corporate taxes
reg dummy_policy_corporatetaxes treatment $demo_controls, r
matrix R[10,1]=e(b)[1,1]
matrix R[10,2]=r(table)[2,1]
matrix R[10,3]=R[10,1]- invnormal(0.975)*R[10,2]
matrix R[10,4]=R[10,1]+ invnormal(0.975)*R[10,2]
matrix R[10,5]=4

*** price caps
reg dummy_policy_pricecaps treatment $demo_controls, r
matrix R[11,1]=e(b)[1,1]
matrix R[11,2]=r(table)[2,1]
matrix R[11,3]=R[11,1]- invnormal(0.975)*R[11,2]
matrix R[11,4]=R[11,1]+ invnormal(0.975)*R[11,2]
matrix R[11,5]=3

*** wage caps
reg dummy_policy_wagecaps treatment $demo_controls, r
matrix R[12,1]=e(b)[1,1]
matrix R[12,2]=r(table)[2,1]
matrix R[12,3]=R[12,1]- invnormal(0.975)*R[12,2]
matrix R[12,4]=R[12,1]+ invnormal(0.975)*R[12,2]
matrix R[12,5]=2

*** reduce imports
reg dummy_policy_imports treatment $demo_controls, r
matrix R[13,1]=e(b)[1,1]
matrix R[13,2]=r(table)[2,1]
matrix R[13,3]=R[13,1]- invnormal(0.975)*R[13,2]
matrix R[13,4]=R[13,1]+ invnormal(0.975)*R[13,2]
matrix R[13,5]=1

preserve
clear
svmat R
rename R1 coef
rename R2 std_se
rename R3 lb
rename R4 ub
rename R5 spec

graph twoway (scatter spec coef  , color(gray) ) (rcap lb ub spec,  color(gray) horizontal) , ///
			legend(order(1) lab(1 "Full sample") pos(6) ) ylabel(0.75 " " 1 `" "Restrict imports" "' 2 `" "Regulate wage growth" "' 3 `" "Freeze prices of essentials" "' 4 `" "Increase corporate taxes" "' 5 `" "Increase taxes on high" "income to fund transfers" "' 6 `" "Tighten antitrust regulation" "'  7.5 "{bf:Other policies}" 9 `" "Reducing spending on social programs"  "' 10 `" "Increasing taxes on" "high and middle income" "' 11 `" "Increasing taxes on high income" "' 12.5 `" "{bf:Reductions in government}" "{bf:debt financed by}" "' 14 `" "Announce future plans" "for interest rate"  "' 15 `" "Decrease money supply" "' 16 `" "Decrease interest rate" "' 17 "Increase interest rate" 18.5 "{bf:Monetary policy}"   , noticks nogrid) yline(7.5 12.5 , lwidth(vthin)) ytitle(" ") xline(0, lpattern(straight)) xsize(6) ysize(7)
			
			graph export $appendix_figures/figa22_1.png,  as(png) height(3500) width(3000) replace

restore
}

****************************************************************************************
** Run the regressions of treatment on the outcomes in rows (redistributive policies) **
****************************************************************************************
{
	global demo_controls " women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies incomegroup_agg_2 incomegroup_agg_3 race_black race_asian race_hisp race_mixed policy_first marital_status_2 marital_status_3 marital_status_4 employment_group_2 employment_group_3 v"
matrix define R=J(10,5,.)
***minimum wage
reg dummy_policy_redib_minwage treatment $demo_controls, r
matrix R[1,1]=e(b)[1,1]
matrix R[1,2]=r(table)[2,1]
matrix R[1,3]=R[1,1]- invnormal(0.975)*R[1,2]
matrix R[1,4]=R[1,1]+ invnormal(0.975)*R[1,2]
matrix R[1,5]=5

***vouchers low income
reg dummy_policy_redib_vouch_lowinc treatment $demo_controls, r
matrix R[2,1]=e(b)[1,1]
matrix R[2,2]=r(table)[2,1]
matrix R[2,3]=R[2,1]- invnormal(0.975)*R[2,2]
matrix R[2,4]=R[2,1]+ invnormal(0.975)*R[2,2]
matrix R[2,5]=4

***vouchers mid income
reg dummy_policy_redib_vouch_midinc treatment $demo_controls, r
matrix R[3,1]=e(b)[1,1]
matrix R[3,2]=r(table)[2,1]
matrix R[3,3]=R[3,1]- invnormal(0.975)*R[3,2]
matrix R[3,4]=R[3,1]+ invnormal(0.975)*R[3,2]
matrix R[3,5]=3

***food stamps
reg dummy_policy_redib_stamps treatment $demo_controls, r
matrix R[4,1]=e(b)[1,1]
matrix R[4,2]=r(table)[2,1]
matrix R[4,3]=R[4,1]- invnormal(0.975)*R[4,2]
matrix R[4,4]=R[4,1]+ invnormal(0.975)*R[4,2]
matrix R[4,5]=2

***low income transfers
reg dummy_policy_redib_lowinctransf treatment $demo_controls, r
matrix R[5,1]=e(b)[1,1]
matrix R[5,2]=r(table)[2,1]
matrix R[5,3]=R[5,1]- invnormal(0.975)*R[5,2]
matrix R[5,4]=R[5,1]+ invnormal(0.975)*R[5,2]
matrix R[5,5]=1


preserve
clear
svmat R
rename R1 coef
rename R2 std_se
rename R3 lb
rename R4 ub
rename R5 spec

graph twoway (scatter spec coef  , color(gray) ) (rcap lb ub spec,  color(gray) horizontal) , ///
			legend(order(1) lab(1 "Full sample") pos(6) ) ylabel(0.75 " " 1 `" "Increase low income transfers" "' 2 `" "Increase food stamps" "' 3 `" "Increase vouchers for mid income" "' 4 `" "Increase vouchers for low income" "' 5  `" "Increase minimum wage" "' 5.25 " "  , noticks nogrid) yline(1.5 2.5 3.5 4.5 , lwidth(vthin)) ytitle(" ") xline(0, lpattern(straight)) xsize(6) ysize(7)
			
			graph export $appendix_figures/figa22_2.png,  as(png) height(3500) width(3000) replace

restore
}
