*********************************************************************************
** This code generates Appendix Table 17, which reports the heterogeneities    **
** from the conjoint experiment. 											   **
*********************************************************************************


clear all

use "$data/inflation_understanding_conjoint.dta", clear

*********************************************************************************

***********************************************************
** Prepare the globals and the labels for the regression **
***********************************************************
label var diff_u "\$\Delta\$ u"
label var diff_pi "\$\Delta\$ \$\pi\$"

drop diff_u_* diff_pi_*

global demo_controls " experienced_unemployment women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies incomegroup_agg_2 incomegroup_agg_3 race_black race_asian race_hisp race_mixed policy_first marital_status_2 marital_status_3 marital_status_4 employment_group_2 employment_group_3 experienced_inflation  conjoint_info"
foreach var in $demo_controls{
	gen diff_u_`var' = diff_u * `var'
	gen diff_pi_`var' = diff_pi * `var'
}

global interactions "diff_u* diff_pi* "
label var diff_u_women "\$\Delta\$ u \$\times\$ Female"
label var diff_pi_women "\$\Delta\$ \$\pi\$ \$\times\$ Female"
label var diff_u_agegroup_agg_2 "\$\Delta\$ u \$\times\$ 30-49 years old"
label var diff_pi_agegroup_agg_2 "\$\Delta\$ \$\pi\$ \$\times\$ 30-49 years old"
label var diff_u_agegroup_agg_3 "\$\Delta\$ u \$\times\$ 50-69 years old"
label var diff_pi_agegroup_agg_3 "\$\Delta\$ \$\pi\$ \$\times\$ 50-69 years old"
label var diff_u_independent "\$\Delta\$ u \$\times\$ Independent"
label var diff_pi_independent "\$\Delta\$ \$\pi\$ \$\times\$ Independent"
label var diff_u_republican "\$\Delta\$ u \$\times\$ Republican"
label var diff_pi_republican "\$\Delta\$ \$\pi\$ \$\times\$ Republican"
label var diff_u_college "\$\Delta\$ u \$\times\$ College"
label var diff_pi_college "\$\Delta\$ \$\pi\$ \$\times\$ College"
label var diff_u_incomegroup_agg_2 "\$\Delta\$ u \$\times\$ Income between 40k and 125k"
label var diff_pi_incomegroup_agg_2 "\$\Delta\$ \$\pi\$ \$\times\$ Income between 40k and 125k"
label var diff_u_incomegroup_agg_3 "\$\Delta\$ u \$\times\$ Income more than 125k"
label var diff_pi_incomegroup_agg_3 "\$\Delta\$ \$\pi\$ \$\times\$ Income more than 125k"
label var diff_u_employment_group_2 "\$\Delta\$ u \$\times\$ Unemployed"
label var diff_pi_employment_group_2 "\$\Delta\$ \$\pi\$ \$\times\$ Unemployed"
label var diff_u_employment_group_3 "\$\Delta\$ u \$\times\$ Out of labor force"
label var diff_pi_employment_group_3 "\$\Delta\$ \$\pi\$ \$\times\$ Out of labor force"
label var diff_u_experienced_inflation "\$\Delta\$ u \$\times\$ Experienced inflation"
label var diff_pi_experienced_inflation "\$\Delta\$ \$\pi\$ \$\times\$ Experienced inflation"
label var diff_u_experienced_unemployment "\$\Delta\$ u \$\times\$ Exposure to unemployment"
label var diff_pi_experienced_unemployment "\$\Delta\$ \$\pi\$ \$\times\$ Exposure to unemployment"
label var diff_u_conjoint_info "\$\Delta\$ u \$\times\$ Exact values treatment"
label var diff_pi_conjoint_info "\$\Delta\$ \$\pi\$ \$\times\$ Exact values treatment"
destring inflation_first, replace
replace inflation_first=0 if unemployment_first==1
drop _merge

global interactions "diff_u diff_pi diff_u_agegroup_agg_2 diff_pi_agegroup_agg_2 diff_u_agegroup_agg_3 diff_pi_agegroup_agg_3 diff_u_independent diff_pi_independent  diff_u_republican diff_pi_republican  diff_u_incomegroup_agg_2 diff_pi_incomegroup_agg_2 diff_u_incomegroup_agg_3 diff_pi_incomegroup_agg_3 diff_u_experienced_unemployment diff_pi_experienced_unemployment diff_u_conjoint_info diff_pi_conjoint_info"

*************************
** Generates the table **
*************************

{
global table_name "$appendix_tables/taba17"

* Table end
file open  holder using $appendix_tables/temp_end.tex, write replace text
file write holder " \end{tabular}" _n
file close holder

* Table start
file open holder using $table_name.tex, write replace text
file write holder "\begin{tabular}{lcc} " _n
file write holder "&\multicolumn{2}{c}{\textbf{Probability of being chosen}} \\" _n
file write holder "& (1) & (2)  \\ \hline" _n
file close holder

* Regressions
eststo:  reghdfe chosen $interactions unemployment_first, noabsorb cluster(*Id)
local rsq_1: display %5.3f `e(r2_a)'

qui sum chosen if e(sample) 
local depmean_1: display %5.3f `r(mean)'
local obs_1: display %5.0f `r(N)'
local std_1: display %5.3f `r(sd)'

eststo:  reghdfe chosen $interactions, absorb(*Id) cluster(*Id)
local rsq_2: display %5.3f `e(r2_a)'

qui sum chosen if e(sample) 
local depmean_2: display %5.3f `r(mean)'
local obs_2: display %5.0f `r(N)'
local std_2: display %5.3f `r(sd)'

esttab using $appendix_tables/panel_before.tex, replace fragment booktabs noconst nobase  label cells(b(fmt(3) star) se(par fmt(3))) collabels(none) keep($interactions) /// 
starlevels(* .1 ** .05 *** .01) se nonumbers nomtitles nolines nocon noobs compress

file open holder using $appendix_tables/panel_means_before.tex, write replace text
file write holder "\hline " _n 
file write holder "Individual FE  &   & \checkmark \\" _n       
file write holder "Observations & `obs_1' & `obs_2' \\" _n     
file write holder "Adj. R$^{2}$ & `rsq_1' & `rsq_2'  \\" _n 
file write holder "$\mathbb{E}$(Dependent variable)& `depmean_1' & `depmean_2'  \\" _n   
file write holder "Dependent variable std. dev. & `std_1' & `std_2'  \\" _n
file write holder "\hline " _n 
file write holder " & & \\" _n
file close holder

eststo clear

appendfile $appendix_tables/panel_before.tex $table_name.tex
appendfile $appendix_tables/panel_means_before.tex $table_name.tex
appendfile $appendix_tables/temp_end.tex $table_name.tex

erase $appendix_tables/panel_before.tex
erase $appendix_tables/panel_means_before.tex
erase $appendix_tables/temp_end.tex
}
