************************************************************************************
** This code imports raw data from different final waves (2, 3, 4, 5), adds state **
** names corresponding to ZIP codes, harmonizes the variables of the conjoint     **
** experiment, and merges the waves into a single, consistent cleaned dataset.    **
************************************************************************************



**** Import raw data from wave 5: this contains also raw data from waves 3 and 4, but this step is necessary to ensure consistency of embedded data.
{
import excel "$data/inflation_understanding_5.xlsx",  firstrow clear
drop if  DistributionChannel=="preview"

gen startdate_format = subinstr(StartDate, " ","",.)
gen month = substr(startdate_format,1,1)
gen day = substr(startdate_format,3,2)

*identify and temporary remove data from previous waves
gen v=5
replace v=3 if month=="3"
replace v=4 if (day != "25" & day != "26" & day != "27" & month=="3") | (day =="1/" & month=="4")
keep if v==5

destring Durationinseconds, replace force
gen Durationinminutes=Durationinseconds/60 
label var Durationinminutes "Minutes spent on survey"
destring ZIP_code, gen(zip_code) force
joinby zip_code using "$data/zip_statename_toptax.dta", unmatched(master)
rename _merge merge
drop TopTaxRate
foreach var of varlist t_* {
	destring `var', replace force
	}
	

gen date_start = clock(StartDate, "MDY hm")
format date_start %tc
gen dailydate = dofc(date_start)
format dailydate %td
* harmonize conjoint values
destring choice*, replace
rename choice1_inflation1 pi1
rename choice1_inflation2 pi2
rename choice2_inflation1 pi3
rename choice2_inflation2 pi4
rename choice3_inflation1 pi5
rename choice3_inflation2 pi6
rename choice4_inflation1 pi7
rename choice4_inflation2 pi8
rename choice5_inflation1 pi9
rename choice5_inflation2 pi10

rename choice1_unemployment1 u1
rename choice1_unemployment2 u2
rename choice2_unemployment1 u3
rename choice2_unemployment2 u4
rename choice3_unemployment1 u5
rename choice3_unemployment2 u6
rename choice4_unemployment1 u7
rename choice4_unemployment2 u8
rename choice5_unemployment1 u9
rename choice5_unemployment2 u10


gen conjoint_1_pifirst = _conjoint_pifirst
gen conjoint_1_ufirst = _conjoint_ufirst
drop _conjoint_pifirst _conjoint_ufirst


gen conjoint_2_pifirst = CP
gen conjoint_2_ufirst = CU
drop CP CU

gen conjoint_3_pifirst = CQ
gen conjoint_3_ufirst = CV
drop CQ CV

gen conjoint_4_pifirst = CR
gen conjoint_4_ufirst = CW
drop CR CW

gen conjoint_5_pifirst = CS
gen conjoint_5_ufirst = CX
drop CS CX


*save answers from wave 5 in a temporary file 
tempfile tmp5
save `tmp5'
}



****Import raw data from wave 4: this contains also data from wave 3, but this step is necessary to ensure consistency of embedded data
{
import excel "$data/inflation_understanding_4.xlsx",  firstrow clear
drop if  DistributionChannel=="preview"

gen startdate_format = subinstr(StartDate, " ","",.)
gen month = substr(startdate_format,1,1)
gen day = substr(startdate_format,3,2)

*identify and temporary remove data from previous waves
gen v=3
replace v=4 if month!="3"
replace v=4 if day != "25" & day != "26" & day != "27" & month=="3"
keep if v==4

destring Durationinseconds, replace force
gen Durationinminutes=Durationinseconds/60 
label var Durationinminutes "Minutes spent on survey"
destring ZIP_code, gen(zip_code) force
joinby zip_code using "$data/zip_statename_toptax.dta", unmatched(master)
rename _merge merge
drop TopTaxRate
foreach var of varlist t_* {
	destring `var', replace force
	}
	

gen date_start = clock(StartDate, "MDY hm")
format date_start %tc
gen dailydate = dofc(date_start)
format dailydate %td

*harmonize variables of conjoint experiment values
destring choice*, replace
rename choice1_inflation1 pi1
rename choice1_inflation2 pi2
rename choice2_inflation1 pi3
rename choice2_inflation2 pi4
rename choice3_inflation1 pi5
rename choice3_inflation2 pi6
rename choice4_inflation1 pi7
rename choice4_inflation2 pi8
rename choice5_inflation1 pi9
rename choice5_inflation2 pi10

rename choice1_unemployment1 u1
rename choice1_unemployment2 u2
rename choice2_unemployment1 u3
rename choice2_unemployment2 u4
rename choice3_unemployment1 u5
rename choice3_unemployment2 u6
rename choice4_unemployment1 u7
rename choice4_unemployment2 u8
rename choice5_unemployment1 u9
rename choice5_unemployment2 u10


gen conjoint_1_pifirst = _conjoint_pifirst
gen conjoint_1_ufirst = _conjoint_ufirst
drop _conjoint_pifirst _conjoint_ufirst


gen conjoint_2_pifirst = CP
gen conjoint_2_ufirst = CU
drop CP CU

gen conjoint_3_pifirst = CQ
gen conjoint_3_ufirst = CV
drop CQ CV

gen conjoint_4_pifirst = CR
gen conjoint_4_ufirst = CW
drop CR CW

gen conjoint_5_pifirst = CS
gen conjoint_5_ufirst = CX
drop CS CX


*save answers from wave 4 in a temporary file 
tempfile tmp4
save `tmp4'
}


****Import and clean raw data from wave 3 
{
import excel "$data/inflation_understanding_3.xlsx",  firstrow clear
drop if  DistributionChannel=="preview"

*set identifier for wave 3
gen startdate_format = subinstr(StartDate, " ","",.)
gen month = substr(startdate_format,1,1)
gen day = substr(startdate_format,3,2)
gen v=3

destring Durationinseconds, replace force
gen Durationinminutes=Durationinseconds/60 
label var Durationinminutes "Minutes spent on survey"
destring ZIP_code, gen(zip_code) force
joinby zip_code using "$data/zip_statename_toptax.dta", unmatched(master)
rename _merge merge
drop TopTaxRate
foreach var of varlist t_* {
	destring `var', replace force
	}
	

gen date_start = clock(StartDate, "MDY hm")
format date_start %tc
gen dailydate = dofc(date_start)
format dailydate %td


*harmonize variables of conjoint experiment values
destring choice*, replace
rename choice1_inflation1 pi1
rename choice1_inflation2 pi2
rename choice2_inflation1 pi3
rename choice2_inflation2 pi4
rename choice3_inflation1 pi5
rename choice3_inflation2 pi6
rename choice4_inflation1 pi7
rename choice4_inflation2 pi8
rename choice5_inflation1 pi9
rename choice5_inflation2 pi10

rename choice1_unemployment1 u1
rename choice1_unemployment2 u2
rename choice2_unemployment1 u3
rename choice2_unemployment2 u4
rename choice3_unemployment1 u5
rename choice3_unemployment2 u6
rename choice4_unemployment1 u7
rename choice4_unemployment2 u8
rename choice5_unemployment1 u9
rename choice5_unemployment2 u10


gen conjoint_1_pifirst = _conjoint_pifirst
gen conjoint_1_ufirst = _conjoint_ufirst
drop _conjoint_pifirst _conjoint_ufirst


gen conjoint_2_pifirst = CP
gen conjoint_2_ufirst = CU
drop CP CU

gen conjoint_3_pifirst = CQ
gen conjoint_3_ufirst = CV
drop CQ CV

gen conjoint_4_pifirst = CR
gen conjoint_4_ufirst = CW
drop CR CW

gen conjoint_5_pifirst = CS
gen conjoint_5_ufirst = CX
drop CS CX


*save answers from wave 3 in a temporary file
tempfile tmp
save `tmp'
}




****Import raw data from wave 2, then append data from waves 3, 4 and 5
{
import excel "$data/inflation_understanding_2.xlsx",  firstrow clear
drop if  DistributionChannel=="preview"

destring Durationinseconds, replace force
gen Durationinminutes=Durationinseconds/60 
label var Durationinminutes "Minutes spent on survey"
destring ZIP_code, gen(zip_code) force
joinby zip_code using "$data/zip_statename_toptax.dta", unmatched(master)
rename _merge merge
drop TopTaxRate
foreach var of varlist t_* {
	destring `var', replace force
	}
	

gen date_start = clock(StartDate, "MDY hm")
format date_start %tc
gen dailydate = dofc(date_start)
format dailydate %td


****harmonize variables of conjoint experiment values
destring choice*, replace
rename choice1_inflation1 pi1
rename choice1_inflation2 pi2
rename choice2_inflation1 pi3
rename choice2_inflation2 pi4
rename choice3_inflation1 pi5
rename choice3_inflation2 pi6
rename choice4_inflation1 pi7
rename choice4_inflation2 pi8
rename choice5_inflation1 pi9
rename choice5_inflation2 pi10

rename choice1_unemployment1 u1
rename choice1_unemployment2 u2
rename choice2_unemployment1 u3
rename choice2_unemployment2 u4
rename choice3_unemployment1 u5
rename choice3_unemployment2 u6
rename choice4_unemployment1 u7
rename choice4_unemployment2 u8
rename choice5_unemployment1 u9
rename choice5_unemployment2 u10


gen conjoint_1_pifirst = _conjoint_pifirst
gen conjoint_1_ufirst = _conjoint_ufirst
drop _conjoint_pifirst _conjoint_ufirst


gen conjoint_2_pifirst = CP
gen conjoint_2_ufirst = CU
drop CP CU

gen conjoint_3_pifirst = CQ
gen conjoint_3_ufirst = CV
drop CQ CV

gen conjoint_4_pifirst = CR
gen conjoint_4_ufirst = CW
drop CR CW

gen conjoint_5_pifirst = CS
gen conjoint_5_ufirst = CX
drop CS CX

*set identifier for wave 2
gen v=2


*append cleaned data from wave 2
append using `tmp'

*append data from wave 4
append using `tmp4'

*append data from wave 5
append using `tmp5'

}
*******************************************
*********** Save merged database **********
*******************************************

compress
save "$data/inflation_understanding_screened_attrition.dta", replace
