***************************************************************************
** This code destrings and labels variables and their values, then saves **
** the newly labeled dataset. The questions are organized into the same  **
** sections as in the survey                                             **
***************************************************************************
clear all

use "$data/inflation_understanding_cleaned_attrition.dta", clear

* Drop the first row which contains the text of questions
gen index = _n
drop if index==1
drop index


** Define common labels **
label define yes_no 1 "Yes" 2 "No" 
label define no_yes 1 "No" 2 "Yes" 


*************************************************
** Pre-screening background questions (QUOTAS) ** 
*************************************************
{
*gender
label define gender 1 "Male" 2 "Female" 3 "Other"
destring  gender, replace force
label var 	gender "Gender"
label values gender gender

*age
destring	age, replace

*age_group: Qualtrics and respondents
rename age_group age_group_q
label var age_group_q "Age group qualtrics"

gen 			agegroup="." 
replace 		agegroup="18-29" if(age>17 & age<30)
replace 		agegroup="30-39" if(age>29 & age<40)
replace 		agegroup="40-49" if(age>39 & age<50)
replace 		agegroup="50-59" if(age>49 & age<60)
replace 		agegroup="60-69" if(age>59 & age<70)
label define 	agegroup 1 "18-29" 2 "30-39" 3 "40-49" 4 "50-59" 5 "60-69"
encode			agegroup, gen(age_group) label(agegroup)
drop 			agegroup

*live in the US
destring live_in_US, gen(life_us) force
label values life_us no_yes
label var life_us "Live in the US"

*race
label define race 1 "European American/White" 2 "African American/Black" 3 "Hispanic/Latino" 4 "Asian/Asian American" 5 "Mixed race" 6 "Other (please specify)"
destring race, replace
label values race race
label var race "Race"

*income
rename income_group income_group_q
label var income_group_q "Qualtrics income group"

gen incomegroup="."
replace incomegroup="$0-$19999" if(income_bracket=="1"| income_bracket== "2"|income_bracket=="3")
replace incomegroup="$20000-$39999"	if(income_bracket=="4"  | income_bracket== "5")
replace incomegroup="$40000-$69999" 	if(income_bracket=="6"  | income_bracket== "7")
replace incomegroup="$70000-$99999" 	if(income_bracket=="8"  | income_bracket== "9")
replace incomegroup = "$100000-$124999" if (income_bracket=="10"  | income_bracket== "11")
replace incomegroup="$125000+" 		if(income_bracket=="12"| income_bracket== "13"|income_bracket=="14")

label define incomegroup 1 "$0-$19999" 2 "$20000-$39999" 3 "$40000-$69999" 4 "$70000-$99999" 5 "$100000-$124999" 6 "$125000+"
encode incomegroup, gen(income_group) label(incomegroup)
drop incomegroup
label var income_group "Income group"

*following news
destring news_1, gen(news_social_media)
label values news_social_media no_yes
label var news_social_media "Social media"
destring news_2, gen(news_cnn)
label values news_cnn no_yes
label var news_cnn "CNN"
destring news_3, gen(news_msnbc)
label values news_msnbc no_yes
label var news_msnbc "MSNBC"
destring news_4, gen(news_fox)
label values news_fox no_yes
label var news_fox "Fox News"
destring news_5, gen(news_network)
label values news_network no_yes
label var news_network "TV networks"
destring news_6, gen(news_localtv)
label values news_localtv no_yes
label var news_localtv "Local TV"
destring news_7, gen(news_npr)
label values news_npr no_yes
label var news_npr "NPR"
destring news_8, gen(news_amtalk)
label values news_amtalk no_yes
label var news_amtalk "Radio"
destring news_9, gen(news_nyt)
label values news_nyt no_yes
label var news_nyt "NYT"
destring news_10, gen(news_wsj)
label values news_wsj no_yes
label var news_wsj "WSJ"
destring news_11, gen(news_localpapers)
label values news_localpapers no_yes
label var news_localpapers "Local newspapers"
destring news_12, gen(news_other)
label values news_other no_yes

global sources "news_cnn news_fox news_social_media news_msnbc  news_network news_localtv news_npr news_amtalk news_nyt news_wsj news_localpapers "

foreach var of varlist $sources{
	replace `var'=`var'-1
}

*trusting news
label define trust_news 1 "Completely trust" 2 "Somewhat trust" 3 "Neither trust nor distrust" 4 "Somewhat distrust" 5 "Completely distrust"
destring news_trust_1, gen(news_trust_social_media)
label values news_trust_social_media trust_news
destring news_trust_2, gen(news_trust_cnn)
label values news_trust_cnn trust_news
destring news_trust_3, gen(news_trust_msnbc)
label values news_trust_msnbc trust_news
destring news_trust_4, gen(news_trust_fox)
label values news_trust_fox trust_news
destring news_trust_5, gen(news_trust_network)
label values news_trust_network trust_news
destring news_trust_6, gen(news_trust_localtv)
label values news_trust_localtv trust_news
destring news_trust_7, gen(news_trust_npr)
label values news_trust_npr trust_news
destring news_trust_8, gen(news_trust_amtalk)
label values news_trust_amtalk trust_news
destring news_trust_9, gen(news_trust_nyt)
label values news_trust_nyt trust_news
destring news_trust_10, gen(news_trust_wsj)
label values news_trust_wsj trust_news
destring news_trust_11, gen(news_trust_localpapers)
label values news_trust_localpapers trust_news
destring news_trust_12, gen(news_trust_other)
label values news_trust_other trust_news

}


******************
** Demographics **
******************
{
*born_us
destring born_us, replace
label values born_us no_yes
label var born_us "Born in the US"

* Number of children
label define nb_child 0 "I do not have children" 1 "1" 2 "2" 3 "3" 4 "4" 5 "5 or more"
destring children, gen(nb_child) 
label values nb_child nb_child
replace nb_child = nb_child -1
label var nb_child "N. of children"

* Highest level of education
#delimit ;
label define education_level 1 "Primary education or less" 2 "Some High School"
	3 "High School degree/ GED" 4 "Some College" 5 "2-year College Degree"
	6 "4-year College Degree" 7 "Master's Degree" 8 "Doctoral Degree"
	9 "Professional Degree (JD, MD, MBA)" ; 
#delimit cr
destring educ, gen(education_level)
label values education_level education_level
label var education_level "Education level"

*Econ studies
destring econ, gen(econ_studies)
label values econ_studies no_yes

*Years in which week of unemployment
rename Q408 years_unemployment
label var years_unemployment "Years in which at least a week unemployed"

* Current employment status
#delimit ; 
label define employment_status 1 "Full-time employee" 2 "Part-time employee"
	3 "Self-employed or small business owner" 4 "Unemployed and looking for work"
	5 "Student" 6 "Not currently working and not looking for work" ;
#delimit cr
destring employment_status, replace
label values employment_status employment_status
label var employment_status "Employment status"
	

* Main occupation 
destring occupation, replace
label define occupation 1 "Managers" 2 "Professionals" 3 "Services" 4 "Sales" 5 "Office and Administration" 6 "Agriculture" 7 "Construction" 8 "Technicians" 9 "Production occupations" 10 "Transportation" 11 "Armed forces" 12 "Other"
label values occupation occupation
label var occupation "Main occupation"

*industrial sector	TO FIX
destring sector, replace
	
*gig_economy
destring gig_econ, gen(gig_economy)
label values gig_economy no_yes
label var gig_economy "Gig economy"


* marital status
label define marital_status 1 "Single" 2 "Married" 3 "Legally separated or divorced" 4 "Widowed"
destring marital_status, replace
label values marital_status marital_status
label var marital_status "Marital status"


*spouse's emp status
destring spouse_empl, gen(spouse_emp_status)
label values spouse_emp_status employment_status
label var spouse_emp_status "Spouse's employment status"

*TANF 2023
destring benefits_1, gen(tanf)
label values tanf yes_no
label var tanf "Cash assistance"

*EITC 2023
destring benefits_2, gen(eitc)
label values eitc yes_no
label var eitc "EITC"

*Unemployment insurance 2023
destring benefits_3, gen(u_insurance)
label values u_insurance yes_no
label var u_insurance "Unemployment insurance"

*medical assistance
destring medicaid, gen(med_assistance)
label values med_assistance yes_no
label var med_assistance "Medical assistance"

*food assistance
destring food_stamps, gen(food_assistance)
label values food_assistance yes_no
label var food_assistance "Food assistance"

*income comparison 2023 vs 2022
label define less_more 1 "It will be a lot less" 2 "It will be a bit less" 3 "It will be approximately" 4 "It will be a bit more" 5 "It will be a lot more"
destring future_income, gen(exp_income_comp)
label values exp_income_comp less_more
label var exp_income_comp "Exp Income comparison"

* Economic policy matters: liberal/conservative spectrum
label define economic_ideology 1 "Very liberal" 2 "Liberal" 3 "Moderate" 4 "Conservative" 5 "Very conservative"
destring political_views, gen(econ_ideology) 
label values econ_ideology economic_ideology
label var econ_ideology "Economic ideology"


* Political affiliation
label define political_party 1 "Republican" 2 "Democrat" 3 "Independent" 4 "Other" 5 "Non-Affiliated"
destring political_aff, gen(political_party) 
label values political_party political_party
label var political_party "Political party"


* Vote in 2020 presidential election?
destring vote, gen(vote_2020)
label values vote_2020 no_yes
label var vote_2020 "Vote 2020"

* 2020 preferred candidate (whether they voted or not)
label define candidate 1 "Joe Biden" 2 "Donald Trump" 3 "Howie Hawkins" 4 "Jo Jorgensen" 5 "Other"
gen candidate2020 = vote_candidate
replace candidate2020 = vote_candidate_nov if missing(vote_candidate)
destring candidate2020, gen(candidate_2020)
label values candidate_2020 candidate
label var candidate_2020 "Candidate"
}



**********************************************
** Economic Information about the household **
**********************************************
{
destring ec_inf_1, gen(own_vehicle)
label values own_vehicle yes_no

label define motor_vehicle_freq 1 "Daily" 2 "On a weekly basis, but not all days" 3 "On a monthly basis, but not all weeks" 4 "Less than one per month"
destring ec_inf_2, gen(motor_vehicle_freq_en)
label values motor_vehicle_freq_en motor_vehicle_freq

label define own_or_rent 1 "Own" 2 "Rent" 3 "No primary residence"
destring ec_inf_3, gen(own_or_rent)
label values own_or_rent own_or_rent

label define rent_value 1 "0-399" 2 "400-499" 3 "500-649" 4 "650-799" 5 "800-949" 6 "950-1,099" 7 "1,100-1,299" 8 "1,300-1,499" 9 "1,500-2,499" 10 "2,500+"
destring ec_inf_4, gen(rent_value)
label values rent_value rent_value

label define house_value 1 "0-49,999" 2 "50,000-99,999" 3 "100,000-149,999" 4 "150,000-199,999" 5 "200,000-249,999" 6 "250,000-299,999" 7 "300,000-349,999" 8 "350,000-449,999" 9 "450,000-649,999" 10 "650,000+"
destring ec_inf_5, gen(house_value)
label values house_value house_value

destring ec_inf_6, gen(mortgage)
label values mortgage yes_no

label define mortgage_value 1 "0-24,999" 2 "25,000-49,999" 3 "50,000-74,999" 4 "75,000-99,999" 5 "100,000-124,999" 6 "125,000-149,999" 7 "150,000-199,999" 8 "200,000-249,999" 9 "250,000-349,999" 10 "350,000+"
destring ec_inf_7, gen(mortgage_value)
label values mortgage_value mortgage_value

destring ec_inf_8, gen(checkings)
label values checkings yes_no

label define checkings_value 1 "0-199" 2 "200-699" 3 "700-1,299" 4 "1,300-1,999" 5 "2,000-2,999" 6 "3,000-4,999" 7 "5,000-8,999" 8 "9,000-19,999" 9 "20,000-39,999" 10 "40,000+"
destring ec_inf_9, gen(checkings_value)
label values checkings_value checkings_value

destring ec_inf_10, gen(short_save)
label values short_save yes_no

label define short_save_value 1 "0-999" 2 "1,000-1,999" 3 "2,000-4,999" 4 "5,000-9,999" 5 "10,000-14,999" 6 "15,000-29,999" 7 "30,000-49,999" 8 "50,000-99,999" 9 "100,000-149,999" 10 "150,000+"
destring ec_inf_11, gen(short_save_value)
label values short_save_value short_save_value

destring ec_inf_12, gen(mutual_etf)
label values mutual_etf yes_no

label define mutual_etf_value 1 "0-9,999" 2 "10,000-24,999" 3 "25,000-49,999" 4 "50,000-74,999" 5 "75,000-99,999" 6 "100,000-199,999" 7 "200,000-399,999" 8 "400,000-699,999" 9 "700,000-1,699,999" 10 "1,700,000+"
destring ec_inf_13, gen(mutual_etf_value)
label values mutual_etf_value mutual_etf_value
}


*******************************************************
** Perceived and expected inflation and unemployment **
*******************************************************
{
* Variables recording numeric answers to quantitative questions are destringed and aggregated in the code file "replication_package\code\appendix\tables\taba26\1.1inattentive_creation.do"

destring perc_pi_qual, gen(perceived_inflation)
label define perceived_inflation 1 "Inflation" 2 "Deflation"
label values perceived_inflation perceived_inflation


destring exp_pi_qual, gen(expected_inflation)
label define expected_inflation 1 "Inflation" 2 "Deflation"
label values expected_inflation expected_inflation

}


*********************************************************************
** Conjoint Experiment: Preferences for inflation and unemployment **
*********************************************************************
{
destring u*, replace
destring pi*, replace

foreach x in 1 2 3 4 5 {
	destring conjoint_`x'_pifirst, replace
	destring conjoint_`x'_ufirst, replace
	gen conjoint_`x' = conjoint_`x'_pifirst
	replace conjoint_`x' = conjoint_`x'_ufirst if conjoint_`x'==.
		}

destring conjoint_info conjoint_noinfo, replace
replace conjoint_info=0 if conjoint_noinfo==1

}



*****************************************************************
** Conditional correlations between inflation and unemployment **
*****************************************************************
{
label define decrease_increase 1 "Decrease a lot" 2 "Decrease" 3 "Stay the same" 4 "Increase" 5 "Increase a lot"

destring perc_corr_1_1, gen(corr_interest_pi)
label values corr_interest_pi decrease_increase
label var corr_interest_pi "Correlation increase rate and inflation"

destring perc_corr_1_2, gen(corr_interest_u)
label values corr_interest_u decrease_increase
label var corr_interest_u "Correlation increase rate and unemployment"

destring perc_corr_2_1, gen(corr_lowincomesupport_pi)
label values corr_lowincomesupport_pi decrease_increase
label var corr_lowincomesupport_pi "Correlation low income support and inflation"

destring perc_corr_2_2, gen(corr_lowincomesupport_u)
label values corr_lowincomesupport_u decrease_increase
label var corr_lowincomesupport_u "Correlation low income support and unemployment"

destring perc_corr_3_1, gen(corr_oil_pi)
label values corr_oil_pi decrease_increase
label var corr_oil_pi "Correlation oil prices and inflation"

destring perc_corr_3_2, gen(corr_oil_u)
label values corr_oil_u decrease_increase
label var corr_oil_u "Correlation oil prices and unemployment"

destring perc_corr_4_1, gen(corr_tech_pi)
label values corr_tech_pi decrease_increase
label var corr_tech_pi "Correlation technological improvement and inflation"

destring perc_corr_4_2, gen(corr_tech_u)
label values corr_tech_u decrease_increase
label var corr_tech_u "Correlation technological improvement and unemployment"

destring perc_corr_5_1, gen(corr_wage_pi)
label values corr_wage_pi decrease_increase
label var corr_wage_pi "Correlation wage increases and inflation"

destring perc_corr_5_2, gen(corr_wage_u)
label values corr_wage_u decrease_increase
label var corr_wage_u "Correlation wage increases and unemployment"
}



*************************
** Causes of inflation **
*************************
{
label define importance 1 "Not important at all" 2 "Only a little important" 3 "Very important" 4 "Extremely important"

destring cause_actor_*, replace
foreach var of varlist cause_actor_*{
	label values `var' importance
}

label var cause_actor_gvt "Government important cause of inflation"
label var cause_actor_fed "Fed important cause of inflation"
label var cause_actor_costs "Increases in costs important cause of inflation"
label var cause_actor_labor "Labor market changes important cause of inflation"
label var cause_actor_politics "Politics important cause of inflation"
label var cause_actor_firms "Firms decisions important cause of inflation"
label var cause_actor_hh "Households important cause of inflation"

drop cause_gvt cause_fed cause_costs cause_labor cause_politics cause_firms cause_hh causes_gvt

label define binary 0 "No" 1 "Yes"

gen cause_gvt = 0 if !missing(causes_actor_rank)
replace cause_gvt = 1 if strpos(causes_actor_rank,"1")>0
label var cause_gvt "Government spending, debt, taxation"
label values cause_gvt binary

gen cause_fed = 0 if !missing(causes_actor_rank)
replace cause_fed = 1 if strpos(causes_actor_rank,"2")>0
label var cause_fed "Actions by the Federal Reserve"
label values cause_fed binary

gen cause_costs = 0 if !missing(causes_actor_rank)
replace cause_costs = 1 if strpos(causes_actor_rank,"3")>0
label var cause_costs "Increases in costs of production"
label values cause_costs binary

gen cause_labor = 0 if !missing(causes_actor_rank)
replace cause_labor = 1 if strpos(causes_actor_rank,"4")>0
label var cause_labor "Changes in the labor market"
label values cause_labor binary

gen cause_politics = 0 if !missing(causes_actor_rank)
replace cause_politics = 1 if strpos(causes_actor_rank,"5")>0
label var cause_politics "Politicians and political interests"
label values cause_politics binary

gen cause_hh = 0 if !missing(causes_actor_rank)
replace cause_hh = 1 if strpos(causes_actor_rank,"6")>0
label var cause_hh "Households spending more"
label values cause_hh binary

gen cause_firms = 0 if !missing(causes_actor_rank)
replace cause_firms = 1 if strpos(causes_actor_rank,"7")>0
label var cause_firms "Actions by firms and businesses"
label values cause_firms binary

destring cause_gvt_*, replace

forvalues x=1(1)5{
	label values cause_gvt_`x' importance
}

label var cause_gvt_1 "Income tax cuts important cause of inflation"
label var cause_gvt_2 "Debt-financed increase in foreign assistance important cause of inflation"
label var cause_gvt_3 "Debt-financed increase in  government spending important cause of inflation"
label var cause_gvt_4 "Debt-financed increase in assistance measures for difficult times important cause of inflation"
label var cause_gvt_5 "Debt-financed increase in social spending important cause of inflation"

tab cause_gvt_top, gen(cause_gvt_top_)
forvalues x=1(1)5{
	local lbl : variable label cause_gvt_`x'
	label var cause_gvt_top_`x' "`lbl'"
}

label define top_gvt 1 "Income tax cuts" 2 "Debt-financed increase in foreign assistance" 3 "Debt-financed increase in  government spending" 4 "Debt-financed increase in assistance measures for difficult times" 5 "Debt-financed increase in social spending"
label values cause_gvt_top top_gvt
label var cause_gvt_top "Most important cause in government is"

destring cause_fed_*, replace

forvalues x=1(1)5{
	label values cause_fed_`x' importance
}

label var cause_fed_1 "Decrease in interest rates important cause of inflation"
label var cause_fed_2 "Increase in interest rates important cause of inflation"
label var cause_fed_3 "Increase in money supply important cause of inflation"
label var cause_fed_4 "Fed not taking appropriate actions important cause of inflation"
label var cause_fed_5 "Fed being unclear about the future important cause of inflation"

tab cause_fed_top, gen(cause_fed_top_)
forvalues x=1(1)5{
	local lbl : variable label cause_fed_`x'
	label var cause_fed_top_`x' "`lbl'"
}

label define top_fed 1 "Decrease in interest rates" 2 "Increase in interest rates" 3 "Increase in money supply" 4 "Fed not taking appropriate actions" 5 "Fed being unclear about the future"
label values cause_fed_top top_fed 
label var cause_fed_top "Most important cause in Fed is"

destring cause_costs_*, replace

forvalues x=1(1)5{
	label values cause_costs_`x' importance
}

label var cause_costs_1 "Increases in oil prices important cause of inflation"
label var cause_costs_2 "Increases in energy prices important cause of inflation"
label var cause_costs_3 "Disruptions in other countries important cause of inflation"
label var cause_costs_4 "Supply chain disruptions important cause of inflation"
label var cause_costs_5 "Pandemic induced cost increase important cause of inflation"

tab cause_costs_top, gen(cause_costs_top_)
forvalues x=1(1)5{
	local lbl : variable label cause_costs_`x'
	label var cause_costs_top_`x' "`lbl'"
}

label define top_cost 1 "Increases in oil prices" 2 "Increases in energy prices" 3 "Disruptions in other countries" 4 "Supply chain disruptions" 5 "Pandemic induced cost increase"
label values cause_costs_top top_cost 
label var cause_costs_top "Most important cause in costs is"

destring cause_labor_*, replace

forvalues x=1(1)3{
	label values cause_labor_`x' importance
}

label var cause_labor_1 "Wage increase due to unionization important cause of inflation"
label var cause_labor_2 "Wage increase due to labor shortage important cause of inflation"
label var cause_labor_3 "Wage-price spiral important cause of inflation"

tab cause_labor_top, gen(cause_labor_top_)
forvalues x=1(1)3{
	local lbl : variable label cause_labor_`x'
	label var cause_labor_top_`x' "`lbl'"
}

label define top_labor 1 "Wage increase due to unionization" 2 "Wage increase due to labor shortage" 3 "Wage-price spiral"
label values cause_labor_top top_labor
label var cause_labor_top "Most important cause in labor mkt changes is"

destring cause_hh_*, replace

forvalues x=1(1)2{
	label values cause_hh_`x' importance
}

label var cause_hh_1 "HH increase spending due to expectations important cause of inflation"
label var cause_hh_2 "HH increase spending due to optimism important cause of inflation"

tab cause_hh_top, gen(cause_hh_top_)
forvalues x=1(1)2{
	local lbl : variable label cause_hh_`x'
	label var cause_hh_top_`x' "`lbl'"
}

label define top_hh 1 "HH increase spending due to expectations" 2 "HH increase spending due to optimism"
label values cause_hh_top top_hh
label var cause_hh_top "Most important cause in households is"

destring cause_firms_*, replace

forvalues x=1(1)3{
	label values cause_firms_`x' importance
}

label var cause_firms_1 "Increase prices due to expectations important cause of inflation"
label var cause_firms_2 "Increase prices to increase profits important cause of inflation"
label var cause_firms_3 "Lack of competition important cause of inflation"

tab cause_firms_top, gen(cause_firms_top_)
forvalues x=1(1)3{
	local lbl : variable label cause_firms_`x'
	label var cause_firms_top_`x' "`lbl'"
}

label define top_firms 1 "Increase prices due to expectations" 2 "Increase prices to increase profits" 3 "Lack of competition"
label values cause_firms_top top_firms
label var cause_firms_top "Most important cause in firms decisions changes is"
}



*****************************************
** Distributional impacts of inflation **
*****************************************
{
label define lose_gain 1 "Lose a lot" 2 "Lose somewhat" 3 "Neither gain nor lose" 4 "Gain somewhat" 5 "Gain a lot"

destring distr_1_1, gen(distr_highincome)
label values distr_highincome lose_gain
label var distr_highincome "High income distributional"

destring distr_1_2, gen(distr_midincome)
label values distr_midincome lose_gain
label var distr_midincome "Middle income distributional"

destring distr_1_3, gen(distr_lowincome)
label values distr_lowincome lose_gain
label var distr_lowincome "Low income distributional"

destring distr_2_1, gen(distr_young)
label values distr_young lose_gain
label var distr_young "Young distributional"

destring distr_2_2, gen(distr_midage)
label values distr_midage lose_gain
label var distr_midage "Middle age distributional"

destring distr_2_3, gen(distr_old)
label values distr_old lose_gain
label var distr_old "Old distributional"

destring distr_3_1, gen(distr_unemp)
label values distr_unemp lose_gain
label var distr_unemp "Unemployed distributional"

destring distr_3_2, gen(distr_emp)
label values distr_emp lose_gain
label var distr_emp "Employed distributional"

destring distr_3_3, gen(distr_retire)
label values distr_retire lose_gain
label var distr_retire "Retirees distributional"

destring distr_4_1, gen(distr_cash)
label values distr_cash lose_gain
label var distr_cash "Cash-holding distributional"

destring distr_4_2, gen(distr_finassets)
label values distr_finassets lose_gain
label var distr_finassets "Financial asset-holding distributional"

destring distr_4_3, gen(distr_nosave)
label values distr_nosave lose_gain
label var distr_nosave "No savings distributional"

destring distr_5_1, gen(distr_ccdebt)
label values distr_ccdebt lose_gain
label var distr_ccdebt "Credit card debt distributional"

destring distr_5_2, gen(distr_fixrate)
label values distr_fixrate lose_gain
label var distr_fixrate "Fixed rate mortgages distributional"

destring distr_5_3, gen(distr_flexrate)
label values distr_flexrate lose_gain
label var distr_flexrate "Flexible rate mortgages distributional"

destring distr_5_4, gen(distr_nodebt)
label values distr_nodebt lose_gain
label var distr_nodebt "Low level of debt distributional"

destring distr_6_1, gen(distr_smallfirms)
label values distr_smallfirms lose_gain
label var distr_smallfirms "Small firms distributional"

destring distr_6_2, gen(distr_bigfirms)
label values distr_bigfirms lose_gain
label var distr_bigfirms "Big firms distributional"

}



**********************************************
** Consequences of inflation on the economy **
**********************************************
{
label define complicated 1 "Much more complicated" 2 "More complicated" 3 "Neither simpler nor more complicated" 4 "Simpler" 5 "Much simpler"
label define difficult 1 "Much more difficult" 2 "More difficult" 3 "Neither easier nor more difficult" 4 "Easier" 5 "Much easier"
destring cons_1, gen(cons_budgeting)
label values cons_budgeting complicated
label var cons_budgeting "Inflation on budgeting"

label define uncertain 1 "Significantly reduces uncertainty" 2 "Somewhat reduces uncertainty" 3 "Neither increases nor reduces uncertainty" 4 "Somewhat increases uncertainty" 5 "Significantly increases uncertainty"
destring cons_2, gen(cons_uncertain)
label values cons_uncertain uncertain
label var cons_uncertain "Inflation on household uncertainty"

label define inconvinience 1 "Almost no inconvinience" 2 "A small inconvinience" 3 "A moderate inconvinience" 4 "A very big inconvinience"
destring cons_3, gen(cons_inconvinience)
label values cons_inconvinience inconvinience
label var cons_inconvinience "Inconvinience of holding more cash due to inflation"

destring cons_3_2, gen(cons_setprices)
label values cons_setprices difficult
label var cons_setprices "Difficult for firms to set their prices (menù costs)"

destring cons_4, gen(cons_firmsdecisions)
label values cons_firmsdecisions difficult
label var cons_firmsdecisions "Inflation on firms' decisions"

label define negative_positive 1 "Greatly worsens use" 2 "Sligthly worsen use" 3 "Neither improve nor worsen use" 4 "Sligthly improve use" 5 "Greatly improve use"
destring cons_5, gen(cons_pdifferential)
label values cons_pdifferential negative_positive
label var cons_pdifferential "Inflation on price differentials"

label define slow_quick 1 "Much more slowly" 2 "More slowly" 3 "At the same rate" 4 "More quickly" 5 "Much more quickly"
destring cons_6, gen(cons_gdpgrowth)
label values cons_gdpgrowth slow_quick
label var cons_gdpgrowth "Inflation on growth"

destring cons_7, gen(cons_dollarvalue)
label values cons_dollarvalue decrease_increase
label var cons_dollarvalue "Inflation on dollar value"

destring cons_8, gen(cons_prestige)
label values cons_prestige decrease_increase
label var cons_prestige "Inflation on national prestige"

label define low_high 1 "Much lower" 2 "Lower" 3 "The same" 4 "Higher" 5 "Much higher"
destring cons_9, gen(cons_inequality)
label values cons_inequality low_high
label var cons_inequality "Inflation on inequality"

label define increase_decrease 1 "Increases by a lot" 2 "Increases somewhat" 3 "Neither increases nor decreases" 4 "Decreases somewhat" 5 "Decreases by a lot"
destring cons_10, gen(cons_cohesion)
label values cons_cohesion increase_decrease
label var cons_cohesion "Inflation on cohesion"

destring cons_11, gen(cons_gvttrust)
label values cons_gvttrust increase_decrease
label var cons_gvttrust "Inflation on trust in government"
}



*******************************
** First stage and treatment **
*******************************
{
destring first_stage treatment, replace
label define agree 1 "Strongly disagree" 2 "Disagree" 3 "Neither agree nor disagree" 4 "Agree" 5 "Strongly agree"
label values first_stage agree
label var first_stage "First stage question on tradeoffs"
}

******************
** Policy views **
******************
{
* Variables recording numeric answers to quantitative questions are destringed and aggregated in the code file "replication_package\code\appendix\tables\taba26\1.1inattentive_creation.do"

label define priority_stability 1 "Not at all important" 2 "Slightly important" 3 "Moderately important" 4 "Very important"
destring priority_1, gen(priority_stability)
label values priority_stability priority_stability
label var priority_stability "Priority of price stability"

*encode ranking questions
foreach var in priority_2 {
	foreach x in 1 2 3 4 5  {
		destring `var'_`x', gen(`var'_`x'_en) force	
		}
}

foreach var in priority_3 {
	foreach x in 1 2 3 4 5 6 {
		destring `var'_`x', gen(`var'_`x'_en) force	
		}
}


*label oppose_support already defined in in the code file "replication_package\code\appendix\tables\taba26\1.1inattentive_creation.do"

destring policy_2, gen(policy_announcement)
label values policy_announcement oppose_support
label var policy_announcement "Announce increases in 6 months instead of doing it now"

destring policy_3, gen(policy_decreasemsupply)
label values policy_decreasemsupply oppose_support
label var policy_decreasemsupply "Decrease money supply"

destring policy_4, gen(policy_debtreduce_highinc)
label values policy_debtreduce_highinc oppose_support
label var policy_debtreduce_highinc "Decrease debt through high income taxes"

destring policy_5, gen(policy_debtreduce_midinc)
label values policy_debtreduce_midinc oppose_support
label var policy_debtreduce_midinc "Decrease debt through mid income taxes"

destring policy_6, gen(policy_debtreduce_lowinc)
label values policy_debtreduce_lowinc oppose_support
label var policy_debtreduce_lowinc "Decrease debt through low income transfers"

destring policy_8, gen(policy_transfer_highinc)
label values policy_transfer_highinc oppose_support
label var policy_transfer_highinc "Increase transfers through high income taxes"

destring policy_9, gen(policy_corporatetaxes)
label values policy_corporatetaxes oppose_support
label var policy_corporatetaxes "Increase corporate taxes"

destring policy_9_2, gen(policy_antitrust)
label values policy_antitrust oppose_support
label var policy_antitrust "Increase antitrust regulation"

destring policy_10, gen(policy_pricecaps)
label values policy_pricecaps oppose_support
label var policy_pricecaps "Price caps on gas or basic food items"

destring policy_11, gen(policy_wagecaps)
label values policy_wagecaps oppose_support
label var policy_wagecaps "Price caps on wages"

destring policy_12, gen(policy_imports)
label values policy_imports oppose_support
label var policy_imports "Reduce imports to relocate production in US"


label define necessary 1 "Not necessary at all" 2 "Somewhat necessary" 3 "Very necessary" 4 "Extremely necessary"

destring policy_tradeoff_1, gen(policy_tradeoff_spend)
label values policy_tradeoff_spend necessary
label var policy_tradeoff_spend "Necessary to reduce spending"

destring policy_tradeoff_2, gen(policy_tradeoff_growth)
label values policy_tradeoff_growth necessary
label var policy_tradeoff_growth "Necessary to reduce growth"

destring policy_tradeoff_3, gen(policy_tradeoff_debt)
label values policy_tradeoff_debt necessary
label var policy_tradeoff_debt "Necessary to reduce debt"

destring policy_tradeoff_4, gen(policy_tradeoff_unemp)
label values policy_tradeoff_unemp necessary
label var policy_tradeoff_unemp "Necessary to reduce unemployment"

label define side 1 "Significantly increase" 2 "Increase" 3 "Neither increase nor decrease" 4 "Decrease" 5 "Significantly decrease"

destring policy_sideffects, replace
label values policy_sideffects side
label var policy_sideffects "Policies to reduce unemployment increase inflation"

label define signal 1 "Most often a sign of a bad economy" 2 "Neither a sign of a good nor a bad economy" 3 "Most often a sign of a good economy"

destring policy_signal, replace
label values policy_signal signal
label var policy_signal "Inflation is a signal of"

label define boom 1 "Mostly in booms" 2 "Slightly more in booms" 3 "Equally in booms and recessions" 4 "Slightly more in recessions" 5 "Mostly in recessions"

destring policy_booms, replace
label values policy_booms boom
label var policy_booms "Inflation happens more in booms"

destring redib_tool_1, gen(policy_redib_lowinctransf)
label values policy_redib_lowinctransf oppose_support
label var policy_redib_lowinctransf "Increase cash transfers to low income"

destring redib_tool_2, gen(policy_redib_stamps)
label values policy_redib_stamps oppose_support
label var policy_redib_stamps "Increase food stamps"

destring redib_tool_3, gen(policy_redib_vouch_lowinc)
label values policy_redib_vouch_lowinc oppose_support
label var policy_redib_vouch_lowinc "Increase vouchers to low income"

destring redib_tool_4, gen(policy_redib_vouch_midinc)
label values policy_redib_vouch_midinc oppose_support
label var policy_redib_vouch_midinc "Increase vouchers to mid income"

destring redib_tool_5, gen(policy_redib_minwage)
label values policy_redib_minwage oppose_support
label var policy_redib_minwage "Increase minimum wage"
}



*************************************
** Save the newly labelled dataset **
*************************************
compress
save "$data/inflation_understanding_encoded_attrition.dta", replace
