**************************************************************************
** This code generates Table A26, which reports regression coefficients **
** of attrition determinants.                                           **
**************************************************************************


clear all

use "$data/inflation_understanding_variables_attrition.dta", clear


************************************************************************
label var race_black "Black"
label var race_asian "Asian"
label var race_hisp "Hispanic"
label var race_mixed "Mixed race"


*** Generate the global of variables for the regressions
global quotas "women agegroup_agg_2 agegroup_agg_3  incomegroup_agg_2 incomegroup_agg_3 race_black race_asian race_hisp race_mixed"
global demo_controls " $quotas independent republican college econ_studies marital_status_2 marital_status_3 marital_status_4 kids employment_group_2 employment_group_3 treatment conjoint_info double_order_treated policy_first unemployment_first news_cnn news_fox news_social_media news_npr news_nyt news_wsj news_msnbc    news_network news_localtv  news_amtalk   news_localpapers"

global het_groups "incomegroup_agg_1 incomegroup_agg_3 democrat republican agegroup_agg_1 agegroup_agg_2 agegroup_agg_3"

gen check=0
forvalues x=1(1)12{
	replace news_`x'="999" if news_`x'==""
	replace check= check + 1 if news_`x' !="999"
}


******************************************************
** Create the table (including running regressions) ** 
******************************************************
{
global table_name "$appendix_tables/taba26"

* Table end
file open  holder using $appendix_tables/temp_end.tex, write replace text
file write holder " \end{tabular}" _n
file close holder

* Table start
file open holder using $table_name.tex, write replace text
file write holder "\begin{tabular}{lccccccc} " _n
file write holder "& Dropped attention check & Inattentive open-ended questions &Inaccurate age & Inaccurate gender & Inattentive interest rate policy & Inattentive expectations & In sample \\ \hline" _n
file write holder "& (1) & (2) & (3) & (4) & (5) & (6) & (7) \\ \hline" _n
file close holder


* Run regressions
eststo:  reghdfe attention_checks $quotas if (in_sample==1 | attention_checks==1), noabsorb vce(robust)
local rsq_1: display %5.3f `e(r2_a)'

qui sum attention_checks if e(sample) 
local depmean_1: display %5.3f `r(mean)'
local obs_1: display %5.0f `r(N)'
local std_1: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum attention_checks if e(sample) & `var'==1
	local mean_`var'_1: display %5.3f `r(mean)'
}

eststo:  reghdfe inatt_open $demo_controls if (in_sample==1 | inatt_open==1), noabsorb vce(robust)
local rsq_2: display %5.3f `e(r2_a)'

qui sum inatt_open if e(sample) 
local depmean_2: display %5.3f `r(mean)'
local obs_2: display %5.0f `r(N)'
local std_2: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum inatt_open if e(sample) & `var'==1
	local mean_`var'_2: display %5.3f `r(mean)'
}


eststo:  reghdfe inacc_age $demo_controls if (in_sample==1 | inacc_age==1), noabsorb vce(robust)
local rsq_3: display %5.3f `e(r2_a)'

qui sum inacc_age if e(sample) 
local depmean_3: display %5.3f `r(mean)'
local obs_3: display %5.0f `r(N)'
local std_3: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum inacc_age if e(sample) & `var'==1
	local mean_`var'_3: display %5.3f `r(mean)'
}

eststo:  reghdfe inacc_gender $demo_controls if (in_sample==1 | inacc_gender==1), noabsorb vce(robust)
local rsq_4: display %5.3f `e(r2_a)'

qui sum inacc_gender if e(sample) 
local depmean_4: display %5.3f `r(mean)'
local obs_4: display %5.0f `r(N)'
local std_4: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum inacc_gender if e(sample) & `var'==1
	local mean_`var'_4: display %5.3f `r(mean)'
}


eststo:  reghdfe inattentive_rate $demo_controls if (in_sample==1 | inattentive_rate==1), noabsorb vce(robust)
local rsq_5: display %5.3f `e(r2_a)'

qui sum inattentive_rate if e(sample) 
local depmean_5: display %5.3f `r(mean)'
local obs_5: display %5.0f `r(N)'
local std_5: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum inattentive_rate if e(sample) & `var'==1
	local mean_`var'_5: display %5.3f `r(mean)'
}

eststo:  reghdfe inattentive_expectations $demo_controls if (in_sample==1 | inattentive_expectations==1), noabsorb vce(robust)
local rsq_6: display %5.3f `e(r2_a)'

qui sum inattentive_expectations if e(sample) 
local depmean_6: display %5.3f `r(mean)'
local obs_6: display %5.0f `r(N)'
local std_6: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum inattentive_expectations if e(sample) & `var'==1
	local mean_`var'_6: display %5.3f `r(mean)'
}

eststo:  reghdfe in_sample $quotas if overquota==0, noabsorb vce(robust)
local rsq_7: display %5.3f `e(r2_a)'

qui sum in_sample if e(sample) 
local depmean_7: display %5.3f `r(mean)'
local obs_7: display %5.0f `r(N)'
local std_7: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum in_sample if e(sample) & `var'==1
	local mean_`var'_7: display %5.3f `r(mean)'
}

esttab using $appendix_tables/panel_before.tex, replace fragment booktabs noconst nobase  label cells(b(fmt(3) star) se(par fmt(3))) collabels(none) keep(women agegroup_agg_2 agegroup_agg_3 race_black race_asian race_hisp race_mixed independent republican college econ_studies kids incomegroup_agg_2 incomegroup_agg_3 employment_group_2 employment_group_3      news_cnn news_fox news_social_media news_npr news_nyt news_wsj treatment) /// 
starlevels(* .1 ** .05 *** .01) se nonumbers nomtitles nolines nocon noobs compress

file open holder using $appendix_tables/panel_means_before.tex, write replace text
file write holder "\hline " _n 
file write holder "Observations & `obs_1' & `obs_2' & `obs_3' & `obs_4' & `obs_5' & `obs_6' & `obs_7'  \\" _n     
file write holder "Adj. R$^{2}$ & `rsq_1' & `rsq_2' & `rsq_3' & `rsq_4' & `rsq_5' & `rsq_6' & `rsq_7'  \\" _n 
file write holder "$\mathbb{E}$(Dependent variable)& `depmean_1' & `depmean_2' & `depmean_3'  & `depmean_4' & `depmean_5' & `depmean_6' & `depmean_7'  \\" _n  
file write holder "Mean income \$<\$40k& `mean_incomegroup_agg_1_1' & `mean_incomegroup_agg_1_2' & `mean_incomegroup_agg_1_3'  & `mean_incomegroup_agg_1_4' & `mean_incomegroup_agg_1_5' & `mean_incomegroup_agg_1_6' & `mean_incomegroup_agg_1_7'   \\" _n 
file write holder "Mean income \$>\$125k& `mean_incomegroup_agg_3_1' & `mean_incomegroup_agg_3_2' & `mean_incomegroup_agg_3_3'  & `mean_incomegroup_agg_3_4' & `mean_incomegroup_agg_3_5' & `mean_incomegroup_agg_3_6' & `mean_incomegroup_agg_3_7'   \\" _n 
file write holder "Mean democrat& & `mean_democrat_2' & `mean_democrat_3'  & `mean_democrat_4' & `mean_democrat_5'  & `mean_democrat_6' &  \\" _n 
file write holder "Mean republican&  & `mean_republican_2' & `mean_republican_3'  & `mean_republican_4' & `mean_republican_5'  & `mean_republican_6'  &  \\" _n 
file write holder "Mean 18-29 years old& `mean_agegroup_agg_1_1' & `mean_agegroup_agg_1_2' & `mean_agegroup_agg_1_3'  & `mean_agegroup_agg_1_4' & `mean_agegroup_agg_1_5'  & `mean_agegroup_agg_1_6' & `mean_agegroup_agg_1_7' \\" _n 
file write holder "Mean 30-49 years old& `mean_agegroup_agg_2_1' & `mean_agegroup_agg_2_2' & `mean_agegroup_agg_2_3'  & `mean_agegroup_agg_2_4' & `mean_agegroup_agg_2_5'  & `mean_agegroup_agg_2_6' & `mean_agegroup_agg_2_7' \\" _n 
file write holder "Mean 50-69 years old& `mean_agegroup_agg_3_1' & `mean_agegroup_agg_3_2' & `mean_agegroup_agg_3_3'  & `mean_agegroup_agg_3_4' & `mean_agegroup_agg_3_5' & `mean_agegroup_agg_3_6' & `mean_agegroup_agg_3_7'  \\" _n    
file write holder "Dependent variable std. dev. & `std_1' & `std_2' & `std_3' & `std_4' & `std_5' & `std_6' & `std_7'  \\" _n
file write holder "\hline " _n 
file write holder " & & \\" _n
file close holder

eststo clear

appendfile $appendix_tables/panel_before.tex $table_name.tex
appendfile $appendix_tables/panel_means_before.tex $table_name.tex
appendfile $appendix_tables/temp_end.tex $table_name.tex

erase $appendix_tables/panel_before.tex
erase $appendix_tables/panel_means_before.tex
erase $appendix_tables/temp_end.tex
}
