**************************************************************
** This code generates Appendix Table 3, which presents the **
** correlates of the selected top causes for inflation. 	** 
**************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

****************************************************************************

********************************************
** Prepare the globals for the regression **
********************************************

global demo_controls "women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies incomegroup_agg_2 incomegroup_agg_3 race_black race_asian race_hisp race_mixed  marital_status_2 marital_status_3 marital_status_4 kids employment_group_2 employment_group_3 treatment conjoint_info double_order_treated policy_first unemployment_first news_cnn news_fox news_social_media news_npr news_nyt news_wsj news_msnbc    news_network news_localtv  news_amtalk   news_localpapers"
global het_groups "incomegroup_agg_1 incomegroup_agg_3 democrat republican agegroup_agg_1 agegroup_agg_2 agegroup_agg_3"

*************************
** Generates the table **
*************************

* Note: the output variables are indicators taking value 1 when the respondent chose the cause of inflation as one of the two most important ones

{
global table_name "$appendix_tables/taba3"

* Table end
file open  holder using $appendix_tables/temp_end.tex, write replace text
file write holder " \end{tabular}" _n
file close holder

* Table start
file open holder using $table_name.tex, write replace text
file write holder "\begin{tabular}{lccccccc} " _n
file write holder "&\multicolumn{7}{c}{\textbf{Among 2 most important cause of inflation:}} \\" _n
file write holder "& Government & Fed &Changes in labor market & Politics & Households & Firms & Increases in costs \\ \hline" _n
file write holder "& (1) & (2) & (3) & (4) & (5) & (6) & (7) \\ \hline" _n
file close holder
       
* Regressions
eststo:  reghdfe cause_gvt $demo_controls, noabsorb vce(robust)
local rsq_1: display %5.3f `e(r2_a)'

qui sum cause_gvt if e(sample) 
local depmean_1: display %5.3f `r(mean)'
local obs_1: display %5.0f `r(N)'
local std_1: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum cause_gvt if e(sample) & `var'==1
	local mean_`var'_1: display %5.3f `r(mean)'
}

eststo:  reghdfe cause_fed $demo_controls, noabsorb vce(robust)
local rsq_2: display %5.3f `e(r2_a)'

qui sum cause_fed if e(sample) 
local depmean_2: display %5.3f `r(mean)'
local obs_2: display %5.0f `r(N)'
local std_2: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum cause_fed if e(sample) & `var'==1
	local mean_`var'_2: display %5.3f `r(mean)'
}

eststo:  reghdfe cause_labor $demo_controls, noabsorb vce(robust)
local rsq_3: display %5.3f `e(r2_a)'

qui sum cause_labor if e(sample) 
local depmean_3: display %5.3f `r(mean)'
local obs_3: display %5.0f `r(N)'
local std_3: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum cause_labor if e(sample) & `var'==1
	local mean_`var'_3: display %5.3f `r(mean)'
}

eststo:  reghdfe cause_politics $demo_controls, noabsorb vce(robust)
local rsq_4: display %5.3f `e(r2_a)'

qui sum cause_politics if e(sample) 
local depmean_4: display %5.3f `r(mean)'
local obs_4: display %5.0f `r(N)'
local std_4: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum cause_politics if e(sample) & `var'==1
	local mean_`var'_4: display %5.3f `r(mean)'
}

eststo:  reghdfe cause_hh $demo_controls, noabsorb vce(robust)
local rsq_5: display %5.3f `e(r2_a)'

qui sum cause_hh if e(sample) 
local depmean_5: display %5.3f `r(mean)'
local obs_5: display %5.0f `r(N)'
local std_5: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum cause_hh if e(sample) & `var'==1
	local mean_`var'_5: display %5.3f `r(mean)'
}

eststo:  reghdfe cause_firms $demo_controls, noabsorb vce(robust)
local rsq_6: display %5.3f `e(r2_a)'

qui sum cause_firms if e(sample) 
local depmean_6: display %5.3f `r(mean)'
local obs_6: display %5.0f `r(N)'
local std_6: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum cause_firms if e(sample) & `var'==1
	local mean_`var'_6: display %5.3f `r(mean)'
}

eststo:  reghdfe cause_costs $demo_controls, noabsorb vce(robust)
local rsq_7: display %5.3f `e(r2_a)'

qui sum cause_costs if e(sample) 
local depmean_7: display %5.3f `r(mean)'
local obs_7: display %5.0f `r(N)'
local std_7: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum cause_costs if e(sample) & `var'==1
	local mean_`var'_7: display %5.3f `r(mean)'
}

esttab using $appendix_tables/panel_before.tex, replace fragment booktabs noconst nobase  label cells(b(fmt(3) star) se(par fmt(3))) collabels(none) keep(women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies kids incomegroup_agg_2 incomegroup_agg_3 employment_group_2 employment_group_3      news_cnn news_fox news_social_media news_npr news_nyt news_wsj ) /// 
starlevels(* .1 ** .05 *** .01) se nonumbers nomtitles nolines nocon noobs compress

file open holder using $appendix_tables/panel_means_before.tex, write replace text
file write holder "\hline " _n 
file write holder "Observations & `obs_1' & `obs_2' & `obs_3' & `obs_4' & `obs_5' & `obs_6' & `obs_7'   \\" _n     
file write holder "Adj. R$^{2}$ & `rsq_1' & `rsq_2' & `rsq_3' & `rsq_4' & `rsq_5' & `rsq_6' & `rsq_7' \\" _n 
file write holder "$\mathbb{E}$(Dependent variable)& `depmean_1' & `depmean_2' & `depmean_3'  & `depmean_4' & `depmean_5' & `depmean_6' & `depmean_7' \\" _n   
file write holder "Mean income \$<\$40k& `mean_incomegroup_agg_1_1' & `mean_incomegroup_agg_1_2' & `mean_incomegroup_agg_1_3'  & `mean_incomegroup_agg_1_4' & `mean_incomegroup_agg_1_5' & `mean_incomegroup_agg_1_6'  & `mean_incomegroup_agg_1_7'  \\" _n 
file write holder "Mean income \$>\$125k& `mean_incomegroup_agg_3_1' & `mean_incomegroup_agg_3_2' & `mean_incomegroup_agg_3_3'  & `mean_incomegroup_agg_3_4' & `mean_incomegroup_agg_3_5' & `mean_incomegroup_agg_3_6'  & `mean_incomegroup_agg_3_7'  \\" _n 
file write holder "Mean democrat& `mean_democrat_1' & `mean_democrat_2' & `mean_democrat_3'  & `mean_democrat_4' & `mean_democrat_5'  & `mean_democrat_6'  & `mean_democrat_7' \\" _n 
file write holder "Mean republican& `mean_republican_1' & `mean_republican_2' & `mean_republican_3'  & `mean_republican_4' & `mean_republican_5'  & `mean_republican_6' & `mean_republican_7' \\" _n 
file write holder "Mean 18-29 years old& `mean_agegroup_agg_1_1' & `mean_agegroup_agg_1_2' & `mean_agegroup_agg_1_3'  & `mean_agegroup_agg_1_4' & `mean_agegroup_agg_1_5'  & `mean_agegroup_agg_1_6'  & `mean_agegroup_agg_1_7' \\" _n 
file write holder "Mean 30-49 years old& `mean_agegroup_agg_2_1' & `mean_agegroup_agg_2_2' & `mean_agegroup_agg_2_3'  & `mean_agegroup_agg_2_4' & `mean_agegroup_agg_2_5'  & `mean_agegroup_agg_2_6'  & `mean_agegroup_agg_2_7' \\" _n 
file write holder "Mean 50-69 years old& `mean_agegroup_agg_3_1' & `mean_agegroup_agg_3_2' & `mean_agegroup_agg_3_3'  & `mean_agegroup_agg_3_4' & `mean_agegroup_agg_3_5' & `mean_agegroup_agg_3_6' & `mean_agegroup_agg_3_7' \\" _n    
file write holder "Dependent variable std. dev. & `std_1' & `std_2' & `std_3' & `std_4' & `std_5' & `std_6' & `std_7' \\" _n
file write holder "\hline " _n 
file write holder " & & \\" _n
file close holder

eststo clear

appendfile $appendix_tables/panel_before.tex $table_name.tex
appendfile $appendix_tables/panel_means_before.tex $table_name.tex
appendfile $appendix_tables/temp_end.tex $table_name.tex

erase $appendix_tables/panel_before.tex
erase $appendix_tables/panel_means_before.tex
erase $appendix_tables/temp_end.tex
}
