********************************************************************************
** This code removes inattentive respondents: those who provide repetitive,   ** 
** poor, or entirely unrelated answers (likely bots) to open-ended questions, **
** those who give inconsistent answers to demographic questions compared to   **
** their data on Cint, and those who give inconsistent answers to the same    ** 
** questions. Moreover, this code calculates the time spent on the treatment  **
** page.                                                                      ** 
********************************************************************************


clear all

use "$data/inflation_understanding_screened.dta", clear

********************************************************************************


**********************************************************************
** Identify and remove inattentive respondents based on an analysis ** 
** of their answers to open-ended questions (likely bots)           ** 
**********************************************************************


gen inatt_open=0

global list_remove_1 ///
" R_7BnPSlAf3Y3E5jM R_7nf41mELwpicDXB R_1qguLPo8kyM4nTL R_5VClg0xpuveISgF R_5R1sytijSbYvi1R R_5Nzjiz8w1aHCh4B R_7d0NtCiKGv7aVVk R_1jTWGzEDJyvPxd4 R_5kyRH1Nq3Em2Hne R_2SDGhThvLq4AGQd R_2xUXN8kdELEqt7b R_1czLWFrlU4JGIHS R_6KlRy35eJYJTfTn R_7DHDVCflFonw8mA R_2dtEtxb6XWm3E9p R_3AOeLcd9f3NYysx R_5eK6EyqEIXe8qH0 "

foreach name in $list_remove_1 {
	replace inatt_open = 1 if ResponseId == "`name'"
}

global list_remove_2 ///
"  R_5YymPmhQRWdPdp7 R_7zGdsmVorzjuRDb R_3s0UAS48Rkaj6fB R_3azdRWknIEBqoxz R_3LbZAVx4VdZldLf R_23IfU6c4qo9zWUh R_1uHE5VaYVA77Qov R_1g4V5hWDyslDxiT R_7kHdDGUKxT4t2in R_7IPtbRm7WE1I6fn R_2AXNR6BsSKdL8TS R_8nplkGq3fpiZ8dO R_7ePea6XAy4lvduh R_5R8FDn7fUKIM24H R_2VK2OlAOzBAXvs4 R_2QAQLwaSB9KnqEx R_6GywUvBXpcfc37W R_2DbeanRepzDosmO R_1zdaI6KBRU6tBrH R_5eW7HwPxUJZD5FZ R_3nwuTr4FQBfrRSW R_1DXMPB1SWrTuwTk R_5yw8DzwiWvYXseB R_2oyFdRZDuPGXB51 R_2iNYb9fffquXykp R_6RPtEGzpLEfZ10R R_5fpjU5y918517UJ R_32A79Z6kh7huRjb R_2y7Me7h5gY5eeWf R_1k51wI1mVwkfNwr R_3NvXiIjsOtoiA8B R_2OBs8TxCt2VBEj5 R_22DDiB0FO15DBXz R_52W7W64EHEhfVQ4 R_2kYOnT9Dce2Lvo3 R_59m07Ra10m1Jueo "



foreach name in $list_remove_2 {
	replace inatt_open = 1 if ResponseId == "`name'"
}

global list_remove_3 ///
"   R_3pnJlk3i9GnNgnu R_1uRGIg2OegsuIiB R_2Oe9P23JDDBeJIr R_305Kp27ptRmCd3D R_5DtDPzMkJvFihHS R_3C2YTUNJfhvhrNU R_2Iza06qhF39FOUa R_6w6VBhE8w9r5KwW R_2qNoJrWF8WVH585 R_7N3vjSGI7L1CLqp R_5p5THwRNKvhAWFs R_2Bbs5RJmqAsT5XU R_3ygupKwjGvAktTN R_1oAwRNT3h0XK4Pj R_2726wWh613UxNKJ R_4WuPKWLFvRLxmNP R_1n6L9Y80bKHyBYk R_3nSEHC0Xns5oNpG R_1rZKHHB0igyUAAI R_2aIT60PGVUMXduG R_1gYAX3vJwTFwclb R_5L608VOgblc5EsQ R_71y8oNc8AkfLqtr R_7JLBuBId9HsbLNY R_6DY1DfeWMfrUGG5 R_7VpuV01AhuGrPa1 R_3flMAjPtunCa2sq R_340Dt75o5SGfPuN R_5K3IrHRscJfT1PR R_2fSlMyNLZ8V5RPH R_325zzsmY98pykPQ R_24Jctc5S4ToBCvl R_1gb6UaIK2xRVZob R_4feXK4u0kkLCajN R_3qhKmmlCRBo6mpH R_7WCpfHCpZlAwfLJ "



foreach name in $list_remove_3 {
	replace inatt_open = 1 if ResponseId == "`name'"
}

global list_remove_4 ///
" R_1vgELUuRwpaZlp7 R_3aW1bOjnSlc2FIB R_3rUEucmkHIbaeTd R_3g15K86MIQqSWow R_3iaHxsweK2Hu9KF R_7pa6djqN8H56BKe R_7Ooxqh6uQ68SS4d R_3PhdHCLXTM00OhX R_3HqaR7PHdf8PqIS R_3QJy3atBEnctmlU R_6PdHGllpGoDD0hI R_2hi6hVJxwju9pL3 R_1hiGy53ouw6ybLj R_7scMn1ziDdSKMho R_1OCe3uVDeswOnUW R_8nDeKhsfVnmyPDj R_7jeZp5r12bNt8Ln R_6e8TTMaBC0Z1cUz R_1vBcPhHqVwHN18B R_3Lioe1WECfeS1AU R_4ghAiTolhS7w4ZX R_5TYMsJEXFZlUZyS R_5Gv1mwuOrtETQWx R_4zHF0XVnmaGoEdA R_4o6EX84SAlDhz8o R_5xFQEWbMYxU7ZLJ R_7gwkhRXwxnH80pn R_3dNfhVn3ssXHioy R_768RcE9MOOh8IjM R_41EDkZTL7RqCfyY R_3opeDH4IPXij4iJ R_7JqtJ7rTTcb121K R_7ZPnLUdI40OYsHC R_4QVz8XTy6bPS5gv R_2earZtl4Gox2v6h R_2tydf5inX78Vqhl R_1qWHIbgp9mVsaTd R_2wNwApaA3WpqqIN R_7DhIBuKZrqruIq8 R_2erYdhNPmqOQXnD R_1MWn8fvoVo29Y0U R_2ruvSk4RHzepqf4 R_5OicVwPwbtObGVQ R_7q3EePDbK9e49Ed R_3izYa6gZwnSe2op R_5GlBAbUkZhh1UhG R_5P1KmoDBrO3BsAg R_1PKKBBrOWnmxtiJ R_3DIw66taoDKeN0l R_5h3I5QtEd7HJkcS R_22GhHKA4KiW7o1r R_7tEXx8j1uXMcXrT R_7fz08rMfjdR7lHb R_1GbilJbit3FkT3r R_8nUFcFsjMBd5Ojb R_5xCP7jEydFezeT7 R_7XSBp2se8Ojvdq9 R_5rb8skI7tDgVq01 R_55fzc2iaFjrfRzr R_3SIkiDH7ugvTfJE R_3zYBvo04ljyQgoG R_7r7Y4SiyyWAcEyH R_2dE9NNs6TwUnAMJ R_73p5PEr5euY5WLC R_38UyJnnqatYkA3T R_7RsGDe2JLfYeVH8 R_5Q2XZxXmKX6hHR7 R_5ffBgtkGNFRXqid R_3hoxgUQ5TVkV9R0 R_2b3mUehVGA6D6Yg R_10KNr1dluSMWu2t R_31tXvfUFxTFsGum R_53lMRlYU63CTqev R_4PY1HfzXoEUBqa7"



foreach name in $list_remove_4 {
	replace inatt_open = 1 if ResponseId == "`name'"
}

* Drop these inattentive respondents
drop if inatt_open==1


********************************************************************
** Identify and drop respondents who gave inconsistent answers to ** 
** demographic questions between our Qualtrics survey and Cint    ** 
********************************************************************
* check answers on age and gender
destring age_lucid gender_lucid gender age, replace 
gen test_age = age - age_lucid 
gen test_gender = gender - gender_lucid

gen inacc_gender = 0 
label var inacc_gender "Divergenge gender btw Lucid and Qualtrics"
replace inacc_gender = 1 if abs(test_gender) == 1 // inaccurate if gender is misreported 

gen inacc_age = 0
label var inacc_age "Divergenge age btw Lucid and Qualtrics"
replace inacc_age = 1 if abs(test_age) > 1 //inaccurate age is misreported by more than 1 year


tab inacc_gender
tab inacc_age 

* Drop these inaccurate respondents
drop if inacc_age == 1
drop if (inacc_gender == 1 & gender != 3)


**********************************************************
** Drop respondents who answered always the same number ** 
** for both perceptions and expectations                **
**********************************************************
gen perceived_inflation_value=.
destring perc_pi_quant*, replace
replace perceived_inflation_value = perc_pi_quant1
replace perceived_inflation_value = -perc_pi_quant2 if missing(perceived_inflation_value)
label var perceived_inflation_value "Perceived inflation past 12 months"

gen expected_inflation_value=.
destring exp_pi_quant*, replace
replace expected_inflation_value = exp_pi_quant1
replace expected_inflation_value = -exp_pi_quant2 if missing(expected_inflation_value)
label var expected_inflation_value "expected inflation next 12 months"


destring perc_u, gen(perceived_unemployment_value)
label var perceived_unemployment_value "Perceived unemployment past 12 months"

destring exp_u, gen(expected_unemployment_value)
label var expected_unemployment_value "Expected unemployment next 12 months"

gen inattentive_expectations=0
replace inattentive_expectations=1 if (perceived_inflation_value == expected_inflation_value) &(expected_inflation_value==perceived_unemployment_value) & (perceived_unemployment_value==expected_unemployment_value)

* Drop these inattentive respondents
drop if inattentive_expectations==1


*****************************************************
** Drop respondents who supported both an increase **
** and a decrease in the interest rate.            **
*****************************************************
label define oppose_support 1 "Strongly oppose" 2 "Oppose somewhat" 3 "Neither support nor oppose" 4 "Support somewhat" 5 "Strongly support"
destring policy_1, gen(policy_increaserate)
label values policy_increaserate oppose_support
label var policy_increaserate "Increase interest rates to combat inflation"

destring policy_1_2, gen(policy_decreaserate)
label values policy_decreaserate oppose_support
label var policy_decreaserate "Decrease interest rates to combat inflation"

foreach var in policy_increaserate policy_decreaserate {
	gen dummy_`var' = 0 if !missing(`var')
	replace dummy_`var' = 1 if `var'==4 | `var'==5
	local lbl : variable label `var'
	label var dummy_`var' "Support `lbl'"
}


drop if dummy_policy_increaserate==1 & dummy_policy_decreaserate==1


*******************************************************
** Create variable reporting time spent on treatment **
*******************************************************
destring OL, replace force
destring OG, replace force
replace t_treatment_PageSubmit = OG if t_treatment_PageSubmit==.
replace t_treatment_PageSubmit = OL if t_treatment_PageSubmit==.


************************************
** Save the newly cleaned dataset **
************************************
save "$data/inflation_understanding_noinattentive.dta", replace



