**********************************************************************
** This code generates the indicators (dummy variables) used in the **
** analysis for all the questions. The sections correspond to those **
** in the survey, plus a section for additional indicators.         **
**********************************************************************


clear all

use "$data/inflation_understanding_encoded.dta", clear

**********************************************************************


*******************************************
** Complete and survey branch indicators **
*******************************************
{
destring complete, replace

destring policy_first inflation_first causes_first, replace
replace policy_first=0 if causes_first==1
replace causes_first=0 if policy_first==1
replace unemployment_first = 0 if inflation_first==1
replace inflation_first = 0 if unemployment_first==1
label var unemployment_first "Unemployment first in conjoint"
}


*********************************************************
** Pre-screening background questions and Demographics **
*********************************************************
{
*** Gender
gen women=.
replace women=0 if complete==1
replace women=1 if gender==2


*** Age
* Age groups indicators (coarser partition aggregating groups)
gen 			agegroup_agg=.
replace 		agegroup_agg=1 if age_group==1 
replace 		agegroup_agg=2 if age_group==2 | age_group==3
replace 		agegroup_agg=3 if age_group==4 | age_group==5
label define 	agegroup_agg 1 "18-29" 2 "30-49" 3 "50-69"
label val 		agegroup_agg agegroup_agg

tab agegroup_agg, gen(agegroup_agg_)

gen age_class_agg= 0 if !mi(age)
replace age_class_agg=1 if age >= 18 & age <= 29
replace age_class_agg=2 if age >= 30 & age <= 49
replace age_class_agg=3 if age >= 50 & age <= 69
label define age_class_agg 1 "18-29" 2 "30-49" 3 "50-69"
label val age_class_agg age_class_agg

* Age groups indicators (fine partition)
gen 	age_1829=.
replace age_1829=0 if complete == 1
replace age_1829=1 if age_group == 1
  
gen 	age_3039=.  
replace age_3039=0 if complete == 1
replace age_3039=1 if age_group == 2
  
gen 	age_4049=.  
replace age_4049=0 if complete == 1
replace age_4049=1 if age_group == 3
  
gen 	age_5059=.  
replace age_5059=0 if complete == 1
replace age_5059=1 if age_group == 4
  
gen 	age_6069=.  
replace age_6069=0 if complete == 1
replace age_6069=1 if age_group == 5

* Young/old indicators
gen 	young =.
replace young = 0 if complete == 1
replace young = 1 if age_group == 1 

gen old=.
replace old=0 if complete==1
replace old=1 if age_group==4 | age_group==5

label var agegroup_agg_1 "18-29 years old"
label var agegroup_agg_2 "30-49 years old"
label var agegroup_agg_3 "50-69 years old"


*** Income 
* Income group (coarser partition aggregating groups)
gen 			incomegroup_agg =.
replace 		incomegroup_agg = 1 if income_group == 1 | income_group == 2
replace 		incomegroup_agg = 2 if income_group == 3 | income_group == 4 | income_group == 5 
replace 		incomegroup_agg = 3 if  income_group == 6
label define 	incomegroup_agg 1 "0k-39k" 2 "40k-124k" 3 "124k+"
label val 		incomegroup_agg incomegroup_agg

gen 	rich = 0
replace rich = 1 if incomegroup_agg >= 3

tab incomegroup_agg, gen(incomegroup_agg_)


*** Race
* Race indicators 
gen 	race_white=.
replace race_white=0 if complete==1
replace race_white=1 if race==1

gen 	race_black=.
replace race_black=0 if complete==1
replace race_black=1 if race==2

gen 	race_hisp=.
replace race_hisp=0 if complete==1
replace race_hisp=1 if race==3

gen 	race_asian=.
replace race_asian=0 if complete==1
replace race_asian=1 if race==4

gen 	race_mixed=.
replace race_mixed=0 if complete==1
replace race_mixed=1 if race==5

gen 	race_other=.
replace race_other=0 if complete==1
replace race_other=1 if race==6

gen 			race_group = "White" 	if complete==1
replace 		race_group = "Black" 	if(race==2 & complete==1)
replace 		race_group = "Hispanic" if(race==3 & complete==1)
replace 		race_group = "Other" 	if(race>3 & complete==1)
label define 	race_agg 0 "White" 1 "Black" 2 "Hispanic" 3 "Other"
encode 			race_group, gen(race_agg) label(race_agg)



*** Education
* Education groups indicators (coarser partition aggregating groups)
gen 	education_agg=.
replace education_agg=1 if education_level==1 | education_level==2 
replace education_agg=2 if education_level==3 | education_level==4 | education_level==5
replace education_agg=3 if education_level==6 | education_level==7 
replace education_agg=4 if education_level==8 | education_level==9 
label define education_agg 1 "Less than HS" 2 "Less than 4-year college" 3 "4-year college/Master's" 4 "Professional degree"
label val education_agg education_agg

gen 	education_agg_quota=.
replace education_agg_quota=1 if education_level==1 | education_level==2 |  education_level==3 | education_level==4 | education_level==5
replace education_agg_quota=2 if education_level==6 | education_level==7 
replace education_agg_quota=3 if education_level==8 | education_level==9 
label define education_agg_quota 1 "Less than 4-year college" 2 "4-year college/Master's" 3 "Professional degree"
label val education_agg education_agg

* Education indicators
gen 	educ_low=0 if complete==1
replace educ_low=1 if education_level==1 | education_level==2 

gen 	educ_mid=0 if complete==1
replace educ_mid=1 if education_level==3 | education_level==4 | education_level==5

gen		educ_high=0 if complete==1
replace educ_high=1 if education_level==6 | education_level==7 

gen 	educ_veryhigh = 0 if complete==1
replace educ_veryhigh = 1 if education_level==8 | education_level==9

* Note: college is defined as having a 4-year college degree. 
gen 			college=.
replace 		college=0 if complete==1
replace 		college=1 if education_level>5 
label define 	college_degree 0 "No College" 1 "4-year College Degree"
label val 		college college_degree
label var 		college "College Degree"

gen no_college = 1 if college==0
	replace no_college = 0 if college==1
label var no_college "No College Degree"

tab education_agg, gen(education_agg_)
label var education_agg_2 "Less than 4-year college"
label var education_agg_3 "4-year college/Master's"
*label var education_agg_4 "Professional degree"

replace econ_studies = econ_studies -1
replace econ_studies=0 if econ_studies==.
label var econ_studies "Studied economics"


**** Employment status
gen employment_agg = 1 if complete==1
	replace employment_agg = 2 if(complete==1 & employment_status<4)
	replace employment_agg = 3 if(complete==1 & employment_status==4 |complete==1 & employment_status==6)
label define employment_agg 1 "Student" 2 "Working" 3 "Not working"
label val employment_agg employment_agg

* Employment regression
gen employment_group = 1 if complete==1 & employment_status<4
	replace employment_group = 2 if(complete==1 & employment_status==4)
	replace employment_group = 3 if(complete==1 & employment_status==5 |complete==1 & employment_status==6)
label define employment_group 1 "Employed" 2 "unemployed" 3 "Out of labor force"
label val employment_group employment_group
tab employment_group, gen(employment_group_)


*** Children indicators
gen kids=.
replace kids=0 if complete==1
replace kids=1 if nb_child>0
label define kids 0 "No kids" 1 "Has kids"
label val kids kids
label var kids "Has children"


*** Political affiliation
*Republican-Democrat indicators
gen republican=.
replace republican=0 if complete==1
replace republican=1 if political_party==1

gen democrat=.
replace democrat=0 if complete==1
replace democrat=1 if political_party==2

gen independent = .
replace independent=0 if complete==1
replace independent=1 if political_party>2 & political_party!=.

gen political_agg = 1 if(complete==1 & political_party==2)
	replace political_agg = 2 if(complete==1 & political_party==1)
	replace political_agg = 3 if(complete==1 & political_party>2)
label define political_agg 1 "Democrat" 2 "Republican" 3 "Independent and others"
label val political_agg political_agg

label var democrat "Democrat"
label var republican "Republican"
label var independent "Independent"

* Additional single indicators and labels
tab race_agg, gen(race_agg_)
tab age_class_agg, gen(age_class_agg_)
tab political_agg, gen(political_agg_)
tab employment_agg, gen(employment_agg_)
label var age_class_agg_2 "Age 30-49"
label var age_class_agg_3 "Age 50-69"
label var political_agg_2 "Republican"
label var incomegroup_agg_1 "Income \$<\$40k"
label var incomegroup_agg_2 "Income between 40k and 125k"
label var incomegroup_agg_3 "Income \$>\$125k"
label var women "Female"
label var employment_agg_2 "Working"
label var employment_agg_3 "Not working"
label var employment_group_2 "Unemployed"
label var employment_group_3 "Out of labor force"


*** Trust in news
foreach var in news_trust_social_media news_trust_cnn news_trust_msnbc news_trust_fox news_trust_network news_trust_localtv news_trust_npr news_trust_amtalk news_trust_nyt news_trust_wsj news_trust_localpapers news_trust_other{
	gen dummy_`var' = 0 if !missing(`var')
	replace dummy_`var' = 1 if `var' <3
	label var dummy_`var' " 1 if trust `var'"
}

gen inattentive_news=news_cnn+news_fox+news_social_media+news_msnbc + news_network+news_localtv+news_npr+news_amtalk+news_nyt+news_wsj+news_localpapers


*** Marital status
tab marital_status, gen(marital_status_)

}


**********************************************
** Economic Information about the household **
**********************************************
{
gen dummy_own_vehicle = 0 if !missing(own_vehicle)
replace dummy_own_vehicle = 1 if own_vehicle==1
label var dummy_own_vehicle "Owns a vehicle"

tab own_or_rent, gen(dummy_own_rent_)
label var dummy_own_rent_1 "Owns primary residence"
label var dummy_own_rent_2 "Rents primary residence"
*label var dummy_own_rent_3 "No primary residence"

gen rent_value_midp = 0 if dummy_own_rent_2==0
replace rent_value_midp = 200 if rent_value ==1
replace rent_value_midp = 450 if rent_value ==2
replace rent_value_midp = 575 if rent_value ==3
replace rent_value_midp = 725 if rent_value ==4
replace rent_value_midp = 875 if rent_value ==5
replace rent_value_midp = 1025 if rent_value ==6
replace rent_value_midp = 1200 if rent_value ==7
replace rent_value_midp = 1400 if rent_value ==8
replace rent_value_midp = 2000 if rent_value ==9
replace rent_value_midp = 2500 if rent_value ==10
label var rent_value_midp "Midpoint estimated value of rent"

gen dummy_mortgage = 0 if !missing(mortgage)
replace dummy_mortgage = 1 if mortgage==1
label var dummy_mortgage "Has a mortgage"

gen mortgage_value_midp=0 if dummy_mortgage==0
replace mortgage_value_midp=12500 if mortgage_value==1
replace mortgage_value_midp=37500 if mortgage_value==2
replace mortgage_value_midp=62500 if mortgage_value==3
replace mortgage_value_midp=87500 if mortgage_value==4
replace mortgage_value_midp=112500 if mortgage_value==5
replace mortgage_value_midp=137500 if mortgage_value==6
replace mortgage_value_midp=175000 if mortgage_value==7
replace mortgage_value_midp=225000 if mortgage_value==8
replace mortgage_value_midp=300000 if mortgage_value==9
replace mortgage_value_midp=350000 if mortgage_value==10
replace mortgage_value_midp=0 if mortgage_value_midp==.
label var mortgage_value_midp "Midpoint estimated value of mortgage"

gen house_value_midp=0 if dummy_own_rent_1==0
replace house_value_midp=25000 if house_value==1
replace house_value_midp=75000 if house_value==2
replace house_value_midp=125000 if house_value==3
replace house_value_midp=175000 if house_value==4
replace house_value_midp=225000 if house_value==5
replace house_value_midp=275000 if house_value==6
replace house_value_midp=325000 if house_value==7
replace house_value_midp=400000 if house_value==8
replace house_value_midp=550000 if house_value==9
replace house_value_midp=650000 if house_value==10
label var house_value_midp "Midpoint estimated value of house"


gen dummy_checkings = 0 if !missing(checkings)
replace dummy_checkings = 1 if checkings==1
label var dummy_checkings "Has checkings"

gen checkings_value_midp=0 if dummy_checkings==0
replace checkings_value_midp=100 if checkings_value==1
replace checkings_value_midp=450 if checkings_value==2
replace checkings_value_midp=1000 if checkings_value==3
replace checkings_value_midp=1650 if checkings_value==4
replace checkings_value_midp=2500 if checkings_value==5
replace checkings_value_midp=4000 if checkings_value==6
replace checkings_value_midp=7000 if checkings_value==7
replace checkings_value_midp=14000 if checkings_value==8
replace checkings_value_midp=30000 if checkings_value==9
replace checkings_value_midp=40000 if checkings_value==10
label var checkings_value_midp "Midpoint estimated value of checkings"

gen dummy_shortsave = 0 if !missing(short_save)
replace dummy_shortsave = 1 if short_save==1
label var dummy_shortsave "Has short savings"

gen shortsave_value_midp=0 if dummy_shortsave==0
replace shortsave_value_midp=500 if short_save_value==1
replace shortsave_value_midp=1500 if short_save_value==2
replace shortsave_value_midp=3500 if short_save_value==3
replace shortsave_value_midp=7500 if short_save_value==4
replace shortsave_value_midp=12500 if short_save_value==5
replace shortsave_value_midp=22500 if short_save_value==6
replace shortsave_value_midp=40000 if short_save_value==7
replace shortsave_value_midp=75000 if short_save_value==8
replace shortsave_value_midp=125000 if short_save_value==9
replace shortsave_value_midp=150000 if short_save_value==10
label var shortsave_value_midp "Midpoint estimated value of short savings"


gen dummy_mutual_etf = 0 if !missing(mutual_etf)
replace dummy_mutual_etf = 1 if mutual_etf==1
label var dummy_mutual_etf "Has mutual funds/ETF shares"

gen mutualetf_value_midp=0 if dummy_mutual_etf==0
replace mutualetf_value_midp=5000 if  mutual_etf_value==1
replace mutualetf_value_midp=17500 if  mutual_etf_value==2
replace mutualetf_value_midp=37500 if  mutual_etf_value==3
replace mutualetf_value_midp=62500 if  mutual_etf_value==4
replace mutualetf_value_midp=87500 if  mutual_etf_value==5
replace mutualetf_value_midp=150000 if  mutual_etf_value==6
replace mutualetf_value_midp=300000 if  mutual_etf_value==7
replace mutualetf_value_midp=550000 if  mutual_etf_value==8
replace mutualetf_value_midp=1200000 if  mutual_etf_value==9
replace mutualetf_value_midp=1700000 if  mutual_etf_value==10
label var mutualetf_value_midp "Midpoint estimated value of etf mutual funds"
}


*******************************************************
** Perceived and expected inflation and unemployment **
*******************************************************
{
gen dummy_perceived_inflation = 0 if !missing(perceived_inflation)
replace dummy_perceived_inflation=1 if perceived_inflation==1
label var dummy_perceived_inflation "Perceived inflation"

gen dummy_perceived_deflation = 0 if !missing(perceived_inflation)
replace dummy_perceived_deflation=1 if perceived_inflation==2
label var dummy_perceived_deflation "Perceived deflation"

gen dummy_expected_inflation = 0 if !missing(expected_inflation)
replace dummy_expected_inflation=1 if expected_inflation==1
label var dummy_expected_inflation "Expected inflation"

gen dummy_expected_deflation = 0 if !missing(expected_inflation)
replace dummy_expected_deflation=1 if expected_inflation==2
label var dummy_expected_deflation "Expected deflation"


gen misperception_pi = perceived_inflation_value-3.4
gen abs_misperception_Pi = abs(misperception_pi)
label var abs_misperception_Pi "Misperception of realized inflation"

gen misperception_u = perceived_unemployment_value-3.7
gen abs_misperception_u = abs(misperception_u)
label var abs_misperception_u "Misperception of realized unemployment"

sum abs_misperception_Pi, d
gen above_misp_pi =1 if abs_misperception_Pi> r(p50)
replace above_misp_pi =0 if abs_misperception_Pi<= r(p50)
label var above_misp_pi "Above median misperception of realized inflation"

sum abs_misperception_u, d
gen above_misp_u =1 if abs_misperception_u> r(p50)
replace above_misp_u =0 if abs_misperception_u<= r(p50)
label var above_misp_u "Above median misperception of realized unemployment"


}


*********************************************************************
** Conjoint Experiment: Preferences for inflation and unemployment **
*********************************************************************
{
	
foreach var in conjoint_1 conjoint_2 conjoint_3 conjoint_4 conjoint_5{
	gen dummy_`var'_1 = 0 if !missing(`var')
	replace dummy_`var'_1 = 1 if `var'==1
	label var dummy_`var'_1 "In `var' chose pair 1"
	
	gen dummy_`var'_2 = 0 if !missing(`var')
	replace dummy_`var'_2 = 1 if `var'==2
	label var dummy_`var'_2 "In `var' chose pair 2"
	
}

}


*****************************************************************
** Conditional correlations between inflation and unemployment **
*****************************************************************
{
foreach var in corr_interest_pi corr_interest_u corr_lowincomesupport_pi corr_lowincomesupport_u corr_oil_pi corr_oil_u corr_tech_pi corr_tech_u corr_wage_pi corr_wage_u{
	gen dummy_`var' = 0 if !missing(`var')
	replace dummy_`var' = 1 if `var'==4 | `var'==5
	label var dummy_`var' "`var' increases"
	
	gen dummy_`var'_d = 0 if !missing(`var')
	replace dummy_`var'_d = 1 if `var'==1 | `var'==2
	label var dummy_`var'_d "`var' increases"
}

gen correct_corr_interest=0
replace correct_corr_interest = 1 if (corr_interest_pi==1 | corr_interest_pi==2)&(corr_interest_u==4 | corr_interest_u==5)

gen correct_corr_lowincome=0
replace correct_corr_lowincome=1 if (corr_lowincomesupport_pi==4 | corr_lowincomesupport_pi==5) & (corr_lowincomesupport_u==1 | corr_lowincomesupport_u==2)

gen correct_corr_oil =0 
replace correct_corr_oil=1 if (corr_oil_pi==4 | corr_oil_pi==5) & (corr_oil_u==4 | corr_oil_u==5)

gen correct_corr_wage=0
replace correct_corr_wage=1 if (corr_wage_pi==4 | corr_wage_pi==5) & (corr_wage_u==4 | corr_wage_u==5)

gen correct_corr = correct_corr_interest+correct_corr_lowincome+correct_corr_oil+correct_corr_wage
label var correct_corr "Number of correct answers to conditional correlations"

gen inattentive_corr=0
replace inattentive_corr=1 if (corr_interest_pi==corr_interest_u) & (corr_interest_u==corr_lowincomesupport_pi) & (corr_lowincomesupport_pi==corr_lowincomesupport_u) & (corr_lowincomesupport_u==corr_oil_pi) & (corr_oil_pi==corr_oil_u) & (corr_oil_u==corr_wage_pi) & (corr_wage_pi==corr_wage_u) & (corr_wage_u == corr_tech_pi) & (corr_tech_pi==corr_tech_u)
}


*************************
** Causes of inflation **
*************************
{
foreach var in cause_gvt_1 cause_gvt_2 cause_gvt_3 cause_gvt_4 cause_gvt_5 cause_fed_1 cause_fed_2 cause_fed_3 cause_fed_4 cause_fed_5 cause_costs_1 cause_costs_2 cause_costs_3 cause_costs_4 cause_costs_5 cause_labor_1 cause_labor_2 cause_labor_3 cause_firms_1 cause_firms_2 cause_firms_3 cause_hh_1 cause_hh_2 cause_actor_gvt cause_actor_fed cause_actor_costs cause_actor_labor cause_actor_politics cause_actor_hh cause_actor_firms {
	gen dummy_`var' = 0 if !missing(`var')
	local lbl : variable label `var'
	replace dummy_`var' = 1 if `var'==3 | `var'==4
	label var dummy_`var' "`lbl'"
}

gen inattentive_cause=0
replace inattentive_cause=1 if (cause_actor_gvt==cause_actor_fed) & (cause_actor_fed==cause_actor_costs) & (cause_actor_costs==cause_actor_labor) & (cause_actor_labor==cause_actor_politics) & (cause_actor_politics==cause_actor_hh) & (cause_actor_hh==cause_actor_firms)


}


*****************************************
** Distributional impacts of inflation **
*****************************************
{
foreach var in distr_highincome distr_midincome distr_lowincome distr_young distr_midage distr_old distr_unemp distr_emp distr_retire distr_cash distr_finassets distr_nosave distr_ccdebt distr_fixrate distr_flexrate distr_nodebt distr_smallfirms distr_bigfirms {
	gen dummy_`var' = 0 if !missing(`var')
	replace dummy_`var' = 1 if `var'==1 | `var'==2
	local lbl : variable label `var'
	local dist_lbl: subinstr local lbl "distributional" "lost", all
	di "`dist_lbl'"
	label var dummy_`var' "`dist_lbl'"
}
foreach var of varlist dummy_distr_*{
	egen `var'_std = std(`var')
}

replace dummy_distr_highincome_std = -dummy_distr_highincome_std

egen temp_tot_distr_loss=rowtotal(dummy_distr*_std)
replace temp_tot_distr_loss = (temp_tot_distr_loss -dummy_distr_smallfirms - dummy_distr_bigfirms)/16
egen tot_distr_loss = std(temp_tot_distr_loss)
label var tot_distr_loss "Total perceived distributional losses"
drop temp_tot_distr_loss dummy_distr_*_std

** Withing group index of variability **
gen temp_distr_income = (abs(distr_highincome - distr_midincome) + abs(distr_highincome-distr_lowincome) + abs(distr_midincome - distr_lowincome))/3
egen distr_income = std(temp_distr_income)

gen temp_distr_age = (abs(distr_old - distr_young) + abs(distr_old-distr_midage) + abs(distr_midage - distr_young))/3
egen distr_age = std(temp_distr_age)

gen temp_distr_emp = (abs(distr_unemp - distr_emp) + abs(distr_unemp-distr_retire) + abs(distr_retire - distr_emp))/3
egen distr_occ = std(temp_distr_emp)

gen temp_distr_save = (abs(distr_cash - distr_finassets) + abs(distr_cash-distr_nosave) + abs(distr_nosave - distr_finassets))/3
egen distr_save = std(temp_distr_save)

gen temp_distr_debt = (abs(distr_ccdebt-distr_fixrate)+abs(distr_ccdebt-distr_flexrate)+abs(distr_ccdebt-distr_nodebt)+abs(distr_fixrate-distr_flexrate)+abs(distr_fixrate-distr_nodebt)+abs(distr_flexrate - distr_nodebt))/4
egen distr_debt = std(temp_distr_debt)

gen temp_distr_index = (distr_income+distr_age+distr_occ+distr_save+distr_debt)/5
egen distr_index = std(temp_distr_index)
label var distr_index "Index of perceived distributional losses"

drop temp_distr_*

* Indicator for "Low income lost more than high income"
gen low_inc_lost_more=.
replace low_inc_lost_more=1 if distr_lowincome< distr_highincome
replace low_inc_lost_more=0 if distr_lowincome>= distr_highincome
label var low_inc_lost_more "Low income lost more than high income"

* Indicator for respondents giving all similar answers
gen inattentive_distr=0
replace inattentive_distr=1 if (distr_highincome==distr_midincome) & (distr_midincome==distr_lowincome) & (distr_lowincome==distr_young) & (distr_young==distr_midage) & (distr_midage==distr_old) & (distr_old==distr_unemp) & (distr_unemp==distr_emp) & (distr_emp==distr_retire) & (distr_retire==distr_cash) & (distr_cash==distr_finassets) & (distr_finassets==distr_nosave) & (distr_nosave==distr_ccdebt) & (distr_ccdebt==distr_fixrate) & (distr_fixrate==distr_flexrate) & (distr_flexrate==distr_nodebt) & (distr_nodebt==distr_smallfirms) & (distr_smallfirms==distr_bigfirms)

                 
}


**********************************************
** Consequences of inflation on the economy **
**********************************************
{
gen dummy_cons_budgeting = 0 if !missing(cons_budgeting)
replace dummy_cons_budgeting = 1 if cons_budgeting==1 | cons_budgeting==2
label var dummy_cons_budgeting "Inflation makes budgeting harder"

gen dummy_cons_uncertain = 0 if !missing(cons_uncertain)
replace dummy_cons_uncertain = 1 if cons_uncertain==4 | cons_uncertain==5
label var dummy_cons_uncertain "Inflation makes household more uncertain"

gen dummy_cons_inconvinience = 0 if !missing(cons_inconvinience)
replace dummy_cons_inconvinience = 1 if cons_inconvinience==3 | cons_inconvinience==4
label var dummy_cons_inconvinience "Holding more cash due to inflation is an inconvinience"

gen dummy_cons_setprices = 0 if !missing(cons_setprices)
replace dummy_cons_setprices = 1 if cons_setprices==1 | cons_setprices==2
label var dummy_cons_setprices "Inflation makes firms' price-setting decisions more difficult"

gen dummy_cons_firmsdecisions = 0 if !missing(cons_firmsdecisions)
replace dummy_cons_firmsdecisions = 1 if cons_firmsdecisions==1 | cons_firmsdecisions==2
label var dummy_cons_firmsdecisions "Inflation makes firms' decisions more difficult"

gen dummy_cons_pdifferential = 0 if !missing(cons_pdifferential)
replace dummy_cons_pdifferential = 1 if cons_pdifferential==1 | cons_pdifferential==2
label var dummy_cons_pdifferential "Inflation-induced price differentials are negative"

gen dummy_cons_gdpgrowth = 0 if !missing(cons_gdpgrowth)
replace dummy_cons_gdpgrowth = 1 if cons_gdpgrowth==1 | cons_gdpgrowth==2
label var dummy_cons_gdpgrowth "Inflation slows down GDP growth"

gen dummy_cons_dollarvalue = 0 if !missing(cons_dollarvalue)
replace dummy_cons_dollarvalue = 1 if cons_dollarvalue==1 | cons_dollarvalue==2
label var dummy_cons_dollarvalue "Inflation decreases value of the dollar relative to other currencies"

gen dummy_cons_prestige = 0 if !missing(cons_prestige)
replace dummy_cons_prestige = 1 if cons_prestige==1 | cons_prestige==2
label var dummy_cons_prestige "Inflation decreases national prestige"

gen dummy_cons_inequality = 0 if !missing(cons_inequality)
replace dummy_cons_inequality = 1 if cons_inequality==4 | cons_inequality==5
label var dummy_cons_inequality "Inflation leads to higher inequality"

gen dummy_cons_cohesion = 0 if !missing(cons_cohesion)
replace dummy_cons_cohesion = 1 if cons_cohesion==4 | cons_cohesion==5
label var dummy_cons_cohesion "Inflation decreases social cohesion"

gen dummy_cons_gvttrust = 0 if !missing(cons_gvttrust)
replace dummy_cons_gvttrust = 1 if cons_gvttrust==4 | cons_gvttrust==5
label var dummy_cons_gvttrust "Inflation decreases trust in government"

foreach var of varlist dummy_cons_* {
	egen `var'_std = std(`var')
}

egen temp_tot_cons_loss = rowtotal(dummy_cons*_std)
replace temp_tot_cons_loss=temp_tot_cons_loss/12
egen tot_cons_loss=std(temp_tot_cons_loss)
label var tot_cons_loss "Total perceived negative consequences"
drop temp_tot_cons_loss 

tab cons_top, gen(dummy_cons_top_)
label var dummy_cons_top_1 "Households decisions more complicated top consequence"
label var dummy_cons_top_2 "Households uncertainty top consequence"
label var dummy_cons_top_3 "Shoe leather cost top consequence"
label var dummy_cons_top_12 "Firms' pricing decisions more complicated top consequence"
label var dummy_cons_top_4 "Firms' ordinary decisions more complicated top consequence"
label var dummy_cons_top_5 "Resource misallocation top consequence"
label var dummy_cons_top_6 "Slow down growth top consequence"
label var dummy_cons_top_7 "Decrease value of the dollar top consequence"
label var dummy_cons_top_8 "Decrease national prestige top consequence"
label var dummy_cons_top_9 "Increase inequality top consequence"
label var dummy_cons_top_10 "Decrease social cohesion top consequence"
label var dummy_cons_top_11 "Decrease trust in Federal government top consequence"

gen cons_polecon_temp=(dummy_cons_gvttrust_std+dummy_cons_cohesion_std+dummy_cons_inequality_std+dummy_cons_prestige_std)/4
egen cons_polecon = std(cons_polecon_temp) 
label var cons_polecon  "Political \& social costs (trust in govt, social cohesion, inequality, lower natl. prestige)"
drop cons_polecon_temp 

gen cons_efficiency_temp=(dummy_cons_dollarvalue_std+dummy_cons_gdpgrowth_std+dummy_cons_pdifferential_std+dummy_cons_setprices_std+dummy_cons_inconvinience_std+dummy_cons_firmsdecisions_std)/6
egen cons_efficiency = std(cons_efficiency_temp) 
label var cons_efficiency "Efficiency costs (dollar value, GDP growth, resource misalloc., menu \& shoeleather costs, firms daily decisions)"
drop cons_efficiency_temp 

gen cons_cognitive_temp=(dummy_cons_budgeting_std+dummy_cons_uncertain_std)/2
egen cons_cognitive = std(cons_cognitive_temp) 
label var cons_cognitive  "Cognitive costs (uncertainty \& complex budgeting)"
drop cons_cognitive_temp  dummy_cons_*std

gen top_cons_polecon=0
replace top_cons_polecon=1 if dummy_cons_top_11 ==1 | dummy_cons_top_10==1 |dummy_cons_top_9==1 |dummy_cons_top_8 ==1
label var top_cons_polecon `" "Top consequence is polecon" "'

gen top_cons_efficiency=0
replace top_cons_efficiency = 1 if dummy_cons_top_3 ==1 | dummy_cons_top_12 ==1 | dummy_cons_top_5 ==1 | dummy_cons_top_6 ==1 | dummy_cons_top_7 ==1 
label var top_cons_efficiency "Top consequence is efficiency related"

gen top_cons_cognitive=0
replace top_cons_cognitive = 1 if dummy_cons_top_1 ==1 | dummy_cons_top_2 ==1 | dummy_cons_top_12 ==1 
label var top_cons_cognitive "Top consequence is cognitive related"

* Indicator for respondents giving all similar answers
gen inattentive_cons=0
replace inattentive_cons=1 if (cons_budgeting==cons_cohesion) & (cons_cohesion==cons_dollarvalue) & (cons_dollarvalue==cons_firmsdecisions) & (cons_firmsdecisions==cons_gdpgrowth) & (cons_gdpgrowth==cons_gvttrust) & (cons_gvttrust==cons_inconvinience) & (cons_inconvinience==cons_inequality) & (cons_inequality==cons_pdifferential) & (cons_pdifferential==cons_prestige) & (cons_prestige==cons_setprices) & (cons_setprices==cons_uncertain)

           
}


*******************************
** First stage and treatment **
*******************************
{
label var treatment "Video information treatment"
label var conjoint_info "Exact values treatment"
label var policy_first "Policy first"

gen double_treated = treatment * conjoint_info
label var double_treated "Video information treatment \$\times\$ Exact values treatment"

gen double_order_treated = treatment * policy_first
label var double_order_treated "Saw the video"

gen dummy_first_stage =0 if !missing(first_stage)
replace dummy_first_stage=1 if first_stage==4 | first_stage==5
label var dummy_first_stage "Inflation is an unfortunate side effect"
}


******************
** Policy views **
******************
{
* Note: Variables recording answers to questions about increase or decrease rates are destringed and aggregated in the code file "replication_package\code\data_cleaning\2_inattentives.do"	

foreach var in  policy_antitrust policy_announcement policy_decreasemsupply policy_debtreduce_highinc policy_debtreduce_midinc policy_debtreduce_lowinc policy_transfer_highinc policy_corporatetaxes policy_pricecaps policy_wagecaps policy_imports policy_redib_lowinctransf policy_redib_stamps policy_redib_vouch_lowinc policy_redib_vouch_midinc policy_redib_minwage{
	gen dummy_`var' = 0 if !missing(`var')
	replace dummy_`var' = 1 if `var'==4 | `var'==5
	local lbl : variable label `var'
	label var dummy_`var' "Support `lbl'"
}

gen dummy_priority_stability = 0 if !missing(priority_stability)
replace dummy_priority_stability = 1 if priority_stability==3 | priority_stability==4
label var dummy_priority_stability "Price stability important priority"


foreach var in policy_tradeoff_spend policy_tradeoff_growth policy_tradeoff_debt policy_tradeoff_unemp{
	gen dummy_`var' = 0 if !missing(`var')
	replace dummy_`var' = 1 if `var'==3 | `var'==4
	local lbl : variable label `var'
	label var dummy_`var' "`lbl'"
}

foreach var in policy_sideffects policy_booms{
	gen dummy_`var' = 0 if !missing(`var')
	replace dummy_`var' = 1 if `var'==1 | `var'==2
	local lbl : variable label `var'
	label var dummy_`var' "`lbl'"
}

gen dummy_policy_signal = 0 if !missing(policy_signal)
replace dummy_policy_signal = 1 if policy_signal==3
label var dummy_policy_signal "Inflation sign of a good economy"

***ranking economic issues
destring priority_2_*, replace
gen dummy_inf_first_ec = 0 if !missing(priority_2_1)
replace dummy_inf_first_ec=1 if priority_2_1==1
label var dummy_inf_first_ec "Inflation first among economic issues"

gen dummy_lowu_first_ec = 0 if !missing(priority_2_2)
replace dummy_lowu_first_ec=1 if priority_2_2==1
label var dummy_lowu_first_ec "Low unemployment first among economic issues"

gen dummy_growth_first_ec = 0 if !missing(priority_2_3)
replace dummy_growth_first_ec=1 if priority_2_3==1
label var dummy_growth_first_ec "Growth first among economic issues"

gen dummy_defense_first_ec = 0 if !missing(priority_2_4)
replace dummy_defense_first_ec=1 if priority_2_4==1
label var dummy_defense_first_ec "National defense first among economic issues"

gen dummy_finstab_first_ec = 0 if !missing(priority_2_5)
replace dummy_finstab_first_ec=1 if priority_2_5==1
label var dummy_finstab_first_ec "Financial stability first among economic issues"

***ranking social issues
destring priority_3_*, replace
gen dummy_inf_first_sc = 0 if !missing(priority_3_1)
replace dummy_inf_first_sc=1 if priority_3_1==1
label var dummy_inf_first_sc "Inflation first among social issues"

gen dummy_gun_first_sc = 0 if !missing(priority_3_2)
replace dummy_gun_first_sc=1 if priority_3_2==1
label var dummy_gun_first_sc "Gun rights first among social issues"

gen dummy_abortion_first_sc = 0 if !missing(priority_3_3)
replace dummy_abortion_first_sc=1 if priority_3_3==1
label var dummy_abortion_first_sc "Access to abortion among social issues"

gen dummy_civil_first_sc = 0 if !missing(priority_3_4)
replace dummy_civil_first_sc=1 if priority_3_4==1
label var dummy_civil_first_sc "Civil rights first among social issues"

gen dummy_educ_first_sc = 0 if !missing(priority_3_5)
replace dummy_educ_first_sc=1 if priority_3_5==1
label var dummy_educ_first_sc "Education first among social issues"

gen dummy_health_first_sc = 0 if !missing(priority_3_6)
replace dummy_health_first_sc=1 if priority_3_6==1
label var dummy_health_first_sc "Health first among social issues"


* Indicator for respondents giving all similar answers
gen inattentive_policy=0
replace inattentive_policy = 1 if (policy_increaserate==policy_decreaserate) & (policy_decreaserate==policy_antitrust) & (policy_antitrust==policy_announcement) & (policy_announcement==policy_decreasemsupply) & (policy_decreasemsupply==policy_debtreduce_highinc) & (policy_debtreduce_highinc==policy_debtreduce_midinc) & (policy_debtreduce_midinc==policy_debtreduce_lowinc) & (policy_debtreduce_lowinc==policy_transfer_highinc) & (policy_transfer_highinc==policy_corporatetaxes) & (policy_corporatetaxes==policy_pricecaps)& (policy_pricecaps==policy_wagecaps) & (policy_imports==policy_wagecaps) & (policy_imports==policy_redib_lowinctransf) & (policy_redib_lowinctransf==policy_redib_stamps) & (policy_redib_stamps==policy_redib_vouch_lowinc) & (policy_redib_vouch_lowinc==policy_redib_vouch_midinc) & (policy_redib_vouch_midinc==policy_redib_minwage)
                 
gen total_inattentive = inattentive_cause+inattentive_cons+inattentive_corr+inattentive_distr+inattentive_expectations+inattentive_policy




foreach var of varlist dummy_policy_tradeoff_unemp dummy_policy_tradeoff_spend dummy_policy_tradeoff_growth dummy_policy_tradeoff_debt dummy_policy_booms dummy_policy_signal dummy_policy_sideffects dummy_first_stage {
	egen `var'_std = std(`var')

}

gen index_tradeoffs_temp_1 = (dummy_policy_tradeoff_unemp_std + dummy_policy_tradeoff_spend_std + dummy_policy_tradeoff_growth_std  )/3
gen index_tradeoffs_temp_2 = ( dummy_policy_booms_std +  dummy_policy_signal_std + dummy_first_stage_std  )/3

egen index_tradeoffs_policy = std(index_tradeoffs_temp_1)
label var index_tradeoffs_policy "Policy needs to reduce economic activity to fight inflation (e.g., reduce growth)"

egen index_tradeoffs_good = std(index_tradeoffs_temp_2)
label var index_tradeoffs_good "Inflation perceived as by-product of a good economy (e.g., more often in a boom)"
}




***************************
** ADDITIONAL INDICATORS **
***************************


** Indicators for unemployment years **
{
gen years_unemployment_modified = " " + subinstr(years_unemployment,","," ",.) + " "
gen yob = 2024- age
gen yow = yob + 25
gen denom_weight = .
local j 1968
forvalues x = 1(1)57{
	gen unemployed_in_`j' = 0 if !missing(years_unemployment)
	replace unemployed_in_`j'= 1 if strpos(years_unemployment_modified, " `x' ") > 0	
	local ++j 
	
}

forvalues x=1968(1)2024{
	replace  unemployed_in_`x' = 0 if `x'< yow
}

forvalues x = 1968(1)2024{
	gen weight_unemp_`x' = `x' - yow
	replace weight_unemp_`x' = 0 if weight_unemp_`x' <0
}
egen weight_denom = rowtotal(weight_unemp_*)

forvalues x = 1968(1)2024{
	gen weighted_unemp_`x' = unemployed_in_`x'*weight_unemp_`x'
}

egen experienced_unemployment = rowtotal(weighted_unemp_*)
replace experienced_unemployment = experienced_unemployment/weight_denom if weight_denom!=0
replace experienced_unemployment=0 if weight_denom==0
label var experienced_unemployment "Experienced unemployment"

drop weighted_unemp_* weight_denom weight_unemp_* 

egen above_unemp_exp = xtile(experienced_unemployment), n(2) 
recode above_unemp_exp (1=0) (2=1)

bys incomegroup_agg: egen above_unemp_exp_cond = xtile(experienced_unemployment), n(2) 
recode above_unemp_exp_cond (1=0) (2=1)

bys incomegroup_agg: egen above_unemp_exp_cond75 = xtile(experienced_unemployment), n(4) 
recode above_unemp_exp_cond75 (1=0) (2=0) (3=0) (4=1)

gen weight_employment_status= 70.5 if employment_status<4 & employment_status!=.
replace weight_employment_status = 3.5 if employment_status==4
replace weight_employment_status = 26.9 if employment_status>4 & employment_status!=.s

}


** Indicators for memories about exposure to inflation (combining real information from FRED inflation data) **
{
forvalues x = 1955(1)2024{
	gen weight_inflation_`x' = `x' - yob
	replace weight_inflation_`x' = 0 if weight_inflation_`x' <0
}
egen weight_denom = rowtotal(weight_inflation_*)
gen id=1

**import inflation data
preserve
import excel "$data/us_annual_inflation.xls", sheet("FRED Graph") firstrow clear
rename FPCPITOTLZGUSA inflation
gen year=year(observation_date)
drop observation_date
gen id = 1
reshape wide inflation, i(id) j(year)
tempfile tmp
save `tmp'
restore

**merge and weight
merge m:1 id using `tmp'

forvalues x = 1960(1)2022{
	gen weighted_inflation_`x' = inflation`x'*weight_inflation_`x'
}
egen experienced_inflation = rowtotal(weighted_inflation_*)
replace experienced_inflation = experienced_inflation/weight_denom
label var experienced_inflation "Experienced inflation"

drop weighted_inflation_* weight_denom id weight_inflation_* _merge
forvalues x = 1960(1)2022{
	drop inflation`x'
}

sum experienced_inflation, d
scalar median = r(p50)
gen above_expinf=1 if experienced_inflation>median & experienced_inflation!=.
replace above_expinf=0 if above_expinf==. & experienced_inflation!=.
label var above_expinf "Above median inflation exposure"

bys incomegroup_agg: egen above_inf_exp_cond = xtile(experienced_inflation), n(2) 
recode above_inf_exp_cond (1=0) (2=1)

bys incomegroup_agg: egen above_inf_exp_cond75 = xtile(experienced_inflation), n(4) 
recode above_inf_exp_cond75 (1=0) (2=0) (3=0) (4=1)

}


** Indicators for asset exposure to inflation **
{

gen exposure_index = shortsave_value_midp + house_value_midp + mutualetf_value_midp + checkings_value_midp - mortgage_value_midp  - rent_value_midp
bys incomegroup_agg: egen exposed_dist = xtile(exposure_index), n(2) 

gen exposed_asset=0 if exposed_dist==1
replace exposed_asset = 1 if exposed_dist==2
label var exposed_asset "Above median net nominal position exposure"

egen exposed_dist_unc = xtile(exposure_index), n(2) 

gen exposed_asset_unc=0 if exposed_dist_unc==1
replace exposed_asset_unc = 1 if exposed_dist_unc==2
label var exposed_asset_unc "Above median net nominal position exposure (Unconditional)"

}


**************************************************
** Merge the dataset with the classification of **
** the answers to open-ended questions          **
**************************************************

{
tempfile tmp
save `tmp'

import excel "$dir/replication_package/data/classification_OEQ_importable.xlsx", firstrow clear	
tempfile tmpoeq
save `tmpoeq'

import excel "$dir/replication_package/data/classification_OEQ_importable_additional.xlsx", firstrow clear	
append using `tmpoeq'

foreach var of varlist biden bot debt_down energy_indep fin_system foreing_pol_down govt_spend_down greed immigration int_rates_down taxes_down_lowinc int_rates_up large_firm_tax large_firms_comp large_firms_prices min_wage_up mon_pol money_supp_down money_supp_up n_c none nonsense price_cap prod_growth social_sec_down social_sec_programs stimulus_check sup_chain tax_high_income taxes_down taxes_up trade_pol unemp_down unemp_up{
	replace `var' = 0 if `var'==.
}

gen mon_pol_cont = 0
replace mon_pol_cont =1 if int_rates_up==1 | money_supp_down==1
label var mon_pol_cont "Contractionary monetary policy"

gen mon_pol_exp=0
replace mon_pol_exp=1 if int_rates_down==1 | money_supp_up==1
label var mon_pol_exp "Expansionary monetary policy"

gen help_lowinc=0
replace help_lowinc=1 if social_sec_programs==1 | taxes_down_lowinc==1 | min_wage_up==1 | stimulus_check==1
label var help_lowinc "Help low income"

gen fis_pol_cont =0 
replace fis_pol_cont=1 if tax_high_income==1 | taxes_up==1 | social_sec_down==1 | govt_spend_down==1 | debt_down==1 | foreing_pol_down==1
label var fis_pol_cont "Contractionary fiscal policy"

gen greedflation = 0
replace greedflation=1 if large_firms_prices==1 | large_firms_comp==1 | large_firm_tax==1
label var greedflation "Fight greedflation"

gen fis_pol_exp =0
replace fis_pol_exp=1 if taxes_down==1 | unemp_down==1 | sup_chain==1 | prod_growth==1
label var fis_pol_exp "Expansionary fiscal policy"

gen protect_pol=0
replace protect_pol=1 if energy_indep==1 | trade_pol==1
label var protect_pol "Protectionist policies"



foreach var of varlist  bot debt_down energy_indep fin_system foreing_pol_down govt_spend_down greed  int_rates_down taxes_down_lowinc int_rates_up large_firm_tax large_firms_comp large_firms_prices min_wage_up mon_pol money_supp_down money_supp_up n_c none nonsense  prod_growth social_sec_down social_sec_programs stimulus_check sup_chain tax_high_income taxes_down taxes_up trade_pol unemp_down unemp_up {
	rename `var' oeqc_`var'
}

foreach var of varlist mon_pol_cont biden mon_pol_exp fis_pol_cont fis_pol_exp greedflation protect_pol help_lowinc price_cap immigration  {
	rename `var' oeqcl_`var'
}

merge 1:1 rid using `tmp'
drop if _m==1
drop _m
}



**************************
** Save the new dataset **
**************************
save "$data/inflation_understanding_variables.dta", replace
