****************************************************************************
** This code generates the dataset used to analyze the responses from the **
** conjoint experiment. It starts with the original dataset, where each   **
** row corresponds to a respondent, and reshapes it so that each row      **
** represents a scenario—a combination of unemployment and inflation—for  **
** a given respondent. As a result, in the new dataset, each respondent   **
** appears in 10 rows, one for each scenario.                             **
****************************************************************************

clear all
 
use "$data/inflation_understanding_variables.dta", clear

******************************************************************************


*** Temporarily retain only the variables of interest, compute differences between each pair of scenarios, generate indicators showing respondents' choices, create variables that capture differences in unemployment and inflation for each pair of scenarios, and then reshape the dataset.
{
preserve
keep ResponseId u1 pi1 u2 pi2 u3 pi3 u4 pi4 u5 pi5 u6 pi6 u7 pi7 u8 pi8 u9 u10 pi9 pi10   conjoint_1 conjoint_2 conjoint_3 conjoint_4 conjoint_5

foreach var in u pi{
	gen diff_`var'_1_1 = `var'1 - `var'2
	gen diff_`var'_1_2 = `var'2 - `var'1
	gen diff_`var'_2_1 = `var'3 - `var'4
	gen diff_`var'_2_2 = `var'4 - `var'3
	gen diff_`var'_3_1 = `var'5 - `var'6
	gen diff_`var'_3_2 = `var'6 - `var'5
	gen diff_`var'_4_1 = `var'7 - `var'8
	gen diff_`var'_4_2 = `var'8 - `var'7
	gen diff_`var'_5_1 = `var'9 - `var'10
	gen diff_`var'_5_2 = `var'10 - `var'9
}

reshape long  u pi, i(ResponseId conjoint_1 conjoint_2 conjoint_3 conjoint_4 conjoint_5) j(pair)  
sort *Id pair

* Create indicators for scenario chosen for each pair
gen chosen=. 
replace chosen=1 if (pair==1 & conjoint_1 ==1) | (pair==2 & conjoint_1 ==2) 
replace chosen=0 if (pair==1 & conjoint_1 ==2) | (pair==2 & conjoint_1 ==1) 

replace chosen=1 if (pair==3 & conjoint_2 ==1) | (pair==4 & conjoint_2 ==2) 
replace chosen=0 if (pair==3 & conjoint_2 ==2) | (pair==4 & conjoint_2 ==1)
 
replace chosen=1 if (pair==5 & conjoint_3 ==1) | (pair==6 & conjoint_3 ==2) 
replace chosen=0 if (pair==5 & conjoint_3 ==2) | (pair==6 & conjoint_3 ==1) 

replace chosen=1 if (pair==7 & conjoint_4 ==1) | (pair==8 & conjoint_4 ==2) 
replace chosen=0 if (pair==7 & conjoint_4 ==2) | (pair==8 & conjoint_4 ==1) 

replace chosen=1 if (pair==9 & conjoint_5 ==1) | (pair==10 & conjoint_5 ==2) 
replace chosen=0 if (pair==9 & conjoint_5 ==2) | (pair==10 & conjoint_5 ==1) 

* Create variables reporting the difference in u and pi for the two scenarios in each pair
gen diff_u=.
gen diff_pi=.
foreach var in u pi{
	replace diff_`var' = diff_`var'_1_1 if pair==1
	replace diff_`var' = diff_`var'_1_2 if pair==2
	replace diff_`var' = diff_`var'_2_1 if pair==3
	replace diff_`var' = diff_`var'_2_2 if pair==4
	replace diff_`var' = diff_`var'_3_1 if pair==5
	replace diff_`var' = diff_`var'_3_2 if pair==6
	replace diff_`var' = diff_`var'_4_1 if pair==7
	replace diff_`var' = diff_`var'_4_2 if pair==8
	replace diff_`var' = diff_`var'_5_1 if pair==9
	replace diff_`var' = diff_`var'_5_2 if pair==10
}
tempfile tmp
save `tmp'

drop diff_u_* diff_pi_*
restore
}


*** Merge this newly reshaped dataset with the original one so that each respondent's data contains all the necessary information.
{
merge 1:m ResponseId using `tmp'

label var u "Unemployment"
label var pi "Inflation"

label define info 0 "No information" 1 "Exact values"
label values conjoint_info info

drop DistributionChannel EndDate ExternalReference IPAddress LocationLatitude LocationLongitude StartDate EndDate IPAddress RecipientEmail RecipientFirstName RecipientLastName RecordedDate oeq_* feedback*

compress
}


**************************
** Save the new dataset **
**************************
save "$data/inflation_understanding_conjoint.dta", replace

