***************************************************************************
** This code generates Figure 1, which reports the share of respondents  **
** saying inflation or unemployment increase or decrease after different **
** shocks, dividing the sample between Democrats and Republican.         **
***************************************************************************



clear all

use "$data/inflation_understanding_variables.dta", clear

***************************************************************************


*** set general style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"


******************************************************
** Compute conditional shares and create the figure **
******************************************************
{
preserve

global interest  dummy_corr_interest_pi dummy_corr_interest_u 
global income dummy_corr_lowincomesupport_pi dummy_corr_lowincomesupport_u 
global oil dummy_corr_oil_pi dummy_corr_oil_u 
global tech dummy_corr_tech_pi dummy_corr_tech_u 
global wage dummy_corr_wage_pi dummy_corr_wage_u



* Compute and store conditional means and standard errors for each shock for Republican, Democrats and full sample

global j=1

foreach var_selec of varlist $wage{
	sum `var_selec' if political_agg==1
	scalar    low_wage_impact_${j}=r(mean)*100 
	scalar low_se_wage_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' 
	scalar    full_wage_impact_${j}=r(mean)*100 
	scalar full_se_wage_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    high_wage_impact_${j}=r(mean)*100 
	scalar high_se_wage_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2

}

global j=$j +5

foreach var_selec of varlist $tech{
	sum `var_selec' if political_agg==1
	scalar    low_tech_impact_${j}=r(mean)*100 
	scalar low_se_tech_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' 
	scalar    full_tech_impact_${j}=r(mean)*100 
	scalar full_se_tech_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    high_tech_impact_${j}=r(mean)*100 
	scalar high_se_tech_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2

}

global j=$j +5

foreach var_selec of varlist $oil{
	sum `var_selec' if political_agg==1
	scalar    low_oil_impact_${j}=r(mean)*100 
	scalar low_se_oil_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' 
	scalar    full_oil_impact_${j}=r(mean)*100 
	scalar full_se_oil_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    high_oil_impact_${j}=r(mean)*100 
	scalar high_se_oil_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2

}

global j=$j +5

foreach var_selec of varlist $income{
	sum `var_selec' if political_agg==1
	scalar    low_income_impact_${j}=r(mean)*100 
	scalar low_se_income_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' 
	scalar    full_income_impact_${j}=r(mean)*100 
	scalar full_se_income_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    high_income_impact_${j}=r(mean)*100 
	scalar high_se_income_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2

}

global j=$j +5

foreach var_selec of varlist $interest{
	sum `var_selec' if political_agg==1
	scalar    low_interest_impact_${j}=r(mean)*100 
	scalar low_se_interest_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' 
	scalar    full_interest_impact_${j}=r(mean)*100 
	scalar full_se_interest_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    high_interest_impact_${j}=r(mean)*100 
	scalar high_se_interest_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2

}




clear
set obs 59
egen n = seq()


* Initializes variables to store the computed impacts and their confidence intervals for plotting

macro list
foreach var in full_wage_impact low_wage_impact high_wage_impact full_tech_impact low_tech_impact high_tech_impact full_oil_impact low_oil_impact high_oil_impact full_income_impact low_income_impact high_income_impact full_interest_impact low_interest_impact high_interest_impact{
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5  {
replace low_wage_impact = low_wage_impact_`x' if n == `x'
replace min_low_wage_impact = low_wage_impact_`x'  - 1.965 * low_se_wage_impact_`x'  if n == `x'
replace max_low_wage_impact = low_wage_impact_`x'  + 1.965 * low_se_wage_impact_`x'  if n == `x'
scalar up_`x'=low_wage_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 2 6 {
replace full_wage_impact = full_wage_impact_`x' if n == `x'
replace min_full_wage_impact = full_wage_impact_`x'  - 1.965 * full_se_wage_impact_`x'  if n == `x'
replace max_full_wage_impact = full_wage_impact_`x'  + 1.965 * full_se_wage_impact_`x'  if n == `x'
scalar up_`x'=full_wage_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 3 7  {
replace high_wage_impact = high_wage_impact_`x' if n == `x'
replace min_high_wage_impact = high_wage_impact_`x'  - 1.965 * high_se_wage_impact_`x'  if n == `x'
replace max_high_wage_impact = high_wage_impact_`x'  + 1.965 * high_se_wage_impact_`x'  if n == `x'
scalar up_`x'=high_wage_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 14 18  {
replace low_tech_impact = low_tech_impact_`x' if n == `x'
replace min_low_tech_impact = low_tech_impact_`x'  - 1.965 * low_se_tech_impact_`x'  if n == `x'
replace max_low_tech_impact = low_tech_impact_`x'  + 1.965 * low_se_tech_impact_`x'  if n == `x'
scalar up_`x'=low_tech_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 15 19 {
replace full_tech_impact = full_tech_impact_`x' if n == `x'
replace min_full_tech_impact = full_tech_impact_`x'  - 1.965 * full_se_tech_impact_`x'  if n == `x'
replace max_full_tech_impact = full_tech_impact_`x'  + 1.965 * full_se_tech_impact_`x'  if n == `x'
scalar up_`x'=full_tech_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 16 20  {
replace high_tech_impact = high_tech_impact_`x' if n == `x'
replace min_high_tech_impact = high_tech_impact_`x'  - 1.965 * high_se_tech_impact_`x'  if n == `x'
replace max_high_tech_impact = high_tech_impact_`x'  + 1.965 * high_se_tech_impact_`x'  if n == `x'
scalar up_`x'=high_tech_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 27 31  {
replace low_oil_impact = low_oil_impact_`x' if n == `x'
replace min_low_oil_impact = low_oil_impact_`x'  - 1.965 * low_se_oil_impact_`x'  if n == `x'
replace max_low_oil_impact = low_oil_impact_`x'  + 1.965 * low_se_oil_impact_`x'  if n == `x'
scalar up_`x'=low_oil_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 28 32 {
replace full_oil_impact = full_oil_impact_`x' if n == `x'
replace min_full_oil_impact = full_oil_impact_`x'  - 1.965 * full_se_oil_impact_`x'  if n == `x'
replace max_full_oil_impact = full_oil_impact_`x'  + 1.965 * full_se_oil_impact_`x'  if n == `x'
scalar up_`x'=full_oil_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 29 33  {
replace high_oil_impact = high_oil_impact_`x' if n == `x'
replace min_high_oil_impact = high_oil_impact_`x'  - 1.965 * high_se_oil_impact_`x'  if n == `x'
replace max_high_oil_impact = high_oil_impact_`x'  + 1.965 * high_se_oil_impact_`x'  if n == `x'
scalar up_`x'=high_oil_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 40 44  {
replace low_income_impact = low_income_impact_`x' if n == `x'
replace min_low_income_impact = low_income_impact_`x'  - 1.965 * low_se_income_impact_`x'  if n == `x'
replace max_low_income_impact = low_income_impact_`x'  + 1.965 * low_se_income_impact_`x'  if n == `x'
scalar up_`x'=low_income_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 41 45 {
replace full_income_impact = full_income_impact_`x' if n == `x'
replace min_full_income_impact = full_income_impact_`x'  - 1.965 * full_se_income_impact_`x'  if n == `x'
replace max_full_income_impact = full_income_impact_`x'  + 1.965 * full_se_income_impact_`x'  if n == `x'
scalar up_`x'=full_income_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 42 46  {
replace high_income_impact = high_income_impact_`x' if n == `x'
replace min_high_income_impact = high_income_impact_`x'  - 1.965 * high_se_income_impact_`x'  if n == `x'
replace max_high_income_impact = high_income_impact_`x'  + 1.965 * high_se_income_impact_`x'  if n == `x'
scalar up_`x'=high_income_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 53 57  {
replace low_interest_impact = low_interest_impact_`x' if n == `x'
replace min_low_interest_impact = low_interest_impact_`x'  - 1.965 * low_se_interest_impact_`x'  if n == `x'
replace max_low_interest_impact = low_interest_impact_`x'  + 1.965 * low_se_interest_impact_`x'  if n == `x'
scalar up_`x'=low_interest_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 54 58 {
replace full_interest_impact = full_interest_impact_`x' if n == `x'
replace min_full_interest_impact = full_interest_impact_`x'  - 1.965 * full_se_interest_impact_`x'  if n == `x'
replace max_full_interest_impact = full_interest_impact_`x'  + 1.965 * full_se_interest_impact_`x'  if n == `x'
scalar up_`x'=full_interest_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 55 59  {
replace high_interest_impact = high_interest_impact_`x' if n == `x'
replace min_high_interest_impact = high_interest_impact_`x'  - 1.965 * high_se_interest_impact_`x'  if n == `x'
replace max_high_interest_impact = high_interest_impact_`x'  + 1.965 * high_se_interest_impact_`x'  if n == `x'
scalar up_`x'=high_interest_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}


* Create yvar for command scatter (to control vertical positioning)

gen temp= 0.5 + n*0.25 if n<8
replace temp=1.25 +n*0.25 if n<21 & temp==.
replace temp = 2 + n*0.25 if n<34 & temp==.
replace temp=2.75 +n*0.25 if n<47 & temp==.
replace temp=3.5 +n*0.25 if temp==.



* Set figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"

graph twoway (scatter temp low_wage_impact,  color(ebblue) msymbol(D) ) (rcap min_low_wage_impact max_low_wage_impact temp, horizontal color(ebblue) lwidth(vthin)) (scatter temp high_wage_impact ,  color(cranberry) msymbol(X) ) (rcap min_high_wage_impact max_high_wage_impact temp, horizontal color(cranberry) lwidth(vthin)) ///
(scatter temp low_tech_impact,  color(ebblue) msymbol(D) ) (rcap min_low_tech_impact max_low_tech_impact temp, horizontal color(ebblue) lwidth(vthin)) (scatter temp high_tech_impact ,  color(cranberry) msymbol(X) ) (rcap min_high_tech_impact max_high_tech_impact temp, horizontal color(cranberry) lwidth(vthin)) ///
(scatter temp low_oil_impact,  color(ebblue) msymbol(D)) (rcap min_low_oil_impact max_low_oil_impact temp, horizontal color(ebblue) lwidth(vthin)) (scatter temp high_oil_impact ,  color(cranberry) msymbol(X)) (rcap min_high_oil_impact max_high_oil_impact temp, horizontal color(cranberry) lwidth(vthin)) ///
(scatter temp low_income_impact,  color(ebblue) msymbol(D)) (rcap min_low_income_impact max_low_income_impact temp, horizontal color(ebblue) lwidth(vthin)) (scatter temp high_income_impact ,msymbol(X) color(cranberry) ) (rcap min_high_income_impact max_high_income_impact temp, horizontal color(cranberry) lwidth(vthin)) ///
(scatter temp low_interest_impact, msymbol(D) color(ebblue) ) (rcap min_low_interest_impact max_low_interest_impact temp, horizontal color(ebblue) lwidth(vthin)) (scatter temp high_interest_impact , msymbol(X) color(cranberry) ) (rcap min_high_interest_impact max_high_interest_impact temp, horizontal color(cranberry) lwidth(vthin)) ///
, legend(order(1 3) lab(1 "{bf:Democrat}") lab(3 "{bf:Republican}")  size(medsmall) position(6) cols(2)   symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center)) ///
			 xlabel(0(20)100, labsize(small)) ylabel(1 `" "Inflation increases" "' 2 `" "Unemployment increases" "' 3.5 `" "{bf:Wages due to}" "{bf:labor laws}" "' 5 `" "Inflation increases" "' 6 `" "Unemployment increases" "' 7.5 `" "{bf:Technology (TFP)}" "'  9 `" "Inflation increases" "' 10 `" "Unemployment increases" "' 11.5 `" "{bf:Oil prices}" "'  13 `" "Inflation increases" "' 14 `" "Unemployment increases" "' 15.5 `" "{bf: Government debt}" "{bf:for low-income support}" "'  17 `" "Inflation increases" "' 18 `" "Unemployment increases" "' 19.5 `" "{bf:Interest rate}" "'   , labsize(medsmall) noticks nogrid)   xtitle("") ytitle("") yline(3.5 7.5 11.5 15.5) yline(1.5 5.5 9.5 13.5 17.5, lwidth(vthin) lcolor(gray%50))

			 
graph export "$figures/fig1.png", as(png) replace

restore

}
