**************************************************************************************
** This code generates Figure 3, which reports the share of respondents indicating  **
** a specific cause as the most important cause of inflation within its category,   **
** conditional on having previously selected the category as one of the two most    **
** important causes of inflation, dividing the sample between Democrats and         **
** Republicans.                                                                     **
**************************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

**************************************************************************************


*** set general style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"


******************************************************
** Compute conditional shares and create the figure **
******************************************************

{
preserve

* Note: these variables are indicators taking value 1 when the respondent chose this cause as the most important one in the category (conditional on having indicated the category of causes as one of the two most important ones in question 2 of section A.8.6.1 of the appendix)

global gvt cause_gvt_top_1 cause_gvt_top_2  cause_gvt_top_3  cause_gvt_top_4  cause_gvt_top_5 
global fed cause_fed_top_1 cause_fed_top_2 cause_fed_top_3 cause_fed_top_4 cause_fed_top_5 
global costs cause_costs_top_1 cause_costs_top_2 cause_costs_top_3 cause_costs_top_4 cause_costs_top_5
global hh cause_hh_top_1 cause_hh_top_2
global labor cause_labor_top_1 cause_labor_top_2 cause_labor_top_3 
global firms cause_firms_top_1 cause_firms_top_2 cause_firms_top_3

* Compute and store conditional means and standard errors for each cause for Republican, Democrats and full sample

global j=1

foreach var_selec of varlist $firms{
	sum `var_selec' if political_agg==1
	scalar    firms_low_${j}=r(mean)*100 
	scalar se_firms_low_${j}=(r(sd)/sqrt(r(N)))*100
	global  j=$j +1
	sum `var_selec' 
	scalar    firms_${j}=r(mean)*100 
	scalar se_firms_${j}=(r(sd)/sqrt(r(N)))*100
	global  j=$j +1
	sum `var_selec' if political_agg==2
	scalar    firms_high_${j}=r(mean)*100 
	scalar se_firms_high_${j}=(r(sd)/sqrt(r(N)))*100

global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $labor{
	sum `var_selec' if political_agg==1
	scalar    labor_low_${j}=r(mean)*100 
	scalar se_labor_low_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec'
	scalar    labor_${j}=r(mean)*100 
	scalar se_labor_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec' if political_agg==2
	scalar    labor_high_${j}=r(mean)*100 
	scalar se_labor_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $hh {
	sum `var_selec' if political_agg==1
	scalar    hh_low_${j}=r(mean)*100 
	scalar se_hh_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    hh_${j}=r(mean)*100 
	scalar se_hh_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec' if political_agg==2
	scalar    hh_high_${j}=r(mean)*100 
	scalar se_hh_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2

}

global j=$j +5

foreach var_selec of varlist $costs{
	sum `var_selec' if political_agg==1
	scalar    costs_low_${j}=r(mean)*100 
	scalar se_costs_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    costs_${j}=r(mean)*100 
	scalar se_costs_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    costs_high_${j}=r(mean)*100 
	scalar se_costs_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $fed{
		sum `var_selec' if political_agg==1
	scalar    fed_low_${j}=r(mean)*100 
	scalar se_fed_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    fed_${j}=r(mean)*100 
	scalar se_fed_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if political_agg==2
	scalar    fed_high_${j}=r(mean)*100 
	scalar se_fed_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $gvt{
	sum `var_selec' if political_agg==1
	scalar    gvt_low_${j}=r(mean)*100 
	scalar se_gvt_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    gvt_${j}=r(mean)*100 
	scalar se_gvt_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    gvt_high_${j}=r(mean)*100 
	scalar se_gvt_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}


clear
set obs 116
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in firms firms_low firms_high labor labor_low labor_high hh hh_low hh_high costs costs_low costs_high fed fed_low fed_high gvt gvt_low gvt_high {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 9{
replace firms_low = firms_low_`x' if n == `x'
replace min_firms_low = firms_low_`x'  - 1.965 * se_firms_low_`x'  if n == `x'
replace max_firms_low = firms_low_`x'  + 1.965 * se_firms_low_`x'  if n == `x'
scalar up_`x'=firms_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 10{
replace firms = firms_`x' if n == `x'
replace min_firms = firms_`x'  - 1.965 * se_firms_`x'  if n == `x'
replace max_firms = firms_`x'  + 1.965 * se_firms_`x'  if n == `x'
scalar up_`x'=firms_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 11{
replace firms_high = firms_high_`x' if n == `x'
replace min_firms_high = firms_high_`x'  - 1.965 * se_firms_high_`x'  if n == `x'
replace max_firms_high = firms_high_`x'  + 1.965 * se_firms_high_`x'  if n == `x'
scalar up_`x'=firms_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


foreach x in 18 22 26 {
replace labor_low = labor_low_`x' if n == `x'
replace min_labor_low = labor_low_`x'  - 1.965 * se_labor_low_`x'  if n == `x'
replace max_labor_low = labor_low_`x'  + 1.965 * se_labor_low_`x'  if n == `x'
scalar up_`x'=labor_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 19 23 27 {
replace labor = labor_`x' if n == `x'
replace min_labor = labor_`x'  - 1.965 * se_labor_`x'  if n == `x'
replace max_labor = labor_`x'  + 1.965 * se_labor_`x'  if n == `x'
scalar up_`x'=labor_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 20 24 28 {
replace labor_high = labor_high_`x' if n == `x'
replace min_labor_high = labor_high_`x'  - 1.965 * se_labor_high_`x'  if n == `x'
replace max_labor_high = labor_high_`x'  + 1.965 * se_labor_high_`x'  if n == `x'
scalar up_`x'=labor_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}



foreach x in 35 39 {
replace hh_low = hh_low_`x' if n == `x'
replace min_hh_low = hh_low_`x'  - 1.965 * se_hh_low_`x'  if n == `x'
replace max_hh_low = hh_low_`x'  + 1.965 * se_hh_low_`x'  if n == `x'
scalar up_`x'=hh_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 36 40 {
replace hh = hh_`x' if n == `x'
replace min_hh = hh_`x'  - 1.965 * se_hh_`x'  if n == `x'
replace max_hh = hh_`x'  + 1.965 * se_hh_`x'  if n == `x'
scalar up_`x'=hh_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 37 41{
replace hh_high = hh_high_`x' if n == `x'
replace min_hh_high = hh_high_`x'  - 1.965 * se_hh_high_`x'  if n == `x'
replace max_hh_high = hh_high_`x'  + 1.965 * se_hh_high_`x'  if n == `x'
scalar up_`x'=hh_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 48 52 56 60 64 {
replace costs_low = costs_low_`x' if n == `x'
replace min_costs_low = costs_low_`x'  - 1.965 * se_costs_low_`x'  if n == `x'
replace max_costs_low = costs_low_`x'  + 1.965 * se_costs_low_`x'  if n == `x'
scalar up_`x'=costs_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 49 53 57 61 65 {
replace costs = costs_`x' if n == `x'
replace min_costs = costs_`x'  - 1.965 * se_costs_`x'  if n == `x'
replace max_costs = costs_`x'  + 1.965 * se_costs_`x'  if n == `x'
scalar up_`x'=costs_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 50 54 58 62 66 {
replace costs_high = costs_high_`x' if n == `x'
replace min_costs_high = costs_high_`x'  - 1.965 * se_costs_high_`x'  if n == `x'
replace max_costs_high = costs_high_`x'  + 1.965 * se_costs_high_`x'  if n == `x'
scalar up_`x'=costs_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 73 77 81 85 89 {
replace fed_low = fed_low_`x' if n == `x'
replace min_fed_low = fed_low_`x'  - 1.965 * se_fed_low_`x'  if n == `x'
replace max_fed_low = fed_low_`x'  + 1.965 * se_fed_low_`x'  if n == `x'
scalar up_`x'=fed_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 74 78 82 86 90  {
replace fed = fed_`x' if n == `x'
replace min_fed = fed_`x'  - 1.965 * se_fed_`x'  if n == `x'
replace max_fed = fed_`x'  + 1.965 * se_fed_`x'  if n == `x'
scalar up_`x'=fed_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 75 79 83 87 91  {
replace fed_high = fed_high_`x' if n == `x'
replace min_fed_high = fed_high_`x'  - 1.965 * se_fed_high_`x'  if n == `x'
replace max_fed_high = fed_high_`x'  + 1.965 * se_fed_high_`x'  if n == `x'
scalar up_`x'=fed_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 98 102 106 110 114 {
replace gvt_low = gvt_low_`x' if n == `x'
replace min_gvt_low = gvt_low_`x'  - 1.965 * se_gvt_low_`x'  if n == `x'
replace max_gvt_low = gvt_low_`x'  + 1.965 * se_gvt_low_`x'  if n == `x'
scalar up_`x'=gvt_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}
	
foreach x in 99 103 107 111 115  {
replace gvt = gvt_`x' if n == `x'
replace min_gvt = gvt_`x'  - 1.965 * se_gvt_`x'  if n == `x'
replace max_gvt = gvt_`x'  + 1.965 * se_gvt_`x'  if n == `x'
scalar up_`x'=gvt_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 100 104 108 112 116  {
replace gvt_high = gvt_high_`x' if n == `x'
replace min_gvt_high = gvt_high_`x'  - 1.965 * se_gvt_high_`x'  if n == `x'
replace max_gvt_high = gvt_high_`x'  + 1.965 * se_gvt_high_`x'  if n == `x'
scalar up_`x'=gvt_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


* Create yvar for command scatter (to control vertical positioning)

gen temp=0.5+n*0.25 if n<12
replace temp=1.25+0.25*n if n<29 & temp==.
replace temp=2 + 0.25*n if  n<42 & temp==.
replace temp=2.75 + 0.25*n if  n<67 & temp==.
replace temp=3.5 + 0.25*n if  n<92 & temp==.
replace temp=4.25 + 0.25*n if   temp==.




* Set figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter temp firms_low ,  color(ebblue) msymbol(D) ) (rcap min_firms_low max_firms_low temp, horizontal color(ebblue))    (scatter temp firms_high ,  color(cranberry) msymbol(X) ) (rcap min_firms_high max_firms_high temp, horizontal color(cranberry))  ///
   (scatter temp labor_low ,  color(ebblue) msymbol(D) ) (rcap min_labor_low max_labor_low temp, horizontal color(ebblue))    (scatter temp labor_high ,  color(cranberry) msymbol(X) ) (rcap min_labor_high max_labor_high temp, horizontal color(cranberry))    ///
    (scatter temp hh_low ,  color(ebblue) msymbol(D) ) (rcap min_hh_low max_hh_low temp, horizontal color(ebblue))   (scatter temp hh_high ,  color(cranberry) msymbol(X) ) (rcap min_hh_high max_hh_high temp, horizontal color(cranberry)) ///
     (scatter temp costs_low ,  color(ebblue) msymbol(D) ) (rcap min_costs_low max_costs_low temp, horizontal color(ebblue)) (scatter temp costs_high ,  color(cranberry) msymbol(X) ) (rcap min_costs_high max_costs_high temp, horizontal color(cranberry)) ///
	  (scatter temp fed_low ,  color(ebblue) msymbol(D) ) (rcap min_fed_low max_fed_low temp, horizontal color(ebblue))  (scatter temp fed_high ,  color(cranberry) msymbol(X) ) (rcap min_fed_high max_fed_high temp, horizontal color(cranberry)) ///
	  (scatter temp gvt_low ,  color(ebblue) msymbol(D) ) (rcap min_gvt_low max_gvt_low temp, horizontal color(ebblue))  (scatter temp gvt_high ,  color(cranberry) msymbol(X) ) (rcap min_gvt_high max_gvt_high temp, horizontal color(cranberry)), ///
			 legend(order(1 3) lab(1 "{bf:Democrat}") lab(3 "{bf:Republican}")  size(medsmall) position(6) cols(3)  symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center)) xlabel(0(10)100, labsize(small)) ylabel(1 `" "Increases in prices due to" "increases in inflation expectations" "'  2 `"  "Increases in prices to increase profits" "' 3 `" "Decrease in competition" "' 4.5  `" "{bf:Actions by firms}" "{bf: and businesses}" "' 6 `" "Wage increases due to unions or labor rights" "' 7 `" "Labor shortages" "' 8 `" "Wage-price spirals" "'  9.5  `" "{bf:Changes in the labor market}" "' 11 `" "Increases in inflation expectations" "' 12 `" "Optimism" "' 13.5  `"  "{bf:Households spending more}" "{bf:due to}" "' 15 `" "Increases in oil prices" "' 16 `" "Increases in energy prices" "' 17 `" "Disruptions in other countries" "' 18 `" "Supply chain disruptions" "' 19`" "The pandemic" "' 20.5 `" "{bf:Increases in costs of production}" "{bf:caused by}"  "' 22 `" "Decreases in interest rates" "' 23 `" "Increases in interest rates" "' 24 `" "Increases in money supply" "' 25 `" "Wrong actions" "' 26 `" "Unclear announcements" "'  27.5 `" "{bf:Actions by the}" "{bf: Federal Reserve}" "' 29 `" "Income tax cuts" "' 30 `" "Debt-financed increases in foreign assistance" "' 31 `" "Debt-financed increases in government spending" "for infrastructure and defense" "' 32 `" "Debt-financed increases in assistance for tough times" "' 33 `" "Debt-financed increases in social security" "'  34.5 `" "{bf:Government spending,}" "{bf:debt, and taxation}" "', labsize(medsmall) noticks nogrid)  xsize(10)  ysize(8)  yline(4.5 9.5 13.5 20.5 27.5) yline(1.5 2.5 6.5 7.5 11.5 12.5 15.5 16.5 17.5 18.5 22.5 23.5 24.5 25.5 29.5 30.5 31.5 32.5, lwidth(vvthin) lcolor(gray%50)) ytitle("")

resize, xsize(20cm) ysize(20cm)
graph export "$figures/fig3.png", as(png)  replace

restore

}
