******************************************************************************
** This code generates Figure 5, which reports the share of respondents     **
** saying that the consequence on the row is the most important consequence ** 
** of inflation, dividing the sample between Democrats and Republican.      **
******************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

******************************************************************************


*** set general style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"

******************************************************
** Compute conditional shares and create the figure **
******************************************************

{
preserve

* Note: In first 13 questions of section A.8.6.3 respondents were asked to assess whether inflation has negative consequences in various realms (e.g., U.S. economy, household uncertainty, etc.). The variables used in this code are indicators taking value 1 when the respondent chose this consequence as the most important among all the negative consequences of inflation previously selected.

global cognitive dummy_cons_top_1 dummy_cons_top_2  

global efficiency dummy_cons_top_3 dummy_cons_top_12 dummy_cons_top_4 dummy_cons_top_5 dummy_cons_top_6 dummy_cons_top_7

global polecon dummy_cons_top_8 dummy_cons_top_9 dummy_cons_top_10 dummy_cons_top_11 
          

* Compute and store conditional means and standard errors for each consequence for Republican, Democrats and full sample

global j=1

foreach var_selec of varlist $cognitive{
	sum `var_selec' if political_agg==1
	scalar    low_cons_impact_${j}=r(mean)*100 
	scalar low_se_cons_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' 
	scalar    full_cons_impact_${j}=r(mean)*100 
	scalar full_se_cons_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    high_cons_impact_${j}=r(mean)*100 
	scalar high_se_cons_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2

}

global j=$j +5

foreach var_selec of varlist $efficiency{
	sum `var_selec' if political_agg==1
	scalar    low_eff_impact_${j}=r(mean)*100 
	scalar low_se_eff_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' 
	scalar    full_eff_impact_${j}=r(mean)*100 
	scalar full_se_eff_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    high_eff_impact_${j}=r(mean)*100 
	scalar high_se_eff_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2

}

global j=$j +5

foreach var_selec of varlist $polecon{
	sum `var_selec' if political_agg==1
	scalar    low_pol_impact_${j}=r(mean)*100 
	scalar low_se_pol_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' 
	scalar    full_pol_impact_${j}=r(mean)*100 
	scalar full_se_pol_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    high_pol_impact_${j}=r(mean)*100 
	scalar high_se_pol_impact_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2

}



clear
set obs 57
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in full_cons_impact low_cons_impact high_cons_impact full_eff_impact low_eff_impact high_eff_impact full_pol_impact low_pol_impact high_pol_impact{
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5  {
replace low_cons_impact = low_cons_impact_`x' if n == `x'
replace min_low_cons_impact = low_cons_impact_`x'  - 1.965 * low_se_cons_impact_`x'  if n == `x'
replace max_low_cons_impact = low_cons_impact_`x'  + 1.965 * low_se_cons_impact_`x'  if n == `x'
scalar up_`x'=low_cons_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 2 6  {
replace full_cons_impact = full_cons_impact_`x' if n == `x'
replace min_full_cons_impact = full_cons_impact_`x'  - 1.965 * full_se_cons_impact_`x'  if n == `x'
replace max_full_cons_impact = full_cons_impact_`x'  + 1.965 * full_se_cons_impact_`x'  if n == `x'
scalar up_`x'=full_cons_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 3 7  {
replace high_cons_impact = high_cons_impact_`x' if n == `x'
replace min_high_cons_impact = high_cons_impact_`x'  - 1.965 * high_se_cons_impact_`x'  if n == `x'
replace max_high_cons_impact = high_cons_impact_`x'  + 1.965 * high_se_cons_impact_`x'  if n == `x'
scalar up_`x'=high_cons_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 14 18 22 26 30 34  {
replace low_eff_impact = low_eff_impact_`x' if n == `x'
replace min_low_eff_impact = low_eff_impact_`x'  - 1.965 * low_se_eff_impact_`x'  if n == `x'
replace max_low_eff_impact = low_eff_impact_`x'  + 1.965 * low_se_eff_impact_`x'  if n == `x'
scalar up_`x'=low_eff_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 15 19 23 27 31 35  {
replace full_eff_impact = full_eff_impact_`x' if n == `x'
replace min_full_eff_impact = full_eff_impact_`x'  - 1.965 * full_se_eff_impact_`x'  if n == `x'
replace max_full_eff_impact = full_eff_impact_`x'  + 1.965 * full_se_eff_impact_`x'  if n == `x'
scalar up_`x'=full_eff_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 16 20 24 28 32 36  {
replace high_eff_impact = high_eff_impact_`x' if n == `x'
replace min_high_eff_impact = high_eff_impact_`x'  - 1.965 * high_se_eff_impact_`x'  if n == `x'
replace max_high_eff_impact = high_eff_impact_`x'  + 1.965 * high_se_eff_impact_`x'  if n == `x'
scalar up_`x'=high_eff_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 43 47 51 55  {
replace low_pol_impact = low_pol_impact_`x' if n == `x'
replace min_low_pol_impact = low_pol_impact_`x'  - 1.965 * low_se_pol_impact_`x'  if n == `x'
replace max_low_pol_impact = low_pol_impact_`x'  + 1.965 * low_se_pol_impact_`x'  if n == `x'
scalar up_`x'=low_pol_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 44 48 52 56  {
replace full_pol_impact = full_pol_impact_`x' if n == `x'
replace min_full_pol_impact = full_pol_impact_`x'  - 1.965 * full_se_pol_impact_`x'  if n == `x'
replace max_full_pol_impact = full_pol_impact_`x'  + 1.965 * full_se_pol_impact_`x'  if n == `x'
scalar up_`x'=full_pol_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}

foreach x in 45 49 53 57  {
replace high_pol_impact = high_pol_impact_`x' if n == `x'
replace min_high_pol_impact = high_pol_impact_`x'  - 1.965 * high_se_pol_impact_`x'  if n == `x'
replace max_high_pol_impact = high_pol_impact_`x'  + 1.965 * high_se_pol_impact_`x'  if n == `x'
scalar up_`x'=high_pol_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+13
}


* Create yvar for command scatter (to control vertical positioning)

gen temp = 0.5+n*0.25 if n<8
replace temp=1.25+n*0.25 if n<37 & temp==.
replace temp = 2 + n*0.25 if temp==.


*set figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter temp low_cons_impact ,  color(ebblue) msymbol(D) ) (rcap min_low_cons_impact max_low_cons_impact temp, horizontal color(ebblue)) (scatter temp high_cons_impact ,  color(cranberry) msymbol(X) ) (rcap min_high_cons_impact max_high_cons_impact temp, horizontal color(cranberry)) ///
(scatter temp low_eff_impact ,  color(ebblue) msymbol(D) ) (rcap min_low_eff_impact max_low_eff_impact temp, horizontal color(ebblue)) (scatter temp high_eff_impact ,  color(cranberry) msymbol(X) ) (rcap min_high_eff_impact max_high_eff_impact temp, horizontal color(cranberry)) ///
(scatter temp low_pol_impact ,  color(ebblue) msymbol(D) ) (rcap min_low_pol_impact max_low_pol_impact temp, horizontal color(ebblue)) (scatter temp high_pol_impact ,  color(cranberry) msymbol(X) ) (rcap min_high_pol_impact max_high_pol_impact temp, horizontal color(cranberry)), legend(order(1 3 ) lab(1 "{bf:Democrat}")  lab(3 "{bf:Republican}")   position(6) cols(2) size(small)  symysize(4) symxsize(4) rowgap(-2) colgap(2) just(left) symplacement(center)) ///
			 xlabel(0(10)50, labsize(small) ) ylabel(1 `" "Makes daily economic decisions" "more complicated for households" "' 2 `" "Increases households uncertainty" "when making decisions" "' 3.5 `" "{bf:Cognitive costs}" "' 5 `" "Forces households to have cash" "(shoe-leather cost)" "'  6 `" "Makes setting prices harder" "(menu costs)" "' 7 `" "Makes firms ordinary decisions" "more difficult" "'  8 `" "Increases resource misallocation" "' 9 `" "Slows down GDP growth" "' 10 `" "Decreases value of the dollar" "' 11.5 `" "{bf:Efficiency & economic costs}" "' 13 `" "Decreases national prestige" "' 14 `" "Increases inequality" "' 15 `" "Decreases social cohesion" "' 16 `" "Decrease trust in government" "'  17.5 `" "{bf:Political & social costs}" "', labsize(medsmall) noticks nogrid)   xtitle("") ytitle("") name(gr1, replace) yline(1.5 5.5 6.5 7.5 8.5 9.5 13.5 14.5 15.5, lwidth(vthin)  lcolor(gray%50)) yline(3.5 11.5)
			 	resize, xsize(10cm) ysize(15cm)
	graph export $figures/fig5.png, width(2000) height(3000) as(png) replace
restore

}
