****************************************************************************
** This code generates Figure 6, which reports the share of respondents  **
** share of respondents who agree with the statement on the corresponding **
** row, dividing the sample between Democrats and Republican.             **
****************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

****************************************************************************


*** set general style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"


******************************************************
** Compute conditional shares and create the figure **
******************************************************
{
preserve

*Note: sample includes only respondents who were not shown the video on the trade-offs between inflation and unemployment.
keep if treatment==0

* Note:  dummy_policy_booms is an indicator equal to one if the respondent says that inflation happens mostly or slightly more often in booms. dummy_policy_sideffects is an indicator equal to one if the respondent says that these policies increase or significantly increase inflation.  dummy_first_stage is an indicator equal to one if the respondent agrees or strongly agrees with the statement that inflation is an unfortunate side effect of growth.

global signal dummy_first_stage dummy_policy_sideffects  dummy_policy_signal dummy_policy_booms

*Note:  these are indicators equal to one if the respondent says that the trade-off listed in the row is very or extremely necessary
global mechanisms dummy_policy_tradeoff_spend dummy_policy_tradeoff_growth dummy_policy_tradeoff_debt dummy_policy_tradeoff_unemp


* Compute and store conditional means and standard errors for each statement for Republican, Democrats and full sample

global j=1

foreach var_selec of varlist $mechanisms{
	sum `var_selec' if political_agg==1
	scalar    mechanisms_low_${j}=r(mean)*100 
	scalar se_mechanisms_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    mechanisms_${j}=r(mean)*100 
	scalar se_mechanisms_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    mechanisms_high_${j}=r(mean)*100 
	scalar se_mechanisms_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $signal{
	sum `var_selec' if political_agg==1
	scalar    signal_low_${j}=r(mean)*100 
	scalar se_signal_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    signal_${j}=r(mean)*100 
	scalar se_signal_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if political_agg==2
	scalar    signal_high_${j}=r(mean)*100 
	scalar se_signal_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}


clear
set obs 36
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in mechanisms mechanisms_low mechanisms_high signal signal_low signal_high  {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 9 13 {
replace mechanisms_low = mechanisms_low_`x' if n == `x'
replace min_mechanisms_low = mechanisms_low_`x'  - 1.965 * se_mechanisms_low_`x'  if n == `x'
replace max_mechanisms_low = mechanisms_low_`x'  + 1.965 * se_mechanisms_low_`x'  if n == `x'
scalar up_`x'=mechanisms_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 10 14 {
replace mechanisms = mechanisms_`x' if n == `x'
replace min_mechanisms = mechanisms_`x'  - 1.965 * se_mechanisms_`x'  if n == `x'
replace max_mechanisms = mechanisms_`x'  + 1.965 * se_mechanisms_`x'  if n == `x'
scalar up_`x'=mechanisms_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 11 15 {
replace mechanisms_high = mechanisms_high_`x' if n == `x'
replace min_mechanisms_high = mechanisms_high_`x'  - 1.965 * se_mechanisms_high_`x'  if n == `x'
replace max_mechanisms_high = mechanisms_high_`x'  + 1.965 * se_mechanisms_high_`x'  if n == `x'
scalar up_`x'=mechanisms_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 22 26 30 34 {
replace signal_low = signal_low_`x' if n == `x'
replace min_signal_low = signal_low_`x'  - 1.965 * se_signal_low_`x'  if n == `x'
replace max_signal_low = signal_low_`x'  + 1.965 * se_signal_low_`x'  if n == `x'
scalar up_`x'=signal_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 23 27 31 35 {
replace signal = signal_`x' if n == `x'
replace min_signal = signal_`x'  - 1.965 * se_signal_`x'  if n == `x'
replace max_signal = signal_`x'  + 1.965 * se_signal_`x'  if n == `x'
scalar up_`x'=signal_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 24 28 32 36{
replace signal_high = signal_high_`x' if n == `x'
replace min_signal_high = signal_high_`x'  - 1.965 * se_signal_high_`x'  if n == `x'
replace max_signal_high = signal_high_`x'  + 1.965 * se_signal_high_`x'  if n == `x'
scalar up_`x'=signal_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


* Create yvar for command scatter (to control vertical positioning)

gen temp=0.5+n*0.25 if n<16
replace temp=1.25+0.25*n if temp==.


* Set the figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter temp mechanisms_low ,  color(ebblue) msymbol(D) ) (rcap min_mechanisms_low max_mechanisms_low temp, horizontal color(ebblue) )      (scatter temp mechanisms_high ,  color(cranberry) msymbol(X)  ) (rcap min_mechanisms_high max_mechanisms_high temp, horizontal color(cranberry)  )    ///
   (scatter temp signal_low ,  color(ebblue) msymbol(D)  ) (rcap min_signal_low max_signal_low temp, horizontal color(ebblue)  )  (scatter temp signal_high ,  color(cranberry) msymbol(X)) (rcap min_signal_high max_signal_high temp, horizontal color(cranberry)  )  , ///
			 legend(order(1 3) lab(1 "{bf:Democrat}") lab(3 "{bf:Republican}")  size(small) position(6) cols(2)   symysize(4) symxsize(4) rowgap(-2) colgap(2) just(left) symplacement(center))  xlabel(0(20)100, labsize(small) ) ylabel(1 "Reduce spending"  2 "Reduce growth" 3 "Reduce debt" 4 "Increase unemployment" 5.5  `" "{bf:To reduce inflation,}" "{bf:it is necessary to}" "' 7 `" "Inflation is a side effect" "of positive economic developments" "' 8  `" "Policies to reduce unemployment" "may increase inflation" "' 9 `" "Inflation is often a sign" "of a good economy" "' 10 `" "Inflation happens more" "often in booms" "'   , labsize(medsmall) noticks nogrid)  xtitle(" ", size(tiny) ) ytitle("")   yline(5.5 ) yline(1.5 2.5 3.5 7.5 8.5 9.5, lwidth(vthin) lcolor(gray%50))
			resize, xsize(10cm) ysize(12cm)

graph export "$figures/fig6.png", as(png) width(2000) height(2400) replace

restore

}
