****************************************************************************
** This code generates Table 1, which presents the sample characteristics ** 
** and compares them with those of the US population.                     **
****************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

****************************************************************************


*** Calculate the shares within our sample
{
	
	foreach var of varlist gender age_group income_group race live_in_US born_us employment_agg_2 education_agg_quota employment_group_2  marital_status kids vote_2020 candidate_2020 political_agg  {

tab `var', matcell(cps_`var')

mata: st_matrix("cps_`var'", (st_matrix("cps_`var'")  :/ colsum(st_matrix("cps_`var'"))))


local r = rowsof(cps_`var')
forvalues x = 1(1)`r'{
    local rf_`var'`x'_temp= round(cps_`var'[`x',1],0.01) 
	local rf_`var'`x': display %5.2f `rf_`var'`x'_temp'
	
}
}

qui:des
local sample_size_af=r(N)
}

*************************
** Generates the table **
*************************
{
file open holder using "$tables/tab1.tex", write replace text
file write holder "\begin{tabular}{lccc} " _n

file write holder "\toprule" _n
file write holder "\hline \noalign{\smallskip}  & Survey & US population   \\\hline" _n


file write holder "\noalign{\smallskip}\hline \noalign{\smallskip} \textbf{Targeted quotas} &     \\" _n
file write holder "Male  & `rf_gender1' & 0.49 \\" _n
file write holder " Female   & `rf_gender2' & 0.51  \\" _n
file write holder " & &   \\" _n
file write holder " 18-29 years old & `rf_age_group1' & 0.23 \\" _n
file write holder " 30-39 years old & `rf_age_group2' & 0.21 \\" _n
file write holder " 40-49 years old & `rf_age_group3' & 0.19 \\" _n
file write holder " 50-59 years old & `rf_age_group4' & 0.19 \\" _n
file write holder " 60-69 years old & `rf_age_group5' & 0.18 \\ " _n
file write holder " & &   \\" _n

file write holder " \\$0-\\$19,999   & `rf_income_group1' & 0.13  \\" _n
file write holder " \\$20,000-\\$39,999   & `rf_income_group2'  & 0.16  \\" _n
file write holder " \\$40,000-\\$69,999 & `rf_income_group3'  & 0.20 \\" _n
file write holder " \\$70,000-\\$99,999   & `rf_income_group4' & 0.15  \\" _n
file write holder " \\$100,000-\\$124,999    & `rf_income_group5' & 0.09  \\" _n
file write holder " \\$125,000+           & `rf_income_group6' & 0.26  \\" _n
file write holder " &  & \\" _n

file write holder " White       			 &  `rf_race1'  & 0.6   \\" _n
file write holder " African-American/Black     &  `rf_race2'  & 0.13\\" _n
file write holder " Hispanic/Latino             &  `rf_race3' & 0.19  \\" _n
file write holder " Asian/Asian-American        &  `rf_race4' & 0.06  \\" _n
file write holder " &   \\" _n

file write holder " \textbf{Non-targeted characteristics} &   \\" _n
file write holder " Married  & `rf_marital_status2' & 0.52 \\" _n
file write holder " Single  & `rf_marital_status1' & 0.35  \\" _n
file write holder " Separated/Divorced   & `rf_marital_status3' & 0.12 \\" _n
file write holder " Widowed   & `rf_marital_status4' & 0.02 \\" _n

file write holder " &      \\" _n
file write holder " Has children  & `rf_kids2' & 0.40  \\" _n


file write holder " &    \\" _n
file write holder " Less than 4-year college  & `rf_education_agg_quota1' & 0.64 \\" _n
file write holder " 4-year college/Master's   & `rf_education_agg_quota2' & 0.32 \\" _n
file write holder " Professional degree  & `rf_education_agg_quota3' & 0.03 \\" _n

file write holder " &     \\" _n
file write holder " Employed  &  `rf_employment_agg_22' & 0.70  \\" _n
file write holder " Unemployed   &  `rf_employment_group_22' & 0.03  \\" _n

file write holder " &     \\" _n
file write holder " Republican	  &  `rf_political_agg2'  & 0.26   \\" _n
file write holder " Democrat    &  `rf_political_agg1'   & 0.25  \\" _n
file write holder " Independent \& others    &  `rf_political_agg3' & 0.47     \\" _n

file write holder " &      \\" _n
file write holder "Voted in 2020 presidential election &  `rf_vote_20202' & 0.61     \\" _n

file write holder " &     \\" _n
file write holder "Voted for Biden in 2020 presidential election &  `rf_candidate_20201'  & 0.51   \\" _n
file write holder "Voted for Trump in 2020 presidential election &  `rf_candidate_20202'  &  0.47  \\" _n

file write holder " &     \\" _n
file write holder " Sample size  &`sample_size_af' \\" _n



file write holder "\bottomrule \end{tabular}" _n
file close holder
}
