****************************************************************************
** This code generates Table 6, which reports the correlates of inflation **
** and unemployment perceptions and expectations.                         **
****************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

****************************************************************************


*** set the table style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"


*** Generate the global of variables for the regressions
global demo_controls " women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies incomegroup_agg_2 incomegroup_agg_3 kids race_black race_asian race_hisp race_mixed  marital_status_2 marital_status_3 marital_status_4 employment_group_2 employment_group_3 news_cnn news_fox news_social_media news_npr news_nyt news_wsj news_msnbc    news_network news_localtv  news_amtalk   news_localpapers"

global het_groups "incomegroup_agg_1 incomegroup_agg_2 incomegroup_agg_3 democrat republican agegroup_agg_1 agegroup_agg_2 agegroup_agg_3"

******************************************************
** Create the table (including running regressions) ** 
******************************************************
{
global table_name "$tables/tab6"

*** Table end
file open  holder using $tables/temp_end.tex, write replace text
file write holder " \end{tabular}" _n
file close holder

    

*** Table start
file open holder using $table_name.tex, write replace text
file write holder "\begin{tabular}{lcccc} " _n
file write holder "& Perceived inflation & Perceived unemployment & Expected inflation & Expected unemployment \\ \hline" _n
file write holder "& (1) & (2) & (3) & (4)  \\ \hline" _n
file close holder 

*** Regressions
* Note:  Inflation perceptions and expectations arecensored at −10 and +25

eststo:  rreg perceived_inflation_value $demo_controls if perceived_inflation_value<25&perceived_inflation_value>-10
local rsq_1: display %5.3f `e(r2_a)'

qui sum perceived_inflation_value if e(sample) 
local depmean_1: display %5.3f `r(mean)'
local obs_1: display %5.0f `r(N)'
local std_1: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum perceived_inflation_value if e(sample) & `var'==1
	local mean_`var'_1: display %5.3f `r(mean)'
}

eststo:  rreg perceived_unemployment_value $demo_controls if perceived_unemployment_value<100
local rsq_2: display %5.3f `e(r2_a)'

qui sum perceived_unemployment_value if e(sample) 
local depmean_2: display %5.3f `r(mean)'
local obs_2: display %5.0f `r(N)'
local std_2: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum perceived_unemployment_value if e(sample) & `var'==1
	local mean_`var'_2: display %5.3f `r(mean)'
}


eststo:  rreg expected_inflation_value $demo_controls if expected_inflation_value<25&expected_inflation_value>-10
local rsq_3: display %5.3f `e(r2_a)'

qui sum expected_inflation_value if e(sample) 
local depmean_3: display %5.3f `r(mean)'
local obs_3: display %5.0f `r(N)'
local std_3: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum expected_inflation_value if e(sample) & `var'==1
	local mean_`var'_3: display %5.3f `r(mean)'
}

eststo:  rreg expected_unemployment_value $demo_controls if expected_unemployment_value<100
local rsq_4: display %5.3f `e(r2_a)'

qui sum expected_unemployment_value if e(sample) 
local depmean_4: display %5.3f `r(mean)'
local obs_4: display %5.0f `r(N)'
local std_4: display %5.3f `r(sd)'

foreach var in $het_groups{
	qui sum expected_unemployment_value if e(sample) & `var'==1
	local mean_`var'_4: display %5.3f `r(mean)'
}


esttab using $tables/panel_before.tex, replace fragment booktabs noconst nobase  label cells(b(fmt(3) star) se(par fmt(3))) collabels(none) keep( women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies kids incomegroup_agg_2 incomegroup_agg_3 employment_group_2 employment_group_3 news_cnn news_fox news_social_media news_npr news_nyt news_wsj) /// 
starlevels(* .1 ** .05 *** .01) se nonumbers nomtitles nolines nocon noobs compress


*** Reporting regression results in the table
file open holder using $tables/panel_means_before.tex, write replace text
file write holder "\hline " _n 
file write holder "Observations & `obs_1' & `obs_2' & `obs_3' & `obs_4'  \\" _n     
file write holder "Adj. R$^{2}$ & `rsq_1' & `rsq_2' & `rsq_3' & `rsq_4'\\" _n 
file write holder "$\mathbb{E}$(Dependent variable)& `depmean_1' & `depmean_2' & `depmean_3'  & `depmean_4'  \\" _n   
file write holder "Mean income \$<\$40& `mean_incomegroup_agg_1_1' & `mean_incomegroup_agg_1_2' & `mean_incomegroup_agg_1_3'  & `mean_incomegroup_agg_1_4'  \\" _n  
file write holder "Mean income \$>\$125k& `mean_incomegroup_agg_3_1' & `mean_incomegroup_agg_3_2' & `mean_incomegroup_agg_3_3'  & `mean_incomegroup_agg_3_4'  \\" _n 
file write holder "Mean democrat& `mean_democrat_1' & `mean_democrat_2' & `mean_democrat_3'  & `mean_democrat_4'  \\" _n 
file write holder "Mean republican& `mean_republican_1' & `mean_republican_2' & `mean_republican_3'  & `mean_republican_4' \\" _n 
file write holder "Mean 18-29 years old& `mean_agegroup_agg_1_1' & `mean_agegroup_agg_1_2' & `mean_agegroup_agg_1_3'  & `mean_agegroup_agg_1_4' \\" _n 
file write holder "Mean 30-49 years old& `mean_agegroup_agg_2_1' & `mean_agegroup_agg_2_2' & `mean_agegroup_agg_2_3'  & `mean_agegroup_agg_2_4' \\" _n 
file write holder "Mean 50-69 years old& `mean_agegroup_agg_3_1' & `mean_agegroup_agg_3_2' & `mean_agegroup_agg_3_3'  & `mean_agegroup_agg_3_4' \\" _n    
file write holder "Dependent variable std. dev. & `std_1' & `std_2' & `std_3' & `std_4' \\" _n
file write holder "\hline " _n 
file write holder " & & \\" _n
file close holder

eststo clear


appendfile $tables/panel_before.tex $table_name.tex
appendfile $tables/panel_means_before.tex $table_name.tex
appendfile $tables/temp_end.tex $table_name.tex

erase $tables/panel_before.tex
erase $tables/panel_means_before.tex
erase $tables/temp_end.tex
}

