************************************************************************
** This code generates Table 7, which reports the correlation between **
** monetary and fiscal policy views and beliefs about inflation.      **
************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

************************************************************************


*** set the table style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"


*** Generate the global of variables for the regressions
replace exposure_index=exposure_index/100000
label var exposure_index "Net nominal position (in hundreds of thousands)"
global demo_controls "women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies incomegroup_agg_2 incomegroup_agg_3 race_black race_asian race_hisp race_mixed  marital_status_2 marital_status_3 marital_status_4 kids employment_group_2 employment_group_3 treatment conjoint_info   policy_first unemployment_first"
global regressors "cause_labor cause_fed  cause_politics cause_hh cause_firms cause_costs low_inc_lost_more cons_cognitive cons_polecon cons_efficiency correct_corr index_tradeoffs_good index_tradeoffs_policy exposure_index"

global het_groups "incomegroup_agg_1 incomegroup_agg_3 democrat republican agegroup_agg_1 agegroup_agg_2 agegroup_agg_3"

global table_name "$tables/tab7"


******************************************************
** Create the table (including running regressions) ** 
******************************************************
{
*** Table end
file open  holder using $tables/temp_end.tex, write replace text
file write holder " \end{tabular}" _n
file close holder

    

*** Table start
file open holder using $table_name.tex, write replace text
file write holder "\begin{tabular}{lccccccc} " _n
file write holder "&\multicolumn{4}{c}{\textbf{Monetary policy:}} &\multicolumn{3}{c}{\textbf{Ways to reduce debt:}}  \\" _n
file write holder "& Increase interest rate & Reduce interest rates & Reduce money supply & Announce future plans for interest rate & Tax high income & Tax high/mid income & Reduce spending on social programs   \\ \hline" _n
file write holder "& (1) & (2) & (3) & (4) & (5) & (6) & (7)\\ \hline" _n
file close holder

*** Run regressions
eststo:  reghdfe dummy_policy_increaserate $regressors $demo_controls, noabsorb vce(robust)
local rsq_1: display %5.3f `e(r2_a)'

qui sum dummy_policy_increaserate if e(sample) 
local obs_1: display %5.0f `r(N)'

qui sum dummy_policy_increaserate if e(sample) & treatment==0
local depmean_1: display %5.3f `r(mean)'
local std_1: display %5.3f `r(sd)'


eststo:  reghdfe dummy_policy_decreaserate $regressors $demo_controls, noabsorb vce(robust)
local rsq_2: display %5.3f `e(r2_a)'

qui sum dummy_policy_decreaserate if e(sample) 
local obs_2: display %5.0f `r(N)'

qui sum dummy_policy_decreaserate if e(sample) & treatment==0
local depmean_2: display %5.3f `r(mean)'
local std_2: display %5.3f `r(sd)'

eststo:  reghdfe dummy_policy_decreasemsupply $regressors $demo_controls, noabsorb vce(robust)
local rsq_3: display %5.3f `e(r2_a)'

qui sum dummy_policy_decreasemsupply if e(sample) 
local obs_3: display %5.0f `r(N)'

qui sum dummy_policy_decreasemsupply if e(sample) & treatment==0
local depmean_3: display %5.3f `r(mean)'
local std_3: display %5.3f `r(sd)'



eststo:  reghdfe dummy_policy_announcement $regressors $demo_controls, noabsorb vce(robust)
local rsq_4: display %5.3f `e(r2_a)'

qui sum dummy_policy_announcement if e(sample) 
local obs_4: display %5.0f `r(N)'


qui sum dummy_policy_announcement if e(sample) & treatment==0
local depmean_4: display %5.3f `r(mean)'
local std_4: display %5.3f `r(sd)'


eststo:  reghdfe dummy_policy_debtreduce_highinc $regressors $demo_controls, noabsorb vce(robust)
local rsq_5: display %5.3f `e(r2_a)'

qui sum dummy_policy_debtreduce_highinc if e(sample) 
local obs_5: display %5.0f `r(N)'

qui sum dummy_policy_debtreduce_highinc if e(sample) & treatment==0
local depmean_5: display %5.3f `r(mean)'
local std_5: display %5.3f `r(sd)'

eststo:  reghdfe dummy_policy_debtreduce_midinc $regressors $demo_controls, noabsorb vce(robust)
local rsq_6: display %5.3f `e(r2_a)'

qui sum dummy_policy_debtreduce_midinc if e(sample) 
local obs_6: display %5.0f `r(N)'


qui sum dummy_policy_debtreduce_midinc if e(sample) & treatment==0
local depmean_6: display %5.3f `r(mean)'
local std_6: display %5.3f `r(sd)'


eststo:  reghdfe dummy_policy_debtreduce_lowinc $regressors $demo_controls, noabsorb vce(robust)
local rsq_7: display %5.3f `e(r2_a)'

qui sum dummy_policy_debtreduce_lowinc if e(sample) 
local obs_7: display %5.0f `r(N)'

qui sum dummy_policy_debtreduce_lowinc if e(sample) & treatment==0
local depmean_7: display %5.3f `r(mean)'
local std_7: display %5.3f `r(sd)'


** First panel: Perceived causes of inflation **
file open holder using $tables/panel_causes.tex, write replace text
file write holder "\textbf{Perceived causes of inflation}\\ " _n 
file close holder

esttab using $tables/panel_causes_reg.tex, replace fragment  booktabs noconst nobase  label cells(b(fmt(3) star) se(par fmt(3))) collabels(none) keep(cause_*) /// 
starlevels(* .1 ** .05 *** .01) se nonumbers nomtitles nolines nocon noobs coeflabels( cause_gvt "Government spending, debt, taxation (e.g., income tax cuts, increase spending in social security)" cause_costs "Increases in costs of production (e.g., supply chain disruptions, increases in oil prices)" cause_fed "Actions by the Federal Reserve (e.g, decrease interest rate, increase money supply)" cause_firms "Actions by firms and businesses (e.g., decrease in competition, increase prices to increase profits)" cause_hh "Households spending more (e.g., because of optimism, because of increases in inflation expectations)" cause_labor "Changes in the labor market (e.g., wage-price spirals, labor shortages)" ) compress


** Second panel: Perceived consequences of inflation **
file open holder using $tables/panel_cons.tex, write replace text
file write holder "\textbf{Perceived consequences of inflation}\\ " _n 
file close holder

esttab using $tables/panel_cons_reg.tex, replace fragment  booktabs noconst nobase  label cells(b(fmt(3) star) se(par fmt(3))) collabels(none) keep(cons_*) /// 
starlevels(* .1 ** .05 *** .01) se nonumbers nomtitles nolines nocon noobs coeflabels(cons_cognitive "Cognitive costs (uncertainty \& complex budgeting)" cons_polecon "Political \& social costs (trust in govt, social cohesion, inequality, lower natl. prestige)" cons_efficiency "Efficiency \& economic costs (dollar value, GDP growth, resource misalloc., menu \& shoeleather costs, firms daily decisions)") compress


** Third panel: Perceived distributional impacts of inflation **
file open holder using $tables/panel_distr.tex, write replace text
file write holder "\textbf{Perceived distributional impacts of inflation}\\ " _n 
file close holder

esttab using $tables/panel_distr_reg.tex, replace fragment  booktabs noconst nobase  label cells(b(fmt(3) star) se(par fmt(3))) collabels(none) keep(low_inc_lost_more) /// 
starlevels(* .1 ** .05 *** .01) se nonumbers nomtitles nolines nocon noobs compress


** Fourth panel: Knowledge of inflation **
file open holder using $tables/panel_condcorr.tex, write replace text
file write holder "\textbf{Knowledge of inflation}\\ " _n 
file close holder

esttab using $tables/panel_condcorr_reg.tex, replace fragment  booktabs noconst nobase  label cells(b(fmt(3) star) se(par fmt(3))) collabels(none) keep(correct_corr  ) /// 
starlevels(* .1 ** .05 *** .01) se nonumbers nomtitles nolines nocon noobs compress


** Fifth panel: Perceived trade-offs **
file open holder using $tables/panel_tradeoffs.tex, write replace text
file write holder "\textbf{Perceived trade-offs}\\ " _n 
file close holder

esttab using $tables/panel_tradeoffs_reg.tex, replace fragment  booktabs noconst nobase  label cells(b(fmt(3) star) se(par fmt(3))) collabels(none) keep( index_tradeoffs_good index_tradeoffs_policy) coeflabel(index_tradeoffs_policy "Policy needs to reduce economic activity to fight inflation (e.g., reduce growth)") /// 
starlevels(* .1 ** .05 *** .01) se nonumbers nomtitles nolines nocon noobs compress


** Sixth panel: Asset exposure **
file open holder using $tables/panel_asset.tex, write replace text
file write holder "\textbf{Asset exposure}\\ " _n 
file close holder

esttab using $tables/panel_asset_reg.tex, replace fragment  booktabs noconst nobase  label cells(b(fmt(3) star) se(par fmt(3))) collabels(none) keep( exposure_index)  /// 
starlevels(* .1 ** .05 *** .01) se nonumbers nomtitles nolines nocon noobs compress

** Summary statistics **
file open holder using $tables/panel_means_before.tex, write replace text
file write holder "\hline " _n 
file write holder "Observations & `obs_1' & `obs_2' & `obs_3' & `obs_4' & `obs_5' & `obs_6' & `obs_7' \\" _n  
file write holder "Adj. R$^{2}$ & `rsq_1' & `rsq_2' & `rsq_3' & `rsq_4' & `rsq_5' & `rsq_6' & `rsq_7' \\" _n 
file write holder "$\mathbb{E}$(Dependent variable)& `depmean_1' & `depmean_2' & `depmean_3'  & `depmean_4' & `depmean_5' & `depmean_6' & `depmean_7' \\" _n   
file write holder "Dependent variable std. dev. & `std_1' & `std_2' & `std_3' & `std_4' & `std_5' & `std_6' & `std_7' \\" _n
file write holder "\hline " _n 
file write holder " & & \\" _n
file close holder


eststo clear

appendfile $tables/panel_causes.tex $table_name.tex
appendfile $tables/panel_causes_reg.tex $table_name.tex
appendfile $tables/panel_cons.tex $table_name.tex
appendfile $tables/panel_cons_reg.tex $table_name.tex
appendfile $tables/panel_distr.tex $table_name.tex
appendfile $tables/panel_distr_reg.tex $table_name.tex
appendfile $tables/panel_condcorr.tex $table_name.tex
appendfile $tables/panel_condcorr_reg.tex $table_name.tex
appendfile $tables/panel_tradeoffs.tex $table_name.tex
appendfile $tables/panel_tradeoffs_reg.tex $table_name.tex
appendfile $tables/panel_asset.tex $table_name.tex
appendfile $tables/panel_asset_reg.tex $table_name.tex
appendfile $tables/panel_means_before.tex $table_name.tex
appendfile $tables/temp_end.tex $table_name.tex

erase $tables/panel_causes.tex 
erase $tables/panel_causes_reg.tex 
erase $tables/panel_cons.tex 
erase $tables/panel_cons_reg.tex 
erase $tables/panel_distr.tex 
erase $tables/panel_distr_reg.tex 
erase $tables/panel_condcorr.tex 
erase $tables/panel_condcorr_reg.tex 
erase $tables/panel_tradeoffs.tex 
erase $tables/panel_tradeoffs_reg.tex 
erase $tables/panel_asset.tex 
erase $tables/panel_asset_reg.tex 
erase $tables/panel_means_before.tex
erase $tables/temp_end.tex
}




